<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'atlana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa go taga, mmala wa letlalo wa go taga wa magareng',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'atlana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa go taga, mmala wa letlalo wa magareng',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'atlana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa go taga, mmala wa letlalo wo moswana wa magareng',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'atlana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa go taga, mmala wa letlalo wo moswana',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'atlana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa go taga',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'atlana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa magareng',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'atlana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana wa magareng',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'atlana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'atlana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa magareng, mmala wa letlalo wa go taga',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'atlana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa magareng, mmala wa letlalo wa go taga wa magareng',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'atlana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa magareng, mmala wa letlalo wo moswana wa magareng',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'atlana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa magareng, mmala wa letlalo wo moswana',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'atlana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'atlana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga wa magareng',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'atlana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa magareng',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'atlana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wo moswana',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'atlana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wo moswana, mmala wa letlalo wa go taga',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'atlana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wo moswana, mmala wa letlalo wa go taga wa magareng',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'atlana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wo moswana, mmala wa letlalo wa magareng',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'atlana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wo moswana, mmala wa letlalo wo moswana wa magareng',
    '👨🏻‍❤‍💋‍👨🏻' => 'atlana: monna, monna, mmala wa letlalo wa go taga',
    '👨🏻‍❤‍💋‍👨🏼' => 'atlana: monna, monna, mmala wa letlalo wa go taga, mmala wa letlalo wa go taga wa magareng',
    '👨🏻‍❤‍💋‍👨🏽' => 'atlana: monna, monna, mmala wa letlalo wa go taga, mmala wa letlalo wa magareng',
    '👨🏻‍❤‍💋‍👨🏾' => 'atlana: monna, monna, mmala wa letlalo wa go taga, mmala wa letlalo wo moswana wa magareng',
    '👨🏻‍❤‍💋‍👨🏿' => 'atlana: monna, monna, mmala wa letlalo wa go taga, mmala wa letlalo wo moswana',
    '👨🏼‍❤‍💋‍👨🏻' => 'atlana: monna, monna, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa go taga',
    '👨🏼‍❤‍💋‍👨🏼' => 'atlana: monna, monna, mmala wa letlalo wa go taga wa magareng',
    '👨🏼‍❤‍💋‍👨🏽' => 'atlana: monna, monna, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa magareng',
    '👨🏼‍❤‍💋‍👨🏾' => 'atlana: monna, monna, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👨🏼‍❤‍💋‍👨🏿' => 'atlana: monna, monna, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana',
    '👨🏽‍❤‍💋‍👨🏻' => 'atlana: monna, monna, mmala wa letlalo wa magareng, mmala wa letlalo wa go taga',
    '👨🏽‍❤‍💋‍👨🏼' => 'atlana: monna, monna, mmala wa letlalo wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍❤‍💋‍👨🏽' => 'atlana: monna, monna, mmala wa letlalo wa magareng',
    '👨🏽‍❤‍💋‍👨🏾' => 'atlana: monna, monna, mmala wa letlalo wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👨🏽‍❤‍💋‍👨🏿' => 'atlana: monna, monna, mmala wa letlalo wa magareng, mmala wa letlalo wo moswana',
    '👨🏾‍❤‍💋‍👨🏻' => 'atlana: monna, monna, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga',
    '👨🏾‍❤‍💋‍👨🏼' => 'atlana: monna, monna, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👨🏾‍❤‍💋‍👨🏽' => 'atlana: monna, monna, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa magareng',
    '👨🏾‍❤‍💋‍👨🏾' => 'atlana: monna, monna, mmala wa letlalo wo moswana wa magareng',
    '👨🏾‍❤‍💋‍👨🏿' => 'atlana: monna, monna, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wo moswana',
    '👨🏿‍❤‍💋‍👨🏻' => 'atlana: monna, monna, mmala wa letlalo wo moswana, mmala wa letlalo wa go taga',
    '👨🏿‍❤‍💋‍👨🏼' => 'atlana: monna, monna, mmala wa letlalo wo moswana, mmala wa letlalo wa go taga wa magareng',
    '👨🏿‍❤‍💋‍👨🏽' => 'atlana: monna, monna, mmala wa letlalo wo moswana, mmala wa letlalo wa magareng',
    '👨🏿‍❤‍💋‍👨🏾' => 'atlana: monna, monna, mmala wa letlalo wo moswana, mmala wa letlalo wo moswana wa magareng',
    '👨🏿‍❤‍💋‍👨🏿' => 'atlana: monna, monna, mmala wa letlalo wo moswana',
    '👩🏻‍❤‍💋‍👨🏻' => 'atlana: mosadi, monna, mmala wa letlalo wa go taga',
    '👩🏻‍❤‍💋‍👨🏼' => 'atlana: mosadi, monna, mmala wa letlalo wa go taga, mmala wa letlalo wa go taga wa magareng',
    '👩🏻‍❤‍💋‍👨🏽' => 'atlana: mosadi, monna, mmala wa letlalo wa go taga, mmala wa letlalo wa magareng',
    '👩🏻‍❤‍💋‍👨🏾' => 'atlana: mosadi, monna, mmala wa letlalo wa go taga, mmala wa letlalo wo moswana wa magareng',
    '👩🏻‍❤‍💋‍👨🏿' => 'atlana: mosadi, monna, mmala wa letlalo wa go taga, mmala wa letlalo wo moswana',
    '👩🏼‍❤‍💋‍👨🏻' => 'atlana: mosadi, monna, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa go taga',
    '👩🏼‍❤‍💋‍👨🏼' => 'atlana: mosadi, monna, mmala wa letlalo wa go taga wa magareng',
    '👩🏼‍❤‍💋‍👨🏽' => 'atlana: mosadi, monna, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa magareng',
    '👩🏼‍❤‍💋‍👨🏾' => 'atlana: mosadi, monna, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👩🏼‍❤‍💋‍👨🏿' => 'atlana: mosadi, monna, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana',
    '👩🏽‍❤‍💋‍👨🏻' => 'atlana: mosadi, monna, mmala wa letlalo wa magareng, mmala wa letlalo wa go taga',
    '👩🏽‍❤‍💋‍👨🏼' => 'atlana: mosadi, monna, mmala wa letlalo wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍❤‍💋‍👨🏽' => 'atlana: mosadi, monna, mmala wa letlalo wa magareng',
    '👩🏽‍❤‍💋‍👨🏾' => 'atlana: mosadi, monna, mmala wa letlalo wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👩🏽‍❤‍💋‍👨🏿' => 'atlana: mosadi, monna, mmala wa letlalo wa magareng, mmala wa letlalo wo moswana',
    '👩🏾‍❤‍💋‍👨🏻' => 'atlana: mosadi, monna, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga',
    '👩🏾‍❤‍💋‍👨🏼' => 'atlana: mosadi, monna, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👩🏾‍❤‍💋‍👨🏽' => 'atlana: mosadi, monna, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa magareng',
    '👩🏾‍❤‍💋‍👨🏾' => 'atlana: mosadi, monna, mmala wa letlalo wo moswana wa magareng',
    '👩🏾‍❤‍💋‍👨🏿' => 'atlana: mosadi, monna, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wo moswana',
    '👩🏿‍❤‍💋‍👨🏻' => 'atlana: mosadi, monna, mmala wa letlalo wo moswana, mmala wa letlalo wa go taga',
    '👩🏿‍❤‍💋‍👨🏼' => 'atlana: mosadi, monna, mmala wa letlalo wo moswana, mmala wa letlalo wa go taga wa magareng',
    '👩🏿‍❤‍💋‍👨🏽' => 'atlana: mosadi, monna, mmala wa letlalo wo moswana, mmala wa letlalo wa magareng',
    '👩🏿‍❤‍💋‍👨🏾' => 'atlana: mosadi, monna, mmala wa letlalo wo moswana, mmala wa letlalo wo moswana wa magareng',
    '👩🏿‍❤‍💋‍👨🏿' => 'atlana: mosadi, monna, mmala wa letlalo wo moswana',
    '👩🏻‍❤‍💋‍👩🏻' => 'atlana: mosadi, mosadi, mmala wa letlalo wa go taga',
    '👩🏻‍❤‍💋‍👩🏼' => 'atlana: mosadi, mosadi, mmala wa letlalo wa go taga, mmala wa letlalo wa go taga wa magareng',
    '👩🏻‍❤‍💋‍👩🏽' => 'atlana: mosadi, mosadi, mmala wa letlalo wa go taga, mmala wa letlalo wa magareng',
    '👩🏻‍❤‍💋‍👩🏾' => 'atlana: mosadi, mosadi, mmala wa letlalo wa go taga, mmala wa letlalo wo moswana wa magareng',
    '👩🏻‍❤‍💋‍👩🏿' => 'atlana: mosadi, mosadi, mmala wa letlalo wa go taga, mmala wa letlalo wo moswana',
    '👩🏼‍❤‍💋‍👩🏻' => 'atlana: mosadi, mosadi, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa go taga',
    '👩🏼‍❤‍💋‍👩🏼' => 'atlana: mosadi, mosadi, mmala wa letlalo wa go taga wa magareng',
    '👩🏼‍❤‍💋‍👩🏽' => 'atlana: mosadi, mosadi, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa magareng',
    '👩🏼‍❤‍💋‍👩🏾' => 'atlana: mosadi, mosadi, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👩🏼‍❤‍💋‍👩🏿' => 'atlana: mosadi, mosadi, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana',
    '👩🏽‍❤‍💋‍👩🏻' => 'atlana: mosadi, mosadi, mmala wa letlalo wa magareng, mmala wa letlalo wa go taga',
    '👩🏽‍❤‍💋‍👩🏼' => 'atlana: mosadi, mosadi, mmala wa letlalo wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍❤‍💋‍👩🏽' => 'atlana: mosadi, mosadi, mmala wa letlalo wa magareng',
    '👩🏽‍❤‍💋‍👩🏾' => 'atlana: mosadi, mosadi, mmala wa letlalo wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👩🏽‍❤‍💋‍👩🏿' => 'atlana: mosadi, mosadi, mmala wa letlalo wa magareng, mmala wa letlalo wo moswana',
    '👩🏾‍❤‍💋‍👩🏻' => 'atlana: mosadi, mosadi, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga',
    '👩🏾‍❤‍💋‍👩🏼' => 'atlana: mosadi, mosadi, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👩🏾‍❤‍💋‍👩🏽' => 'atlana: mosadi, mosadi, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa magareng',
    '👩🏾‍❤‍💋‍👩🏾' => 'atlana: mosadi, mosadi, mmala wa letlalo wo moswana wa magareng',
    '👩🏾‍❤‍💋‍👩🏿' => 'atlana: mosadi, mosadi, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wo moswana',
    '👩🏿‍❤‍💋‍👩🏻' => 'atlana: mosadi, mosadi, mmala wa letlalo wo moswana, mmala wa letlalo wa go taga',
    '👩🏿‍❤‍💋‍👩🏼' => 'atlana: mosadi, mosadi, mmala wa letlalo wo moswana, mmala wa letlalo wa go taga wa magareng',
    '👩🏿‍❤‍💋‍👩🏽' => 'atlana: mosadi, mosadi, mmala wa letlalo wo moswana, mmala wa letlalo wa magareng',
    '👩🏿‍❤‍💋‍👩🏾' => 'atlana: mosadi, mosadi, mmala wa letlalo wo moswana, mmala wa letlalo wo moswana wa magareng',
    '👩🏿‍❤‍💋‍👩🏿' => 'atlana: mosadi, mosadi, mmala wa letlalo wo moswana',
    '🧑🏻‍🫯‍🧑🏼' => 'motho o lwa reseling: mmala wa letlalo wa go taga, mmala wa letlalo wa go taga wa magareng',
    '🧑🏻‍🫯‍🧑🏽' => 'motho o lwa reseling: mmala wa letlalo wa go taga, mmala wa letlalo wa magareng',
    '🧑🏻‍🫯‍🧑🏾' => 'motho o lwa reseling: mmala wa letlalo wa go taga, mmala wa letlalo wo moswana wa magareng',
    '🧑🏻‍🫯‍🧑🏿' => 'motho o lwa reseling: mmala wa letlalo wa go taga, mmala wa letlalo wo moswana',
    '🧑🏼‍🫯‍🧑🏻' => 'motho o lwa reseling: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa go taga',
    '🧑🏼‍🫯‍🧑🏽' => 'motho o lwa reseling: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa magareng',
    '🧑🏼‍🫯‍🧑🏾' => 'motho o lwa reseling: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana wa magareng',
    '🧑🏼‍🫯‍🧑🏿' => 'motho o lwa reseling: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana',
    '🧑🏽‍🫯‍🧑🏻' => 'motho o lwa reseling: mmala wa letlalo wa magareng, mmala wa letlalo wa go taga',
    '🧑🏽‍🫯‍🧑🏼' => 'motho o lwa reseling: mmala wa letlalo wa magareng, mmala wa letlalo wa go taga wa magareng',
    '🧑🏽‍🫯‍🧑🏾' => 'motho o lwa reseling: mmala wa letlalo wa magareng, mmala wa letlalo wo moswana wa magareng',
    '🧑🏽‍🫯‍🧑🏿' => 'motho o lwa reseling: mmala wa letlalo wa magareng, mmala wa letlalo wo moswana',
    '🧑🏾‍🫯‍🧑🏻' => 'motho o lwa reseling: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga',
    '🧑🏾‍🫯‍🧑🏼' => 'motho o lwa reseling: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga wa magareng',
    '🧑🏾‍🫯‍🧑🏽' => 'motho o lwa reseling: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa magareng',
    '🧑🏾‍🫯‍🧑🏿' => 'motho o lwa reseling: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wo moswana',
    '🧑🏿‍🫯‍🧑🏻' => 'motho o lwa reseling: mmala wa letlalo wo moswana, mmala wa letlalo wa go taga',
    '🧑🏿‍🫯‍🧑🏼' => 'motho o lwa reseling: mmala wa letlalo wo moswana, mmala wa letlalo wa go taga wa magareng',
    '🧑🏿‍🫯‍🧑🏽' => 'motho o lwa reseling: mmala wa letlalo wo moswana, mmala wa letlalo wa magareng',
    '🧑🏿‍🫯‍🧑🏾' => 'motho o lwa reseling: mmala wa letlalo wo moswana, mmala wa letlalo wo moswana wa magareng',
    '🧑🏻‍❤‍🧑🏼' => 'balekane ka pelwana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa go taga, mmala wa letlalo wa go taga wa magareng',
    '🧑🏻‍❤‍🧑🏽' => 'balekane ka pelwana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa go taga, mmala wa letlalo wa magareng',
    '🧑🏻‍❤‍🧑🏾' => 'balekane ka pelwana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa go taga, mmala wa letlalo wo moswana wa magareng',
    '🧑🏻‍❤‍🧑🏿' => 'balekane ka pelwana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa go taga, mmala wa letlalo wo moswana',
    '🧑🏼‍❤‍🧑🏻' => 'balekane ka pelwana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa go taga',
    '🧑🏼‍❤‍🧑🏽' => 'balekane ka pelwana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa magareng',
    '🧑🏼‍❤‍🧑🏾' => 'balekane ka pelwana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana wa magareng',
    '🧑🏼‍❤‍🧑🏿' => 'balekane ka pelwana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana',
    '🧑🏽‍❤‍🧑🏻' => 'balekane ka pelwana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa magareng, mmala wa letlalo wa go taga',
    '🧑🏽‍❤‍🧑🏼' => 'balekane ka pelwana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa magareng, mmala wa letlalo wa go taga wa magareng',
    '🧑🏽‍❤‍🧑🏾' => 'balekane ka pelwana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa magareng, mmala wa letlalo wo moswana wa magareng',
    '🧑🏽‍❤‍🧑🏿' => 'balekane ka pelwana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wa magareng, mmala wa letlalo wo moswana',
    '🧑🏾‍❤‍🧑🏻' => 'balekane ka pelwana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga',
    '🧑🏾‍❤‍🧑🏼' => 'balekane ka pelwana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga wa magareng',
    '🧑🏾‍❤‍🧑🏽' => 'balekane ka pelwana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa magareng',
    '🧑🏾‍❤‍🧑🏿' => 'balekane ka pelwana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wo moswana',
    '🧑🏿‍❤‍🧑🏻' => 'balekane ka pelwana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wo moswana, mmala wa letlalo wa go taga',
    '🧑🏿‍❤‍🧑🏼' => 'balekane ka pelwana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wo moswana, mmala wa letlalo wa go taga wa magareng',
    '🧑🏿‍❤‍🧑🏽' => 'balekane ka pelwana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wo moswana, mmala wa letlalo wa magareng',
    '🧑🏿‍❤‍🧑🏾' => 'balekane ka pelwana: motho yo mogolo, motho yo mogolo, mmala wa letlalo wo moswana, mmala wa letlalo wo moswana wa magareng',
    '🧑🏻‍🐰‍🧑🏼' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wa go taga, mmala wa letlalo wa go taga wa magareng',
    '🧑🏻‍🐰‍🧑🏽' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wa go taga, mmala wa letlalo wa magareng',
    '🧑🏻‍🐰‍🧑🏾' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wa go taga, mmala wa letlalo wo moswana wa magareng',
    '🧑🏻‍🐰‍🧑🏿' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wa go taga, mmala wa letlalo wo moswana',
    '🧑🏼‍🐰‍🧑🏻' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa go taga',
    '🧑🏼‍🐰‍🧑🏽' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa magareng',
    '🧑🏼‍🐰‍🧑🏾' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana wa magareng',
    '🧑🏼‍🐰‍🧑🏿' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana',
    '🧑🏽‍🐰‍🧑🏻' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wa magareng, mmala wa letlalo wa go taga',
    '🧑🏽‍🐰‍🧑🏼' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wa magareng, mmala wa letlalo wa go taga wa magareng',
    '🧑🏽‍🐰‍🧑🏾' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wa magareng, mmala wa letlalo wo moswana wa magareng',
    '🧑🏽‍🐰‍🧑🏿' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wa magareng, mmala wa letlalo wo moswana',
    '🧑🏾‍🐰‍🧑🏻' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga',
    '🧑🏾‍🐰‍🧑🏼' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga wa magareng',
    '🧑🏾‍🐰‍🧑🏽' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa magareng',
    '🧑🏾‍🐰‍🧑🏿' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wo moswana',
    '🧑🏿‍🐰‍🧑🏻' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wo moswana, mmala wa letlalo wa go taga',
    '🧑🏿‍🐰‍🧑🏼' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wo moswana, mmala wa letlalo wa go taga wa magareng',
    '🧑🏿‍🐰‍🧑🏽' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wo moswana, mmala wa letlalo wa magareng',
    '🧑🏿‍🐰‍🧑🏾' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wo moswana, mmala wa letlalo wo moswana wa magareng',
    '👨🏻‍🫯‍👨🏼' => 'banna ba a resela: mmala wa letlalo wa go taga, mmala wa letlalo wa go taga wa magareng',
    '👨🏻‍🫯‍👨🏽' => 'banna ba a resela: mmala wa letlalo wa go taga, mmala wa letlalo wa magareng',
    '👨🏻‍🫯‍👨🏾' => 'banna ba a resela: mmala wa letlalo wa go taga, mmala wa letlalo wo moswana wa magareng',
    '👨🏻‍🫯‍👨🏿' => 'banna ba a resela: mmala wa letlalo wa go taga, mmala wa letlalo wo moswana',
    '👨🏼‍🫯‍👨🏻' => 'banna ba a resela: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa go taga',
    '👨🏼‍🫯‍👨🏽' => 'banna ba a resela: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa magareng',
    '👨🏼‍🫯‍👨🏾' => 'banna ba a resela: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👨🏼‍🫯‍👨🏿' => 'banna ba a resela: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana',
    '👨🏽‍🫯‍👨🏻' => 'banna ba a resela: mmala wa letlalo wa magareng, mmala wa letlalo wa go taga',
    '👨🏽‍🫯‍👨🏼' => 'banna ba a resela: mmala wa letlalo wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍🫯‍👨🏾' => 'banna ba a resela: mmala wa letlalo wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👨🏽‍🫯‍👨🏿' => 'banna ba a resela: mmala wa letlalo wa magareng, mmala wa letlalo wo moswana',
    '👨🏾‍🫯‍👨🏻' => 'banna ba a resela: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga',
    '👨🏾‍🫯‍👨🏼' => 'banna ba a resela: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👨🏾‍🫯‍👨🏽' => 'banna ba a resela: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa magareng',
    '👨🏾‍🫯‍👨🏿' => 'banna ba a resela: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wo moswana',
    '👨🏿‍🫯‍👨🏻' => 'banna ba a resela: mmala wa letlalo wo moswana, mmala wa letlalo wa go taga',
    '👨🏿‍🫯‍👨🏼' => 'banna ba a resela: mmala wa letlalo wo moswana, mmala wa letlalo wa go taga wa magareng',
    '👨🏿‍🫯‍👨🏽' => 'banna ba a resela: mmala wa letlalo wo moswana, mmala wa letlalo wa magareng',
    '👨🏿‍🫯‍👨🏾' => 'banna ba a resela: mmala wa letlalo wo moswana, mmala wa letlalo wo moswana wa magareng',
    '👨🏻‍❤‍👨🏻' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wa go taga',
    '👨🏻‍❤‍👨🏼' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wa go taga, mmala wa letlalo wa go taga wa magareng',
    '👨🏻‍❤‍👨🏽' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wa go taga, mmala wa letlalo wa magareng',
    '👨🏻‍❤‍👨🏾' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wa go taga, mmala wa letlalo wo moswana wa magareng',
    '👨🏻‍❤‍👨🏿' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wa go taga, mmala wa letlalo wo moswana',
    '👨🏼‍❤‍👨🏻' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa go taga',
    '👨🏼‍❤‍👨🏼' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wa go taga wa magareng',
    '👨🏼‍❤‍👨🏽' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa magareng',
    '👨🏼‍❤‍👨🏾' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👨🏼‍❤‍👨🏿' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana',
    '👨🏽‍❤‍👨🏻' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wa magareng, mmala wa letlalo wa go taga',
    '👨🏽‍❤‍👨🏼' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍❤‍👨🏽' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wa magareng',
    '👨🏽‍❤‍👨🏾' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👨🏽‍❤‍👨🏿' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wa magareng, mmala wa letlalo wo moswana',
    '👨🏾‍❤‍👨🏻' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga',
    '👨🏾‍❤‍👨🏼' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👨🏾‍❤‍👨🏽' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa magareng',
    '👨🏾‍❤‍👨🏾' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wo moswana wa magareng',
    '👨🏾‍❤‍👨🏿' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wo moswana',
    '👨🏿‍❤‍👨🏻' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wo moswana, mmala wa letlalo wa go taga',
    '👨🏿‍❤‍👨🏼' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wo moswana, mmala wa letlalo wa go taga wa magareng',
    '👨🏿‍❤‍👨🏽' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wo moswana, mmala wa letlalo wa magareng',
    '👨🏿‍❤‍👨🏾' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wo moswana, mmala wa letlalo wo moswana wa magareng',
    '👨🏿‍❤‍👨🏿' => 'balekane ka pelwana: monna, monna, mmala wa letlalo wo moswana',
    '👨🏻‍🐰‍👨🏼' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa go taga, mmala wa letlalo wa go taga wa magareng',
    '👨🏻‍🐰‍👨🏽' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa go taga, mmala wa letlalo wa magareng',
    '👨🏻‍🐰‍👨🏾' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa go taga, mmala wa letlalo wo moswana wa magareng',
    '👨🏻‍🐰‍👨🏿' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa go taga, mmala wa letlalo wo moswana',
    '👨🏼‍🐰‍👨🏻' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa go taga',
    '👨🏼‍🐰‍👨🏽' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa magareng',
    '👨🏼‍🐰‍👨🏾' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👨🏼‍🐰‍👨🏿' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana',
    '👨🏽‍🐰‍👨🏻' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa magareng, mmala wa letlalo wa go taga',
    '👨🏽‍🐰‍👨🏼' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍🐰‍👨🏾' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👨🏽‍🐰‍👨🏿' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa magareng, mmala wa letlalo wo moswana',
    '👨🏾‍🐰‍👨🏻' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga',
    '👨🏾‍🐰‍👨🏼' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👨🏾‍🐰‍👨🏽' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa magareng',
    '👨🏾‍🐰‍👨🏿' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wo moswana',
    '👨🏿‍🐰‍👨🏻' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wo moswana, mmala wa letlalo wa go taga',
    '👨🏿‍🐰‍👨🏼' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wo moswana, mmala wa letlalo wa go taga wa magareng',
    '👨🏿‍🐰‍👨🏽' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wo moswana, mmala wa letlalo wa magareng',
    '👨🏿‍🐰‍👨🏾' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wo moswana, mmala wa letlalo wo moswana wa magareng',
    '👩🏻‍🫯‍👩🏼' => 'mosadi o lwa reseling: mmala wa letlalo wa go taga, mmala wa letlalo wa go taga wa magareng',
    '👩🏻‍🫯‍👩🏽' => 'mosadi o lwa reseling: mmala wa letlalo wa go taga, mmala wa letlalo wa magareng',
    '👩🏻‍🫯‍👩🏾' => 'mosadi o lwa reseling: mmala wa letlalo wa go taga, mmala wa letlalo wo moswana wa magareng',
    '👩🏻‍🫯‍👩🏿' => 'mosadi o lwa reseling: mmala wa letlalo wa go taga, mmala wa letlalo wo moswana',
    '👩🏼‍🫯‍👩🏻' => 'mosadi o lwa reseling: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa go taga',
    '👩🏼‍🫯‍👩🏽' => 'mosadi o lwa reseling: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa magareng',
    '👩🏼‍🫯‍👩🏾' => 'mosadi o lwa reseling: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👩🏼‍🫯‍👩🏿' => 'mosadi o lwa reseling: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana',
    '👩🏽‍🫯‍👩🏻' => 'mosadi o lwa reseling: mmala wa letlalo wa magareng, mmala wa letlalo wa go taga',
    '👩🏽‍🫯‍👩🏼' => 'mosadi o lwa reseling: mmala wa letlalo wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍🫯‍👩🏾' => 'mosadi o lwa reseling: mmala wa letlalo wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👩🏽‍🫯‍👩🏿' => 'mosadi o lwa reseling: mmala wa letlalo wa magareng, mmala wa letlalo wo moswana',
    '👩🏾‍🫯‍👩🏻' => 'mosadi o lwa reseling: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga',
    '👩🏾‍🫯‍👩🏼' => 'mosadi o lwa reseling: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👩🏾‍🫯‍👩🏽' => 'mosadi o lwa reseling: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa magareng',
    '👩🏾‍🫯‍👩🏿' => 'mosadi o lwa reseling: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wo moswana',
    '👩🏿‍🫯‍👩🏻' => 'mosadi o lwa reseling: mmala wa letlalo wo moswana, mmala wa letlalo wa go taga',
    '👩🏿‍🫯‍👩🏼' => 'mosadi o lwa reseling: mmala wa letlalo wo moswana, mmala wa letlalo wa go taga wa magareng',
    '👩🏿‍🫯‍👩🏽' => 'mosadi o lwa reseling: mmala wa letlalo wo moswana, mmala wa letlalo wa magareng',
    '👩🏿‍🫯‍👩🏾' => 'mosadi o lwa reseling: mmala wa letlalo wo moswana, mmala wa letlalo wo moswana wa magareng',
    '👩🏻‍❤‍👨🏻' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wa go taga',
    '👩🏻‍❤‍👨🏼' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wa go taga, mmala wa letlalo wa go taga wa magareng',
    '👩🏻‍❤‍👨🏽' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wa go taga, mmala wa letlalo wa magareng',
    '👩🏻‍❤‍👨🏾' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wa go taga, mmala wa letlalo wo moswana wa magareng',
    '👩🏻‍❤‍👨🏿' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wa go taga, mmala wa letlalo wo moswana',
    '👩🏼‍❤‍👨🏻' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa go taga',
    '👩🏼‍❤‍👨🏼' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wa go taga wa magareng',
    '👩🏼‍❤‍👨🏽' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa magareng',
    '👩🏼‍❤‍👨🏾' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👩🏼‍❤‍👨🏿' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana',
    '👩🏽‍❤‍👨🏻' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wa magareng, mmala wa letlalo wa go taga',
    '👩🏽‍❤‍👨🏼' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍❤‍👨🏽' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wa magareng',
    '👩🏽‍❤‍👨🏾' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👩🏽‍❤‍👨🏿' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wa magareng, mmala wa letlalo wo moswana',
    '👩🏾‍❤‍👨🏻' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga',
    '👩🏾‍❤‍👨🏼' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👩🏾‍❤‍👨🏽' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa magareng',
    '👩🏾‍❤‍👨🏾' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wo moswana wa magareng',
    '👩🏾‍❤‍👨🏿' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wo moswana',
    '👩🏿‍❤‍👨🏻' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wo moswana, mmala wa letlalo wa go taga',
    '👩🏿‍❤‍👨🏼' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wo moswana, mmala wa letlalo wa go taga wa magareng',
    '👩🏿‍❤‍👨🏽' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wo moswana, mmala wa letlalo wa magareng',
    '👩🏿‍❤‍👨🏾' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wo moswana, mmala wa letlalo wo moswana wa magareng',
    '👩🏿‍❤‍👨🏿' => 'balekane ka pelwana: mosadi, monna, mmala wa letlalo wo moswana',
    '👩🏻‍❤‍👩🏻' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wa go taga',
    '👩🏻‍❤‍👩🏼' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wa go taga, mmala wa letlalo wa go taga wa magareng',
    '👩🏻‍❤‍👩🏽' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wa go taga, mmala wa letlalo wa magareng',
    '👩🏻‍❤‍👩🏾' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wa go taga, mmala wa letlalo wo moswana wa magareng',
    '👩🏻‍❤‍👩🏿' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wa go taga, mmala wa letlalo wo moswana',
    '👩🏼‍❤‍👩🏻' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa go taga',
    '👩🏼‍❤‍👩🏼' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wa go taga wa magareng',
    '👩🏼‍❤‍👩🏽' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa magareng',
    '👩🏼‍❤‍👩🏾' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👩🏼‍❤‍👩🏿' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana',
    '👩🏽‍❤‍👩🏻' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wa magareng, mmala wa letlalo wa go taga',
    '👩🏽‍❤‍👩🏼' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍❤‍👩🏽' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wa magareng',
    '👩🏽‍❤‍👩🏾' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👩🏽‍❤‍👩🏿' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wa magareng, mmala wa letlalo wo moswana',
    '👩🏾‍❤‍👩🏻' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga',
    '👩🏾‍❤‍👩🏼' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👩🏾‍❤‍👩🏽' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa magareng',
    '👩🏾‍❤‍👩🏾' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wo moswana wa magareng',
    '👩🏾‍❤‍👩🏿' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wo moswana',
    '👩🏿‍❤‍👩🏻' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wo moswana, mmala wa letlalo wa go taga',
    '👩🏿‍❤‍👩🏼' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wo moswana, mmala wa letlalo wa go taga wa magareng',
    '👩🏿‍❤‍👩🏽' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wo moswana, mmala wa letlalo wa magareng',
    '👩🏿‍❤‍👩🏾' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wo moswana, mmala wa letlalo wo moswana wa magareng',
    '👩🏿‍❤‍👩🏿' => 'balekane ka pelwana: mosadi, mosadi, mmala wa letlalo wo moswana',
    '👩🏻‍🐰‍👩🏼' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa go taga, mmala wa letlalo wa go taga wa magareng',
    '👩🏻‍🐰‍👩🏽' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa go taga, mmala wa letlalo wa magareng',
    '👩🏻‍🐰‍👩🏾' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa go taga, mmala wa letlalo wo moswana wa magareng',
    '👩🏻‍🐰‍👩🏿' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa go taga, mmala wa letlalo wo moswana',
    '👩🏼‍🐰‍👩🏻' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa go taga',
    '👩🏼‍🐰‍👩🏽' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa magareng',
    '👩🏼‍🐰‍👩🏾' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👩🏼‍🐰‍👩🏿' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana',
    '👩🏽‍🐰‍👩🏻' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa magareng, mmala wa letlalo wa go taga',
    '👩🏽‍🐰‍👩🏼' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍🐰‍👩🏾' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👩🏽‍🐰‍👩🏿' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa magareng, mmala wa letlalo wo moswana',
    '👩🏾‍🐰‍👩🏻' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga',
    '👩🏾‍🐰‍👩🏼' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👩🏾‍🐰‍👩🏽' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa magareng',
    '👩🏾‍🐰‍👩🏿' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wo moswana',
    '👩🏿‍🐰‍👩🏻' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wo moswana, mmala wa letlalo wa go taga',
    '👩🏿‍🐰‍👩🏼' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wo moswana, mmala wa letlalo wa go taga wa magareng',
    '👩🏿‍🐰‍👩🏽' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wo moswana, mmala wa letlalo wa magareng',
    '👩🏿‍🐰‍👩🏾' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wo moswana, mmala wa letlalo wo moswana wa magareng',
    '👩🏻‍🤝‍👩🏼' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wa go taga, mmala wa letlalo wa go taga wa magareng',
    '👩🏻‍🤝‍👩🏽' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wa go taga, mmala wa letlalo wa magareng',
    '👩🏻‍🤝‍👩🏾' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wa go taga, mmala wa letlalo wo moswana wa magareng',
    '👩🏻‍🤝‍👩🏿' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wa go taga, mmala wa letlalo wo moswana',
    '👩🏼‍🤝‍👩🏻' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa go taga',
    '👩🏼‍🤝‍👩🏽' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa magareng',
    '👩🏼‍🤝‍👩🏾' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👩🏼‍🤝‍👩🏿' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana',
    '👩🏽‍🤝‍👩🏻' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wa magareng, mmala wa letlalo wa go taga',
    '👩🏽‍🤝‍👩🏼' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍🤝‍👩🏾' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👩🏽‍🤝‍👩🏿' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wa magareng, mmala wa letlalo wo moswana',
    '👩🏾‍🤝‍👩🏻' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga',
    '👩🏾‍🤝‍👩🏼' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👩🏾‍🤝‍👩🏽' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa magareng',
    '👩🏾‍🤝‍👩🏿' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wo moswana',
    '👩🏿‍🤝‍👩🏻' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wo moswana, mmala wa letlalo wa go taga',
    '👩🏿‍🤝‍👩🏼' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wo moswana, mmala wa letlalo wa go taga wa magareng',
    '👩🏿‍🤝‍👩🏽' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wo moswana, mmala wa letlalo wa magareng',
    '👩🏿‍🤝‍👩🏾' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wo moswana, mmala wa letlalo wo moswana wa magareng',
    '👩🏻‍🤝‍👨🏼' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wa go taga, mmala wa letlalo wa go taga wa magareng',
    '👩🏻‍🤝‍👨🏽' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wa go taga, mmala wa letlalo wa magareng',
    '👩🏻‍🤝‍👨🏾' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wa go taga, mmala wa letlalo wo moswana wa magareng',
    '👩🏻‍🤝‍👨🏿' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wa go taga, mmala wa letlalo wo moswana',
    '👩🏼‍🤝‍👨🏻' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa go taga',
    '👩🏼‍🤝‍👨🏽' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa magareng',
    '👩🏼‍🤝‍👨🏾' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👩🏼‍🤝‍👨🏿' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana',
    '👩🏽‍🤝‍👨🏻' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wa magareng, mmala wa letlalo wa go taga',
    '👩🏽‍🤝‍👨🏼' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍🤝‍👨🏾' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👩🏽‍🤝‍👨🏿' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wa magareng, mmala wa letlalo wo moswana',
    '👩🏾‍🤝‍👨🏻' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga',
    '👩🏾‍🤝‍👨🏼' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👩🏾‍🤝‍👨🏽' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa magareng',
    '👩🏾‍🤝‍👨🏿' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wo moswana',
    '👩🏿‍🤝‍👨🏻' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wo moswana, mmala wa letlalo wa go taga',
    '👩🏿‍🤝‍👨🏼' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wo moswana, mmala wa letlalo wa go taga wa magareng',
    '👩🏿‍🤝‍👨🏽' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wo moswana, mmala wa letlalo wa magareng',
    '👩🏿‍🤝‍👨🏾' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wo moswana, mmala wa letlalo wo moswana wa magareng',
    '👨🏻‍🤝‍👨🏼' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wa go taga, mmala wa letlalo wa go taga wa magareng',
    '👨🏻‍🤝‍👨🏽' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wa go taga, mmala wa letlalo wa magareng',
    '👨🏻‍🤝‍👨🏾' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wa go taga, mmala wa letlalo wo moswana wa magareng',
    '👨🏻‍🤝‍👨🏿' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wa go taga, mmala wa letlalo wo moswana',
    '👨🏼‍🤝‍👨🏻' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa go taga',
    '👨🏼‍🤝‍👨🏽' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa magareng',
    '👨🏼‍🤝‍👨🏾' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👨🏼‍🤝‍👨🏿' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana',
    '👨🏽‍🤝‍👨🏻' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wa magareng, mmala wa letlalo wa go taga',
    '👨🏽‍🤝‍👨🏼' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍🤝‍👨🏾' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wa magareng, mmala wa letlalo wo moswana wa magareng',
    '👨🏽‍🤝‍👨🏿' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wa magareng, mmala wa letlalo wo moswana',
    '👨🏾‍🤝‍👨🏻' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga',
    '👨🏾‍🤝‍👨🏼' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga wa magareng',
    '👨🏾‍🤝‍👨🏽' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa magareng',
    '👨🏾‍🤝‍👨🏿' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wo moswana',
    '👨🏿‍🤝‍👨🏻' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wo moswana, mmala wa letlalo wa go taga',
    '👨🏿‍🤝‍👨🏼' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wo moswana, mmala wa letlalo wa go taga wa magareng',
    '👨🏿‍🤝‍👨🏽' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wo moswana, mmala wa letlalo wa magareng',
    '👨🏿‍🤝‍👨🏾' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wo moswana, mmala wa letlalo wo moswana wa magareng',
    '👩‍❤‍💋‍👨' => 'atlana: mosadi, monna',
    '👨‍❤‍💋‍👨' => 'atlana: monna, monna',
    '👩‍❤‍💋‍👩' => 'atlana: mosadi, mosadi',
    '👨‍👩‍👧‍👦' => 'lapa: monna, mosadi, mosetsana, mošemane',
    '👨‍👩‍👦‍👦' => 'lapa: monna, mosadi, mošemane, mošemane',
    '👨‍👩‍👧‍👧' => 'lapa: monna, mosadi, mosetsana, mosetsana',
    '👨‍👨‍👧‍👦' => 'lapa: monna, monna, mosetsana, mošemane',
    '👨‍👨‍👦‍👦' => 'lapa: monna, monna, mošemane, mošemane',
    '👨‍👨‍👧‍👧' => 'lapa: monna, monna, mosetsana, mosetsana',
    '👩‍👩‍👧‍👦' => 'lapa: mosadi, mosadi, mosetsana, mošemane',
    '👩‍👩‍👦‍👦' => 'lapa: mosadi, mosadi, mošemane, mošemane',
    '👩‍👩‍👧‍👧' => 'lapa: mosadi, mosadi, mosetsana, mosetsana',
    '🫱🏻‍🫲🏼' => 'tumedišo ka letsogo: mmala wa letlalo wa go taga, mmala wa letlalo wa go taga wa magareng',
    '🫱🏻‍🫲🏽' => 'tumedišo ka letsogo: mmala wa letlalo wa go taga, mmala wa letlalo wa magareng',
    '🫱🏻‍🫲🏾' => 'tumedišo ka letsogo: mmala wa letlalo wa go taga, mmala wa letlalo wo moswana wa magareng',
    '🫱🏻‍🫲🏿' => 'tumedišo ka letsogo: mmala wa letlalo wa go taga, mmala wa letlalo wo moswana',
    '🫱🏼‍🫲🏻' => 'tumedišo ka letsogo: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa go taga',
    '🫱🏼‍🫲🏽' => 'tumedišo ka letsogo: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wa magareng',
    '🫱🏼‍🫲🏾' => 'tumedišo ka letsogo: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana wa magareng',
    '🫱🏼‍🫲🏿' => 'tumedišo ka letsogo: mmala wa letlalo wa go taga wa magareng, mmala wa letlalo wo moswana',
    '🫱🏽‍🫲🏻' => 'tumedišo ka letsogo: mmala wa letlalo wa magareng, mmala wa letlalo wa go taga',
    '🫱🏽‍🫲🏼' => 'tumedišo ka letsogo: mmala wa letlalo wa magareng, mmala wa letlalo wa go taga wa magareng',
    '🫱🏽‍🫲🏾' => 'tumedišo ka letsogo: mmala wa letlalo wa magareng, mmala wa letlalo wo moswana wa magareng',
    '🫱🏽‍🫲🏿' => 'tumedišo ka letsogo: mmala wa letlalo wa magareng, mmala wa letlalo wo moswana',
    '🫱🏾‍🫲🏻' => 'tumedišo ka letsogo: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga',
    '🫱🏾‍🫲🏼' => 'tumedišo ka letsogo: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa go taga wa magareng',
    '🫱🏾‍🫲🏽' => 'tumedišo ka letsogo: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wa magareng',
    '🫱🏾‍🫲🏿' => 'tumedišo ka letsogo: mmala wa letlalo wo moswana wa magareng, mmala wa letlalo wo moswana',
    '🫱🏿‍🫲🏻' => 'tumedišo ka letsogo: mmala wa letlalo wo moswana, mmala wa letlalo wa go taga',
    '🫱🏿‍🫲🏼' => 'tumedišo ka letsogo: mmala wa letlalo wo moswana, mmala wa letlalo wa go taga wa magareng',
    '🫱🏿‍🫲🏽' => 'tumedišo ka letsogo: mmala wa letlalo wo moswana, mmala wa letlalo wa magareng',
    '🫱🏿‍🫲🏾' => 'tumedišo ka letsogo: mmala wa letlalo wo moswana, mmala wa letlalo wo moswana wa magareng',
    '👩‍❤‍👨' => 'balekane ka pelwana: mosadi, monna',
    '👨‍❤‍👨' => 'balekane ka pelwana: monna, monna',
    '👩‍❤‍👩' => 'balekane ka pelwana: mosadi, mosadi',
    '👨‍👩‍👦' => 'lapa: monna, mosadi, mošemane',
    '👨‍👩‍👧' => 'lapa: monna, mosadi, mosetsana',
    '👨‍👨‍👦' => 'lapa: monna, monna, mošemane',
    '👨‍👨‍👧' => 'lapa: monna, monna, mosetsana',
    '👩‍👩‍👦' => 'lapa: mosadi, mosadi, mošemane',
    '👩‍👩‍👧' => 'lapa: mosadi, mosadi, mosetsana',
    '👨‍👦‍👦' => 'lapa: monna, mošemane, mošemane',
    '👨‍👧‍👦' => 'lapa: monna, mosetsana, mošemane',
    '👨‍👧‍👧' => 'lapa: monna, mosetsana, mosetsana',
    '👩‍👦‍👦' => 'lapa: mosadi, mošemane, mošemane',
    '👩‍👧‍👦' => 'lapa: mosadi, mosetsana, mošemane',
    '👩‍👧‍👧' => 'lapa: mosadi, mosetsana, mosetsana',
    '👱🏻‍♂' => 'monna wa meriri ya mesehla: mmala wa letlalo wa go taga',
    '👱🏼‍♂' => 'monna wa meriri ya mesehla: mmala wa letlalo wa go taga wa magareng',
    '👱🏽‍♂' => 'monna wa meriri ya mesehla: mmala wa letlalo wa magareng',
    '👱🏾‍♂' => 'monna wa meriri ya mesehla: mmala wa letlalo wo moswana wa magareng',
    '👱🏿‍♂' => 'monna wa meriri ya mesehla: mmala wa letlalo wo moswana',
    '👱🏻‍♀' => 'mosadi wa meriri ye mesehla: mmala wa letlalo wa go taga',
    '👱🏼‍♀' => 'mosadi wa meriri ye mesehla: mmala wa letlalo wa go taga wa magareng',
    '👱🏽‍♀' => 'mosadi wa meriri ye mesehla: mmala wa letlalo wa magareng',
    '👱🏾‍♀' => 'mosadi wa meriri ye mesehla: mmala wa letlalo wo moswana wa magareng',
    '👱🏿‍♀' => 'mosadi wa meriri ye mesehla: mmala wa letlalo wo moswana',
    '🙍🏻‍♂' => 'monna yo a sa dumelego: mmala wa letlalo wa go taga',
    '🙍🏼‍♂' => 'monna yo a sa dumelego: mmala wa letlalo wa go taga wa magareng',
    '🙍🏽‍♂' => 'monna yo a sa dumelego: mmala wa letlalo wa magareng',
    '🙍🏾‍♂' => 'monna yo a sa dumelego: mmala wa letlalo wo moswana wa magareng',
    '🙍🏿‍♂' => 'monna yo a sa dumelego: mmala wa letlalo wo moswana',
    '🙍🏻‍♀' => 'mosadi yo a sa dumelego ka ditho: mmala wa letlalo wa go taga',
    '🙍🏼‍♀' => 'mosadi yo a sa dumelego ka ditho: mmala wa letlalo wa go taga wa magareng',
    '🙍🏽‍♀' => 'mosadi yo a sa dumelego ka ditho: mmala wa letlalo wa magareng',
    '🙍🏾‍♀' => 'mosadi yo a sa dumelego ka ditho: mmala wa letlalo wo moswana wa magareng',
    '🙍🏿‍♀' => 'mosadi yo a sa dumelego ka ditho: mmala wa letlalo wo moswana',
    '🙎🏻‍♂' => 'monna yo a ipopilego molomo: mmala wa letlalo wa go taga',
    '🙎🏼‍♂' => 'monna yo a ipopilego molomo: mmala wa letlalo wa go taga wa magareng',
    '🙎🏽‍♂' => 'monna yo a ipopilego molomo: mmala wa letlalo wa magareng',
    '🙎🏾‍♂' => 'monna yo a ipopilego molomo: mmala wa letlalo wo moswana wa magareng',
    '🙎🏿‍♂' => 'monna yo a ipopilego molomo: mmala wa letlalo wo moswana',
    '🙎🏻‍♀' => 'mosadi yo a ipopilego molomo: mmala wa letlalo wa go taga',
    '🙎🏼‍♀' => 'mosadi yo a ipopilego molomo: mmala wa letlalo wa go taga wa magareng',
    '🙎🏽‍♀' => 'mosadi yo a ipopilego molomo: mmala wa letlalo wa magareng',
    '🙎🏾‍♀' => 'mosadi yo a ipopilego molomo: mmala wa letlalo wo moswana wa magareng',
    '🙎🏿‍♀' => 'mosadi yo a ipopilego molomo: mmala wa letlalo wo moswana',
    '🙅🏻‍♂' => 'monna o re AOWA ka ditho: mmala wa letlalo wa go taga',
    '🙅🏼‍♂' => 'monna o re AOWA ka ditho: mmala wa letlalo wa go taga wa magareng',
    '🙅🏽‍♂' => 'monna o re AOWA ka ditho: mmala wa letlalo wa magareng',
    '🙅🏾‍♂' => 'monna o re AOWA ka ditho: mmala wa letlalo wo moswana wa magareng',
    '🙅🏿‍♂' => 'monna o re AOWA ka ditho: mmala wa letlalo wo moswana',
    '🙅🏻‍♀' => 'mosadi o re AOWA ka ditho: mmala wa letlalo wa go taga',
    '🙅🏼‍♀' => 'mosadi o re AOWA ka ditho: mmala wa letlalo wa go taga wa magareng',
    '🙅🏽‍♀' => 'mosadi o re AOWA ka ditho: mmala wa letlalo wa magareng',
    '🙅🏾‍♀' => 'mosadi o re AOWA ka ditho: mmala wa letlalo wo moswana wa magareng',
    '🙅🏿‍♀' => 'mosadi o re AOWA ka ditho: mmala wa letlalo wo moswana',
    '🙆🏻‍♂' => 'monna o re GO LOKILE: mmala wa letlalo wa go taga',
    '🙆🏼‍♂' => 'monna o re GO LOKILE: mmala wa letlalo wa go taga wa magareng',
    '🙆🏽‍♂' => 'monna o re GO LOKILE: mmala wa letlalo wa magareng',
    '🙆🏾‍♂' => 'monna o re GO LOKILE: mmala wa letlalo wo moswana wa magareng',
    '🙆🏿‍♂' => 'monna o re GO LOKILE: mmala wa letlalo wo moswana',
    '🙆🏻‍♀' => 'mosadi o re GO LOKILE: mmala wa letlalo wa go taga',
    '🙆🏼‍♀' => 'mosadi o re GO LOKILE: mmala wa letlalo wa go taga wa magareng',
    '🙆🏽‍♀' => 'mosadi o re GO LOKILE: mmala wa letlalo wa magareng',
    '🙆🏾‍♀' => 'mosadi o re GO LOKILE: mmala wa letlalo wo moswana wa magareng',
    '🙆🏿‍♀' => 'mosadi o re GO LOKILE: mmala wa letlalo wo moswana',
    '💁🏻‍♂' => 'monna yo a kgwathago seatla: mmala wa letlalo wa go taga',
    '💁🏼‍♂' => 'monna yo a kgwathago seatla: mmala wa letlalo wa go taga wa magareng',
    '💁🏽‍♂' => 'monna yo a kgwathago seatla: mmala wa letlalo wa magareng',
    '💁🏾‍♂' => 'monna yo a kgwathago seatla: mmala wa letlalo wo moswana wa magareng',
    '💁🏿‍♂' => 'monna yo a kgwathago seatla: mmala wa letlalo wo moswana',
    '💁🏻‍♀' => 'mosadi o kgwatha ka seatla: mmala wa letlalo wa go taga',
    '💁🏼‍♀' => 'mosadi o kgwatha ka seatla: mmala wa letlalo wa go taga wa magareng',
    '💁🏽‍♀' => 'mosadi o kgwatha ka seatla: mmala wa letlalo wa magareng',
    '💁🏾‍♀' => 'mosadi o kgwatha ka seatla: mmala wa letlalo wo moswana wa magareng',
    '💁🏿‍♀' => 'mosadi o kgwatha ka seatla: mmala wa letlalo wo moswana',
    '🙋🏻‍♂' => 'monna o emiša seatla: mmala wa letlalo wa go taga',
    '🙋🏼‍♂' => 'monna o emiša seatla: mmala wa letlalo wa go taga wa magareng',
    '🙋🏽‍♂' => 'monna o emiša seatla: mmala wa letlalo wa magareng',
    '🙋🏾‍♂' => 'monna o emiša seatla: mmala wa letlalo wo moswana wa magareng',
    '🙋🏿‍♂' => 'monna o emiša seatla: mmala wa letlalo wo moswana',
    '🙋🏻‍♀' => 'mosadi o emiša seatla: mmala wa letlalo wa go taga',
    '🙋🏼‍♀' => 'mosadi o emiša seatla: mmala wa letlalo wa go taga wa magareng',
    '🙋🏽‍♀' => 'mosadi o emiša seatla: mmala wa letlalo wa magareng',
    '🙋🏾‍♀' => 'mosadi o emiša seatla: mmala wa letlalo wo moswana wa magareng',
    '🙋🏿‍♀' => 'mosadi o emiša seatla: mmala wa letlalo wo moswana',
    '🙇🏻‍♂' => 'monna o a inama: mmala wa letlalo wa go taga',
    '🙇🏼‍♂' => 'monna o a inama: mmala wa letlalo wa go taga wa magareng',
    '🙇🏽‍♂' => 'monna o a inama: mmala wa letlalo wa magareng',
    '🙇🏾‍♂' => 'monna o a inama: mmala wa letlalo wo moswana wa magareng',
    '🙇🏿‍♂' => 'monna o a inama: mmala wa letlalo wo moswana',
    '🙇🏻‍♀' => 'mosadi o a inama: mmala wa letlalo wa go taga',
    '🙇🏼‍♀' => 'mosadi o a inama: mmala wa letlalo wa go taga wa magareng',
    '🙇🏽‍♀' => 'mosadi o a inama: mmala wa letlalo wa magareng',
    '🙇🏾‍♀' => 'mosadi o a inama: mmala wa letlalo wo moswana wa magareng',
    '🙇🏿‍♀' => 'mosadi o a inama: mmala wa letlalo wo moswana',
    '🤦🏻‍♂' => 'monna o beile seatla sefahlegong: mmala wa letlalo wa go taga',
    '🤦🏼‍♂' => 'monna o beile seatla sefahlegong: mmala wa letlalo wa go taga wa magareng',
    '🤦🏽‍♂' => 'monna o beile seatla sefahlegong: mmala wa letlalo wa magareng',
    '🤦🏾‍♂' => 'monna o beile seatla sefahlegong: mmala wa letlalo wo moswana wa magareng',
    '🤦🏿‍♂' => 'monna o beile seatla sefahlegong: mmala wa letlalo wo moswana',
    '🤦🏻‍♀' => 'mosadi a beile bokagare bja seatla: mmala wa letlalo wa go taga',
    '🤦🏼‍♀' => 'mosadi a beile bokagare bja seatla: mmala wa letlalo wa go taga wa magareng',
    '🤦🏽‍♀' => 'mosadi a beile bokagare bja seatla: mmala wa letlalo wa magareng',
    '🤦🏾‍♀' => 'mosadi a beile bokagare bja seatla: mmala wa letlalo wo moswana wa magareng',
    '🤦🏿‍♀' => 'mosadi a beile bokagare bja seatla: mmala wa letlalo wo moswana',
    '🤷🏻‍♂' => 'monna o emiša magetla: mmala wa letlalo wa go taga',
    '🤷🏼‍♂' => 'monna o emiša magetla: mmala wa letlalo wa go taga wa magareng',
    '🤷🏽‍♂' => 'monna o emiša magetla: mmala wa letlalo wa magareng',
    '🤷🏾‍♂' => 'monna o emiša magetla: mmala wa letlalo wo moswana wa magareng',
    '🤷🏿‍♂' => 'monna o emiša magetla: mmala wa letlalo wo moswana',
    '🤷🏻‍♀' => 'mosadi o emiša magetla: mmala wa letlalo wa go taga',
    '🤷🏼‍♀' => 'mosadi o emiša magetla: mmala wa letlalo wa go taga wa magareng',
    '🤷🏽‍♀' => 'mosadi o emiša magetla: mmala wa letlalo wa magareng',
    '🤷🏾‍♀' => 'mosadi o emiša magetla: mmala wa letlalo wo moswana wa magareng',
    '🤷🏿‍♀' => 'mosadi o emiša magetla: mmala wa letlalo wo moswana',
    '👨🏻‍⚕' => 'monna wa go šoma ka tša kalafo: mmala wa letlalo wa go taga',
    '👨🏼‍⚕' => 'monna wa go šoma ka tša kalafo: mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍⚕' => 'monna wa go šoma ka tša kalafo: mmala wa letlalo wa magareng',
    '👨🏾‍⚕' => 'monna wa go šoma ka tša kalafo: mmala wa letlalo wo moswana wa magareng',
    '👨🏿‍⚕' => 'monna wa go šoma ka tša kalafo: mmala wa letlalo wo moswana',
    '👩🏻‍⚕' => 'mosadi wa go šoma ka tša kalafo: mmala wa letlalo wa go taga',
    '👩🏼‍⚕' => 'mosadi wa go šoma ka tša kalafo: mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍⚕' => 'mosadi wa go šoma ka tša kalafo: mmala wa letlalo wa magareng',
    '👩🏾‍⚕' => 'mosadi wa go šoma ka tša kalafo: mmala wa letlalo wo moswana wa magareng',
    '👩🏿‍⚕' => 'mosadi wa go šoma ka tša kalafo: mmala wa letlalo wo moswana',
    '👨🏻‍🎓' => 'morutwana wa monna: mmala wa letlalo wa go taga',
    '👨🏼‍🎓' => 'morutwana wa monna: mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍🎓' => 'morutwana wa monna: mmala wa letlalo wa magareng',
    '👨🏾‍🎓' => 'morutwana wa monna: mmala wa letlalo wo moswana wa magareng',
    '👨🏿‍🎓' => 'morutwana wa monna: mmala wa letlalo wo moswana',
    '👩🏻‍🎓' => 'morutwana wa mosadi: mmala wa letlalo wa go taga',
    '👩🏼‍🎓' => 'morutwana wa mosadi: mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍🎓' => 'morutwana wa mosadi: mmala wa letlalo wa magareng',
    '👩🏾‍🎓' => 'morutwana wa mosadi: mmala wa letlalo wo moswana wa magareng',
    '👩🏿‍🎓' => 'morutwana wa mosadi: mmala wa letlalo wo moswana',
    '👨🏻‍🏫' => 'morutiši wa monna: mmala wa letlalo wa go taga',
    '👨🏼‍🏫' => 'morutiši wa monna: mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍🏫' => 'morutiši wa monna: mmala wa letlalo wa magareng',
    '👨🏾‍🏫' => 'morutiši wa monna: mmala wa letlalo wo moswana wa magareng',
    '👨🏿‍🏫' => 'morutiši wa monna: mmala wa letlalo wo moswana',
    '👩🏻‍🏫' => 'morutišigadi: mmala wa letlalo wa go taga',
    '👩🏼‍🏫' => 'morutišigadi: mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍🏫' => 'morutišigadi: mmala wa letlalo wa magareng',
    '👩🏾‍🏫' => 'morutišigadi: mmala wa letlalo wo moswana wa magareng',
    '👩🏿‍🏫' => 'morutišigadi: mmala wa letlalo wo moswana',
    '👨🏻‍⚖' => 'monna wa moahlodi: mmala wa letlalo wa go taga',
    '👨🏼‍⚖' => 'monna wa moahlodi: mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍⚖' => 'monna wa moahlodi: mmala wa letlalo wa magareng',
    '👨🏾‍⚖' => 'monna wa moahlodi: mmala wa letlalo wo moswana wa magareng',
    '👨🏿‍⚖' => 'monna wa moahlodi: mmala wa letlalo wo moswana',
    '👩🏻‍⚖' => 'mosadi wa moahlodi: mmala wa letlalo wa go taga',
    '👩🏼‍⚖' => 'mosadi wa moahlodi: mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍⚖' => 'mosadi wa moahlodi: mmala wa letlalo wa magareng',
    '👩🏾‍⚖' => 'mosadi wa moahlodi: mmala wa letlalo wo moswana wa magareng',
    '👩🏿‍⚖' => 'mosadi wa moahlodi: mmala wa letlalo wo moswana',
    '👨🏻‍🌾' => 'monna wa molemi: mmala wa letlalo wa go taga',
    '👨🏼‍🌾' => 'monna wa molemi: mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍🌾' => 'monna wa molemi: mmala wa letlalo wa magareng',
    '👨🏾‍🌾' => 'monna wa molemi: mmala wa letlalo wo moswana wa magareng',
    '👨🏿‍🌾' => 'monna wa molemi: mmala wa letlalo wo moswana',
    '👩🏻‍🌾' => 'molemi wa mosadi: mmala wa letlalo wa go taga',
    '👩🏼‍🌾' => 'molemi wa mosadi: mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍🌾' => 'molemi wa mosadi: mmala wa letlalo wa magareng',
    '👩🏾‍🌾' => 'molemi wa mosadi: mmala wa letlalo wo moswana wa magareng',
    '👩🏿‍🌾' => 'molemi wa mosadi: mmala wa letlalo wo moswana',
    '👨🏻‍🍳' => 'monna wa go apea: mmala wa letlalo wa go taga',
    '👨🏼‍🍳' => 'monna wa go apea: mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍🍳' => 'monna wa go apea: mmala wa letlalo wa magareng',
    '👨🏾‍🍳' => 'monna wa go apea: mmala wa letlalo wo moswana wa magareng',
    '👨🏿‍🍳' => 'monna wa go apea: mmala wa letlalo wo moswana',
    '👩🏻‍🍳' => 'mosadi wa go apea: mmala wa letlalo wa go taga',
    '👩🏼‍🍳' => 'mosadi wa go apea: mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍🍳' => 'mosadi wa go apea: mmala wa letlalo wa magareng',
    '👩🏾‍🍳' => 'mosadi wa go apea: mmala wa letlalo wo moswana wa magareng',
    '👩🏿‍🍳' => 'mosadi wa go apea: mmala wa letlalo wo moswana',
    '👨🏻‍🔧' => 'monna wa mekheniki: mmala wa letlalo wa go taga',
    '👨🏼‍🔧' => 'monna wa mekheniki: mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍🔧' => 'monna wa mekheniki: mmala wa letlalo wa magareng',
    '👨🏾‍🔧' => 'monna wa mekheniki: mmala wa letlalo wo moswana wa magareng',
    '👨🏿‍🔧' => 'monna wa mekheniki: mmala wa letlalo wo moswana',
    '👩🏻‍🔧' => 'mosadi wa go šoma ka mohlagase: mmala wa letlalo wa go taga',
    '👩🏼‍🔧' => 'mosadi wa go šoma ka mohlagase: mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍🔧' => 'mosadi wa go šoma ka mohlagase: mmala wa letlalo wa magareng',
    '👩🏾‍🔧' => 'mosadi wa go šoma ka mohlagase: mmala wa letlalo wo moswana wa magareng',
    '👩🏿‍🔧' => 'mosadi wa go šoma ka mohlagase: mmala wa letlalo wo moswana',
    '👨🏻‍🏭' => 'monna wa go šoma femeng: mmala wa letlalo wa go taga',
    '👨🏼‍🏭' => 'monna wa go šoma femeng: mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍🏭' => 'monna wa go šoma femeng: mmala wa letlalo wa magareng',
    '👨🏾‍🏭' => 'monna wa go šoma femeng: mmala wa letlalo wo moswana wa magareng',
    '👨🏿‍🏭' => 'monna wa go šoma femeng: mmala wa letlalo wo moswana',
    '👩🏻‍🏭' => 'mosadi wa go šoma femeng: mmala wa letlalo wa go taga',
    '👩🏼‍🏭' => 'mosadi wa go šoma femeng: mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍🏭' => 'mosadi wa go šoma femeng: mmala wa letlalo wa magareng',
    '👩🏾‍🏭' => 'mosadi wa go šoma femeng: mmala wa letlalo wo moswana wa magareng',
    '👩🏿‍🏭' => 'mosadi wa go šoma femeng: mmala wa letlalo wo moswana',
    '👨🏻‍💼' => 'monna wa go šoma ofising: mmala wa letlalo wa go taga',
    '👨🏼‍💼' => 'monna wa go šoma ofising: mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍💼' => 'monna wa go šoma ofising: mmala wa letlalo wa magareng',
    '👨🏾‍💼' => 'monna wa go šoma ofising: mmala wa letlalo wo moswana wa magareng',
    '👨🏿‍💼' => 'monna wa go šoma ofising: mmala wa letlalo wo moswana',
    '👩🏻‍💼' => 'mosadi wa go šoma ofising: mmala wa letlalo wa go taga',
    '👩🏼‍💼' => 'mosadi wa go šoma ofising: mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍💼' => 'mosadi wa go šoma ofising: mmala wa letlalo wa magareng',
    '👩🏾‍💼' => 'mosadi wa go šoma ofising: mmala wa letlalo wo moswana wa magareng',
    '👩🏿‍💼' => 'mosadi wa go šoma ofising: mmala wa letlalo wo moswana',
    '👨🏻‍🔬' => 'ramahlale: mmala wa letlalo wa go taga',
    '👨🏼‍🔬' => 'ramahlale: mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍🔬' => 'ramahlale: mmala wa letlalo wa magareng',
    '👨🏾‍🔬' => 'ramahlale: mmala wa letlalo wo moswana wa magareng',
    '👨🏿‍🔬' => 'ramahlale: mmala wa letlalo wo moswana',
    '👩🏻‍🔬' => 'mosadi wa thutamahlale: mmala wa letlalo wa go taga',
    '👩🏼‍🔬' => 'mosadi wa thutamahlale: mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍🔬' => 'mosadi wa thutamahlale: mmala wa letlalo wa magareng',
    '👩🏾‍🔬' => 'mosadi wa thutamahlale: mmala wa letlalo wo moswana wa magareng',
    '👩🏿‍🔬' => 'mosadi wa thutamahlale: mmala wa letlalo wo moswana',
    '👨🏻‍💻' => 'monna wa theknolotši: mmala wa letlalo wa go taga',
    '👨🏼‍💻' => 'monna wa theknolotši: mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍💻' => 'monna wa theknolotši: mmala wa letlalo wa magareng',
    '👨🏾‍💻' => 'monna wa theknolotši: mmala wa letlalo wo moswana wa magareng',
    '👨🏿‍💻' => 'monna wa theknolotši: mmala wa letlalo wo moswana',
    '👩🏻‍💻' => 'mosadi wa theknolotši: mmala wa letlalo wa go taga',
    '👩🏼‍💻' => 'mosadi wa theknolotši: mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍💻' => 'mosadi wa theknolotši: mmala wa letlalo wa magareng',
    '👩🏾‍💻' => 'mosadi wa theknolotši: mmala wa letlalo wo moswana wa magareng',
    '👩🏿‍💻' => 'mosadi wa theknolotši: mmala wa letlalo wo moswana',
    '👨🏻‍🎤' => 'monna wa seopedi: mmala wa letlalo wa go taga',
    '👨🏼‍🎤' => 'monna wa seopedi: mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍🎤' => 'monna wa seopedi: mmala wa letlalo wa magareng',
    '👨🏾‍🎤' => 'monna wa seopedi: mmala wa letlalo wo moswana wa magareng',
    '👨🏿‍🎤' => 'monna wa seopedi: mmala wa letlalo wo moswana',
    '👩🏻‍🎤' => 'mosadi wa seopedi: mmala wa letlalo wa go taga',
    '👩🏼‍🎤' => 'mosadi wa seopedi: mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍🎤' => 'mosadi wa seopedi: mmala wa letlalo wa magareng',
    '👩🏾‍🎤' => 'mosadi wa seopedi: mmala wa letlalo wo moswana wa magareng',
    '👩🏿‍🎤' => 'mosadi wa seopedi: mmala wa letlalo wo moswana',
    '👨🏻‍🎨' => 'monna wa mothadi: mmala wa letlalo wa go taga',
    '👨🏼‍🎨' => 'monna wa mothadi: mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍🎨' => 'monna wa mothadi: mmala wa letlalo wa magareng',
    '👨🏾‍🎨' => 'monna wa mothadi: mmala wa letlalo wo moswana wa magareng',
    '👨🏿‍🎨' => 'monna wa mothadi: mmala wa letlalo wo moswana',
    '👩🏻‍🎨' => 'mosadi wa go thala: mmala wa letlalo wa go taga',
    '👩🏼‍🎨' => 'mosadi wa go thala: mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍🎨' => 'mosadi wa go thala: mmala wa letlalo wa magareng',
    '👩🏾‍🎨' => 'mosadi wa go thala: mmala wa letlalo wo moswana wa magareng',
    '👩🏿‍🎨' => 'mosadi wa go thala: mmala wa letlalo wo moswana',
    '👨🏻‍✈' => 'monna wa mofofiši: mmala wa letlalo wa go taga',
    '👨🏼‍✈' => 'monna wa mofofiši: mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍✈' => 'monna wa mofofiši: mmala wa letlalo wa magareng',
    '👨🏾‍✈' => 'monna wa mofofiši: mmala wa letlalo wo moswana wa magareng',
    '👨🏿‍✈' => 'monna wa mofofiši: mmala wa letlalo wo moswana',
    '👩🏻‍✈' => 'mosadi wa mofofiši: mmala wa letlalo wa go taga',
    '👩🏼‍✈' => 'mosadi wa mofofiši: mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍✈' => 'mosadi wa mofofiši: mmala wa letlalo wa magareng',
    '👩🏾‍✈' => 'mosadi wa mofofiši: mmala wa letlalo wo moswana wa magareng',
    '👩🏿‍✈' => 'mosadi wa mofofiši: mmala wa letlalo wo moswana',
    '👨🏻‍🚀' => 'monna wa go ya lefaufaung: mmala wa letlalo wa go taga',
    '👨🏼‍🚀' => 'monna wa go ya lefaufaung: mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍🚀' => 'monna wa go ya lefaufaung: mmala wa letlalo wa magareng',
    '👨🏾‍🚀' => 'monna wa go ya lefaufaung: mmala wa letlalo wo moswana wa magareng',
    '👨🏿‍🚀' => 'monna wa go ya lefaufaung: mmala wa letlalo wo moswana',
    '👩🏻‍🚀' => 'mosadi wa go ya lefaufaung: mmala wa letlalo wa go taga',
    '👩🏼‍🚀' => 'mosadi wa go ya lefaufaung: mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍🚀' => 'mosadi wa go ya lefaufaung: mmala wa letlalo wa magareng',
    '👩🏾‍🚀' => 'mosadi wa go ya lefaufaung: mmala wa letlalo wo moswana wa magareng',
    '👩🏿‍🚀' => 'mosadi wa go ya lefaufaung: mmala wa letlalo wo moswana',
    '👨🏻‍🚒' => 'monna wa motimamollo: mmala wa letlalo wa go taga',
    '👨🏼‍🚒' => 'monna wa motimamollo: mmala wa letlalo wa go taga wa magareng',
    '👨🏽‍🚒' => 'monna wa motimamollo: mmala wa letlalo wa magareng',
    '👨🏾‍🚒' => 'monna wa motimamollo: mmala wa letlalo wo moswana wa magareng',
    '👨🏿‍🚒' => 'monna wa motimamollo: mmala wa letlalo wo moswana',
    '👩🏻‍🚒' => 'mosadi ditimamello: mmala wa letlalo wa go taga',
    '👩🏼‍🚒' => 'mosadi ditimamello: mmala wa letlalo wa go taga wa magareng',
    '👩🏽‍🚒' => 'mosadi ditimamello: mmala wa letlalo wa magareng',
    '👩🏾‍🚒' => 'mosadi ditimamello: mmala wa letlalo wo moswana wa magareng',
    '👩🏿‍🚒' => 'mosadi ditimamello: mmala wa letlalo wo moswana',
    '👮🏻‍♂' => 'monna wa mohlankedi wa lephodisa: mmala wa letlalo wa go taga',
    '👮🏼‍♂' => 'monna wa mohlankedi wa lephodisa: mmala wa letlalo wa go taga wa magareng',
    '👮🏽‍♂' => 'monna wa mohlankedi wa lephodisa: mmala wa letlalo wa magareng',
    '👮🏾‍♂' => 'monna wa mohlankedi wa lephodisa: mmala wa letlalo wo moswana wa magareng',
    '👮🏿‍♂' => 'monna wa mohlankedi wa lephodisa: mmala wa letlalo wo moswana',
    '👮🏻‍♀' => 'mosadi wa lephodisa: mmala wa letlalo wa go taga',
    '👮🏼‍♀' => 'mosadi wa lephodisa: mmala wa letlalo wa go taga wa magareng',
    '👮🏽‍♀' => 'mosadi wa lephodisa: mmala wa letlalo wa magareng',
    '👮🏾‍♀' => 'mosadi wa lephodisa: mmala wa letlalo wo moswana wa magareng',
    '👮🏿‍♀' => 'mosadi wa lephodisa: mmala wa letlalo wo moswana',
    '🕵🏻‍♂' => 'monna wa lephodisa: mmala wa letlalo wa go taga',
    '🕵🏼‍♂' => 'monna wa lephodisa: mmala wa letlalo wa go taga wa magareng',
    '🕵🏽‍♂' => 'monna wa lephodisa: mmala wa letlalo wa magareng',
    '🕵🏾‍♂' => 'monna wa lephodisa: mmala wa letlalo wo moswana wa magareng',
    '🕵🏿‍♂' => 'monna wa lephodisa: mmala wa letlalo wo moswana',
    '🕵🏻‍♀' => 'lephodisa la mosadi: mmala wa letlalo wa go taga',
    '🕵🏼‍♀' => 'lephodisa la mosadi: mmala wa letlalo wa go taga wa magareng',
    '🕵🏽‍♀' => 'lephodisa la mosadi: mmala wa letlalo wa magareng',
    '🕵🏾‍♀' => 'lephodisa la mosadi: mmala wa letlalo wo moswana wa magareng',
    '🕵🏿‍♀' => 'lephodisa la mosadi: mmala wa letlalo wo moswana',
    '💂🏻‍♂' => 'mohlokomedi wa monna: mmala wa letlalo wa go taga',
    '💂🏼‍♂' => 'mohlokomedi wa monna: mmala wa letlalo wa go taga wa magareng',
    '💂🏽‍♂' => 'mohlokomedi wa monna: mmala wa letlalo wa magareng',
    '💂🏾‍♂' => 'mohlokomedi wa monna: mmala wa letlalo wo moswana wa magareng',
    '💂🏿‍♂' => 'mohlokomedi wa monna: mmala wa letlalo wo moswana',
    '💂🏻‍♀' => 'mohlokomedi wa mosadi: mmala wa letlalo wa go taga',
    '💂🏼‍♀' => 'mohlokomedi wa mosadi: mmala wa letlalo wa go taga wa magareng',
    '💂🏽‍♀' => 'mohlokomedi wa mosadi: mmala wa letlalo wa magareng',
    '💂🏾‍♀' => 'mohlokomedi wa mosadi: mmala wa letlalo wo moswana wa magareng',
    '💂🏿‍♀' => 'mohlokomedi wa mosadi: mmala wa letlalo wo moswana',
    '👷🏻‍♂' => 'monna wa tša kago: mmala wa letlalo wa go taga',
    '👷🏼‍♂' => 'monna wa tša kago: mmala wa letlalo wa go taga wa magareng',
    '👷🏽‍♂' => 'monna wa tša kago: mmala wa letlalo wa magareng',
    '👷🏾‍♂' => 'monna wa tša kago: mmala wa letlalo wo moswana wa magareng',
    '👷🏿‍♂' => 'monna wa tša kago: mmala wa letlalo wo moswana',
    '👷🏻‍♀' => 'mosadi wa tša kago: mmala wa letlalo wa go taga',
    '👷🏼‍♀' => 'mosadi wa tša kago: mmala wa letlalo wa go taga wa magareng',
    '👷🏽‍♀' => 'mosadi wa tša kago: mmala wa letlalo wa magareng',
    '👷🏾‍♀' => 'mosadi wa tša kago: mmala wa letlalo wo moswana wa magareng',
    '👷🏿‍♀' => 'mosadi wa tša kago: mmala wa letlalo wo moswana',
    '👳🏻‍♂' => 'monna yo rwelego thepene: mmala wa letlalo wa go taga',
    '👳🏼‍♂' => 'monna yo rwelego thepene: mmala wa letlalo wa go taga wa magareng',
    '👳🏽‍♂' => 'monna yo rwelego thepene: mmala wa letlalo wa magareng',
    '👳🏾‍♂' => 'monna yo rwelego thepene: mmala wa letlalo wo moswana wa magareng',
    '👳🏿‍♂' => 'monna yo rwelego thepene: mmala wa letlalo wo moswana',
    '👳🏻‍♀' => 'mosadi yo rwelego thepene: mmala wa letlalo wa go taga',
    '👳🏼‍♀' => 'mosadi yo rwelego thepene: mmala wa letlalo wa go taga wa magareng',
    '👳🏽‍♀' => 'mosadi yo rwelego thepene: mmala wa letlalo wa magareng',
    '👳🏾‍♀' => 'mosadi yo rwelego thepene: mmala wa letlalo wo moswana wa magareng',
    '👳🏿‍♀' => 'mosadi yo rwelego thepene: mmala wa letlalo wo moswana',
    '🧙🏻‍♂' => 'monna wa maleatlana: mmala wa letlalo wa go taga',
    '🧙🏼‍♂' => 'monna wa maleatlana: mmala wa letlalo wa go taga wa magareng',
    '🧙🏽‍♂' => 'monna wa maleatlana: mmala wa letlalo wa magareng',
    '🧙🏾‍♂' => 'monna wa maleatlana: mmala wa letlalo wo moswana wa magareng',
    '🧙🏿‍♂' => 'monna wa maleatlana: mmala wa letlalo wo moswana',
    '🧙🏻‍♀' => 'mosadi wa maleatlana: mmala wa letlalo wa go taga',
    '🧙🏼‍♀' => 'mosadi wa maleatlana: mmala wa letlalo wa go taga wa magareng',
    '🧙🏽‍♀' => 'mosadi wa maleatlana: mmala wa letlalo wa magareng',
    '🧙🏾‍♀' => 'mosadi wa maleatlana: mmala wa letlalo wo moswana wa magareng',
    '🧙🏿‍♀' => 'mosadi wa maleatlana: mmala wa letlalo wo moswana',
    '🧚🏻‍♂' => 'monna wa boikgopolelo: mmala wa letlalo wa go taga',
    '🧚🏼‍♂' => 'monna wa boikgopolelo: mmala wa letlalo wa go taga wa magareng',
    '🧚🏽‍♂' => 'monna wa boikgopolelo: mmala wa letlalo wa magareng',
    '🧚🏾‍♂' => 'monna wa boikgopolelo: mmala wa letlalo wo moswana wa magareng',
    '🧚🏿‍♂' => 'monna wa boikgopolelo: mmala wa letlalo wo moswana',
    '🧚🏻‍♀' => 'mosadi wa boikgopolelo: mmala wa letlalo wa go taga',
    '🧚🏼‍♀' => 'mosadi wa boikgopolelo: mmala wa letlalo wa go taga wa magareng',
    '🧚🏽‍♀' => 'mosadi wa boikgopolelo: mmala wa letlalo wa magareng',
    '🧚🏾‍♀' => 'mosadi wa boikgopolelo: mmala wa letlalo wo moswana wa magareng',
    '🧚🏿‍♀' => 'mosadi wa boikgopolelo: mmala wa letlalo wo moswana',
    '🧛🏻‍♂' => 'monna wa bemphaya: mmala wa letlalo wa go taga',
    '🧛🏼‍♂' => 'monna wa bemphaya: mmala wa letlalo wa go taga wa magareng',
    '🧛🏽‍♂' => 'monna wa bemphaya: mmala wa letlalo wa magareng',
    '🧛🏾‍♂' => 'monna wa bemphaya: mmala wa letlalo wo moswana wa magareng',
    '🧛🏿‍♂' => 'monna wa bemphaya: mmala wa letlalo wo moswana',
    '🧛🏻‍♀' => 'mosadi wa bemphaya: mmala wa letlalo wa go taga',
    '🧛🏼‍♀' => 'mosadi wa bemphaya: mmala wa letlalo wa go taga wa magareng',
    '🧛🏽‍♀' => 'mosadi wa bemphaya: mmala wa letlalo wa magareng',
    '🧛🏾‍♀' => 'mosadi wa bemphaya: mmala wa letlalo wo moswana wa magareng',
    '🧛🏿‍♀' => 'mosadi wa bemphaya: mmala wa letlalo wo moswana',
    '🧜🏻‍♂' => 'monna wa ka meetseng: mmala wa letlalo wa go taga',
    '🧜🏼‍♂' => 'monna wa ka meetseng: mmala wa letlalo wa go taga wa magareng',
    '🧜🏽‍♂' => 'monna wa ka meetseng: mmala wa letlalo wa magareng',
    '🧜🏾‍♂' => 'monna wa ka meetseng: mmala wa letlalo wo moswana wa magareng',
    '🧜🏿‍♂' => 'monna wa ka meetseng: mmala wa letlalo wo moswana',
    '🧜🏻‍♀' => 'sephedi sa ka meetseng: mmala wa letlalo wa go taga',
    '🧜🏼‍♀' => 'sephedi sa ka meetseng: mmala wa letlalo wa go taga wa magareng',
    '🧜🏽‍♀' => 'sephedi sa ka meetseng: mmala wa letlalo wa magareng',
    '🧜🏾‍♀' => 'sephedi sa ka meetseng: mmala wa letlalo wo moswana wa magareng',
    '🧜🏿‍♀' => 'sephedi sa ka meetseng: mmala wa letlalo wo moswana',
    '🧝🏻‍♂' => 'monna wa matla a magolo: mmala wa letlalo wa go taga',
    '🧝🏼‍♂' => 'monna wa matla a magolo: mmala wa letlalo wa go taga wa magareng',
    '🧝🏽‍♂' => 'monna wa matla a magolo: mmala wa letlalo wa magareng',
    '🧝🏾‍♂' => 'monna wa matla a magolo: mmala wa letlalo wo moswana wa magareng',
    '🧝🏿‍♂' => 'monna wa matla a magolo: mmala wa letlalo wo moswana',
    '🧝🏻‍♀' => 'mosadi wa matla a magolo: mmala wa letlalo wa go taga',
    '🧝🏼‍♀' => 'mosadi wa matla a magolo: mmala wa letlalo wa go taga wa magareng',
    '🧝🏽‍♀' => 'mosadi wa matla a magolo: mmala wa letlalo wa magareng',
    '🧝🏾‍♀' => 'mosadi wa matla a magolo: mmala wa letlalo wo moswana wa magareng',
    '🧝🏿‍♀' => 'mosadi wa matla a magolo: mmala wa letlalo wo moswana',
    '💆🏻‍♂' => 'monna o a masatšwa: mmala wa letlalo wa go taga',
    '💆🏼‍♂' => 'monna o a masatšwa: mmala wa letlalo wa go taga wa magareng',
    '💆🏽‍♂' => 'monna o a masatšwa: mmala wa letlalo wa magareng',
    '💆🏾‍♂' => 'monna o a masatšwa: mmala wa letlalo wo moswana wa magareng',
    '💆🏿‍♂' => 'monna o a masatšwa: mmala wa letlalo wo moswana',
    '💆🏻‍♀' => 'mosadi o a masatšwa: mmala wa letlalo wa go taga',
    '💆🏼‍♀' => 'mosadi o a masatšwa: mmala wa letlalo wa go taga wa magareng',
    '💆🏽‍♀' => 'mosadi o a masatšwa: mmala wa letlalo wa magareng',
    '💆🏾‍♀' => 'mosadi o a masatšwa: mmala wa letlalo wo moswana wa magareng',
    '💆🏿‍♀' => 'mosadi o a masatšwa: mmala wa letlalo wo moswana',
    '💇🏻‍♂' => 'monna yo a kotwago moriri: mmala wa letlalo wa go taga',
    '💇🏼‍♂' => 'monna yo a kotwago moriri: mmala wa letlalo wa go taga wa magareng',
    '💇🏽‍♂' => 'monna yo a kotwago moriri: mmala wa letlalo wa magareng',
    '💇🏾‍♂' => 'monna yo a kotwago moriri: mmala wa letlalo wo moswana wa magareng',
    '💇🏿‍♂' => 'monna yo a kotwago moriri: mmala wa letlalo wo moswana',
    '💇🏻‍♀' => 'mosadi yo a kotwago moriri: mmala wa letlalo wa go taga',
    '💇🏼‍♀' => 'mosadi yo a kotwago moriri: mmala wa letlalo wa go taga wa magareng',
    '💇🏽‍♀' => 'mosadi yo a kotwago moriri: mmala wa letlalo wa magareng',
    '💇🏾‍♀' => 'mosadi yo a kotwago moriri: mmala wa letlalo wo moswana wa magareng',
    '💇🏿‍♀' => 'mosadi yo a kotwago moriri: mmala wa letlalo wo moswana',
    '🚶🏻‍♂' => 'monna o a sepela: mmala wa letlalo wa go taga',
    '🚶🏼‍♂' => 'monna o a sepela: mmala wa letlalo wa go taga wa magareng',
    '🚶🏽‍♂' => 'monna o a sepela: mmala wa letlalo wa magareng',
    '🚶🏾‍♂' => 'monna o a sepela: mmala wa letlalo wo moswana wa magareng',
    '🚶🏿‍♂' => 'monna o a sepela: mmala wa letlalo wo moswana',
    '🚶🏻‍♀' => 'mosadi o a sepela: mmala wa letlalo wa go taga',
    '🚶🏼‍♀' => 'mosadi o a sepela: mmala wa letlalo wa go taga wa magareng',
    '🚶🏽‍♀' => 'mosadi o a sepela: mmala wa letlalo wa magareng',
    '🚶🏾‍♀' => 'mosadi o a sepela: mmala wa letlalo wo moswana wa magareng',
    '🚶🏿‍♀' => 'mosadi o a sepela: mmala wa letlalo wo moswana',
    '🏃🏻‍♂' => 'monna o a kitima: mmala wa letlalo wa go taga',
    '🏃🏼‍♂' => 'monna o a kitima: mmala wa letlalo wa go taga wa magareng',
    '🏃🏽‍♂' => 'monna o a kitima: mmala wa letlalo wa magareng',
    '🏃🏾‍♂' => 'monna o a kitima: mmala wa letlalo wo moswana wa magareng',
    '🏃🏿‍♂' => 'monna o a kitima: mmala wa letlalo wo moswana',
    '🏃🏻‍♀' => 'mosadi o a kitima: mmala wa letlalo wa go taga',
    '🏃🏼‍♀' => 'mosadi o a kitima: mmala wa letlalo wa go taga wa magareng',
    '🏃🏽‍♀' => 'mosadi o a kitima: mmala wa letlalo wa magareng',
    '🏃🏾‍♀' => 'mosadi o a kitima: mmala wa letlalo wo moswana wa magareng',
    '🏃🏿‍♀' => 'mosadi o a kitima: mmala wa letlalo wo moswana',
    '👯🏻‍♀' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa go taga',
    '👯🏼‍♀' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa go taga wa magareng',
    '👯🏽‍♀' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa magareng',
    '👯🏾‍♀' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wo moswana wa magareng',
    '👯🏿‍♀' => 'mosadi wa ditsebe tša mmutla o moletlong: mmala wa letlalo wo moswana',
    '👯🏻‍♂' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa go taga',
    '👯🏼‍♂' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa go taga wa magareng',
    '👯🏽‍♂' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wa magareng',
    '👯🏾‍♂' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wo moswana wa magareng',
    '👯🏿‍♂' => 'monna wa ditsebe tša mmutla o moletlong: mmala wa letlalo wo moswana',
    '🧖🏻‍♂' => 'monna ka phaphošing ya moya wa go fiša: mmala wa letlalo wa go taga',
    '🧖🏼‍♂' => 'monna ka phaphošing ya moya wa go fiša: mmala wa letlalo wa go taga wa magareng',
    '🧖🏽‍♂' => 'monna ka phaphošing ya moya wa go fiša: mmala wa letlalo wa magareng',
    '🧖🏾‍♂' => 'monna ka phaphošing ya moya wa go fiša: mmala wa letlalo wo moswana wa magareng',
    '🧖🏿‍♂' => 'monna ka phaphošing ya moya wa go fiša: mmala wa letlalo wo moswana',
    '🧖🏻‍♀' => 'mosadi ka phaphošing ya moya wa go fiša: mmala wa letlalo wa go taga',
    '🧖🏼‍♀' => 'mosadi ka phaphošing ya moya wa go fiša: mmala wa letlalo wa go taga wa magareng',
    '🧖🏽‍♀' => 'mosadi ka phaphošing ya moya wa go fiša: mmala wa letlalo wa magareng',
    '🧖🏾‍♀' => 'mosadi ka phaphošing ya moya wa go fiša: mmala wa letlalo wo moswana wa magareng',
    '🧖🏿‍♀' => 'mosadi ka phaphošing ya moya wa go fiša: mmala wa letlalo wo moswana',
    '🧗🏻‍♂' => 'monna o a namela: mmala wa letlalo wa go taga',
    '🧗🏼‍♂' => 'monna o a namela: mmala wa letlalo wa go taga wa magareng',
    '🧗🏽‍♂' => 'monna o a namela: mmala wa letlalo wa magareng',
    '🧗🏾‍♂' => 'monna o a namela: mmala wa letlalo wo moswana wa magareng',
    '🧗🏿‍♂' => 'monna o a namela: mmala wa letlalo wo moswana',
    '🧗🏻‍♀' => 'mosadi o a namela: mmala wa letlalo wa go taga',
    '🧗🏼‍♀' => 'mosadi o a namela: mmala wa letlalo wa go taga wa magareng',
    '🧗🏽‍♀' => 'mosadi o a namela: mmala wa letlalo wa magareng',
    '🧗🏾‍♀' => 'mosadi o a namela: mmala wa letlalo wo moswana wa magareng',
    '🧗🏿‍♀' => 'mosadi o a namela: mmala wa letlalo wo moswana',
    '🏌🏻‍♂' => 'monna o bapala kolofo: mmala wa letlalo wa go taga',
    '🏌🏼‍♂' => 'monna o bapala kolofo: mmala wa letlalo wa go taga wa magareng',
    '🏌🏽‍♂' => 'monna o bapala kolofo: mmala wa letlalo wa magareng',
    '🏌🏾‍♂' => 'monna o bapala kolofo: mmala wa letlalo wo moswana wa magareng',
    '🏌🏿‍♂' => 'monna o bapala kolofo: mmala wa letlalo wo moswana',
    '🏌🏻‍♀' => 'mosadi o bapala kolofo: mmala wa letlalo wa go taga',
    '🏌🏼‍♀' => 'mosadi o bapala kolofo: mmala wa letlalo wa go taga wa magareng',
    '🏌🏽‍♀' => 'mosadi o bapala kolofo: mmala wa letlalo wa magareng',
    '🏌🏾‍♀' => 'mosadi o bapala kolofo: mmala wa letlalo wo moswana wa magareng',
    '🏌🏿‍♀' => 'mosadi o bapala kolofo: mmala wa letlalo wo moswana',
    '🏄🏻‍♂' => 'monna o sesa lewatleng: mmala wa letlalo wa go taga',
    '🏄🏼‍♂' => 'monna o sesa lewatleng: mmala wa letlalo wa go taga wa magareng',
    '🏄🏽‍♂' => 'monna o sesa lewatleng: mmala wa letlalo wa magareng',
    '🏄🏾‍♂' => 'monna o sesa lewatleng: mmala wa letlalo wo moswana wa magareng',
    '🏄🏿‍♂' => 'monna o sesa lewatleng: mmala wa letlalo wo moswana',
    '🏄🏻‍♀' => 'mosadi o sesa lewatleng: mmala wa letlalo wa go taga',
    '🏄🏼‍♀' => 'mosadi o sesa lewatleng: mmala wa letlalo wa go taga wa magareng',
    '🏄🏽‍♀' => 'mosadi o sesa lewatleng: mmala wa letlalo wa magareng',
    '🏄🏾‍♀' => 'mosadi o sesa lewatleng: mmala wa letlalo wo moswana wa magareng',
    '🏄🏿‍♀' => 'mosadi o sesa lewatleng: mmala wa letlalo wo moswana',
    '🚣🏻‍♂' => 'monna o otlela seketswana: mmala wa letlalo wa go taga',
    '🚣🏼‍♂' => 'monna o otlela seketswana: mmala wa letlalo wa go taga wa magareng',
    '🚣🏽‍♂' => 'monna o otlela seketswana: mmala wa letlalo wa magareng',
    '🚣🏾‍♂' => 'monna o otlela seketswana: mmala wa letlalo wo moswana wa magareng',
    '🚣🏿‍♂' => 'monna o otlela seketswana: mmala wa letlalo wo moswana',
    '🚣🏻‍♀' => 'mosadi o otlela seketswana: mmala wa letlalo wa go taga',
    '🚣🏼‍♀' => 'mosadi o otlela seketswana: mmala wa letlalo wa go taga wa magareng',
    '🚣🏽‍♀' => 'mosadi o otlela seketswana: mmala wa letlalo wa magareng',
    '🚣🏾‍♀' => 'mosadi o otlela seketswana: mmala wa letlalo wo moswana wa magareng',
    '🚣🏿‍♀' => 'mosadi o otlela seketswana: mmala wa letlalo wo moswana',
    '🏊🏻‍♂' => 'monna o a rutha: mmala wa letlalo wa go taga',
    '🏊🏼‍♂' => 'monna o a rutha: mmala wa letlalo wa go taga wa magareng',
    '🏊🏽‍♂' => 'monna o a rutha: mmala wa letlalo wa magareng',
    '🏊🏾‍♂' => 'monna o a rutha: mmala wa letlalo wo moswana wa magareng',
    '🏊🏿‍♂' => 'monna o a rutha: mmala wa letlalo wo moswana',
    '🏊🏻‍♀' => 'mosadi o a rutha: mmala wa letlalo wa go taga',
    '🏊🏼‍♀' => 'mosadi o a rutha: mmala wa letlalo wa go taga wa magareng',
    '🏊🏽‍♀' => 'mosadi o a rutha: mmala wa letlalo wa magareng',
    '🏊🏾‍♀' => 'mosadi o a rutha: mmala wa letlalo wo moswana wa magareng',
    '🏊🏿‍♀' => 'mosadi o a rutha: mmala wa letlalo wo moswana',
    '⛹🏻‍♂' => 'monna o bethantšha polo: mmala wa letlalo wa go taga',
    '⛹🏼‍♂' => 'monna o bethantšha polo: mmala wa letlalo wa go taga wa magareng',
    '⛹🏽‍♂' => 'monna o bethantšha polo: mmala wa letlalo wa magareng',
    '⛹🏾‍♂' => 'monna o bethantšha polo: mmala wa letlalo wo moswana wa magareng',
    '⛹🏿‍♂' => 'monna o bethantšha polo: mmala wa letlalo wo moswana',
    '⛹🏻‍♀' => 'mosadi o bethantšha polo: mmala wa letlalo wa go taga',
    '⛹🏼‍♀' => 'mosadi o bethantšha polo: mmala wa letlalo wa go taga wa magareng',
    '⛹🏽‍♀' => 'mosadi o bethantšha polo: mmala wa letlalo wa magareng',
    '⛹🏾‍♀' => 'mosadi o bethantšha polo: mmala wa letlalo wo moswana wa magareng',
    '⛹🏿‍♀' => 'mosadi o bethantšha polo: mmala wa letlalo wo moswana',
    '🏋🏻‍♂' => 'monna o kuka boima: mmala wa letlalo wa go taga',
    '🏋🏼‍♂' => 'monna o kuka boima: mmala wa letlalo wa go taga wa magareng',
    '🏋🏽‍♂' => 'monna o kuka boima: mmala wa letlalo wa magareng',
    '🏋🏾‍♂' => 'monna o kuka boima: mmala wa letlalo wo moswana wa magareng',
    '🏋🏿‍♂' => 'monna o kuka boima: mmala wa letlalo wo moswana',
    '🏋🏻‍♀' => 'mosadi o kuka boima: mmala wa letlalo wa go taga',
    '🏋🏼‍♀' => 'mosadi o kuka boima: mmala wa letlalo wa go taga wa magareng',
    '🏋🏽‍♀' => 'mosadi o kuka boima: mmala wa letlalo wa magareng',
    '🏋🏾‍♀' => 'mosadi o kuka boima: mmala wa letlalo wo moswana wa magareng',
    '🏋🏿‍♀' => 'mosadi o kuka boima: mmala wa letlalo wo moswana',
    '🚴🏻‍♂' => 'monna o nametše paesekela: mmala wa letlalo wa go taga',
    '🚴🏼‍♂' => 'monna o nametše paesekela: mmala wa letlalo wa go taga wa magareng',
    '🚴🏽‍♂' => 'monna o nametše paesekela: mmala wa letlalo wa magareng',
    '🚴🏾‍♂' => 'monna o nametše paesekela: mmala wa letlalo wo moswana wa magareng',
    '🚴🏿‍♂' => 'monna o nametše paesekela: mmala wa letlalo wo moswana',
    '🚴🏻‍♀' => 'mosadi o nametše paesekela: mmala wa letlalo wa go taga',
    '🚴🏼‍♀' => 'mosadi o nametše paesekela: mmala wa letlalo wa go taga wa magareng',
    '🚴🏽‍♀' => 'mosadi o nametše paesekela: mmala wa letlalo wa magareng',
    '🚴🏾‍♀' => 'mosadi o nametše paesekela: mmala wa letlalo wo moswana wa magareng',
    '🚴🏿‍♀' => 'mosadi o nametše paesekela: mmala wa letlalo wo moswana',
    '🚵🏻‍♂' => 'monna ka paesekela thabeng: mmala wa letlalo wa go taga',
    '🚵🏼‍♂' => 'monna ka paesekela thabeng: mmala wa letlalo wa go taga wa magareng',
    '🚵🏽‍♂' => 'monna ka paesekela thabeng: mmala wa letlalo wa magareng',
    '🚵🏾‍♂' => 'monna ka paesekela thabeng: mmala wa letlalo wo moswana wa magareng',
    '🚵🏿‍♂' => 'monna ka paesekela thabeng: mmala wa letlalo wo moswana',
    '🚵🏻‍♀' => 'mosadi ka paesekela thabeng: mmala wa letlalo wa go taga',
    '🚵🏼‍♀' => 'mosadi ka paesekela thabeng: mmala wa letlalo wa go taga wa magareng',
    '🚵🏽‍♀' => 'mosadi ka paesekela thabeng: mmala wa letlalo wa magareng',
    '🚵🏾‍♀' => 'mosadi ka paesekela thabeng: mmala wa letlalo wo moswana wa magareng',
    '🚵🏿‍♀' => 'mosadi ka paesekela thabeng: mmala wa letlalo wo moswana',
    '🤸🏻‍♂' => 'monna o a khethawila: mmala wa letlalo wa go taga',
    '🤸🏼‍♂' => 'monna o a khethawila: mmala wa letlalo wa go taga wa magareng',
    '🤸🏽‍♂' => 'monna o a khethawila: mmala wa letlalo wa magareng',
    '🤸🏾‍♂' => 'monna o a khethawila: mmala wa letlalo wo moswana wa magareng',
    '🤸🏿‍♂' => 'monna o a khethawila: mmala wa letlalo wo moswana',
    '🤸🏻‍♀' => 'mosadi o a khethawila: mmala wa letlalo wa go taga',
    '🤸🏼‍♀' => 'mosadi o a khethawila: mmala wa letlalo wa go taga wa magareng',
    '🤸🏽‍♀' => 'mosadi o a khethawila: mmala wa letlalo wa magareng',
    '🤸🏾‍♀' => 'mosadi o a khethawila: mmala wa letlalo wo moswana wa magareng',
    '🤸🏿‍♀' => 'mosadi o a khethawila: mmala wa letlalo wo moswana',
    '🤼🏻‍♀' => 'mosadi o lwa reseling: mmala wa letlalo wa go taga',
    '🤼🏼‍♀' => 'mosadi o lwa reseling: mmala wa letlalo wa go taga wa magareng',
    '🤼🏽‍♀' => 'mosadi o lwa reseling: mmala wa letlalo wa magareng',
    '🤼🏾‍♀' => 'mosadi o lwa reseling: mmala wa letlalo wo moswana wa magareng',
    '🤼🏿‍♀' => 'mosadi o lwa reseling: mmala wa letlalo wo moswana',
    '🤼🏻‍♂' => 'banna ba a resela: mmala wa letlalo wa go taga',
    '🤼🏼‍♂' => 'banna ba a resela: mmala wa letlalo wa go taga wa magareng',
    '🤼🏽‍♂' => 'banna ba a resela: mmala wa letlalo wa magareng',
    '🤼🏾‍♂' => 'banna ba a resela: mmala wa letlalo wo moswana wa magareng',
    '🤼🏿‍♂' => 'banna ba a resela: mmala wa letlalo wo moswana',
    '🤽🏻‍♂' => 'monna o bapala polo ya ka meetseng: mmala wa letlalo wa go taga',
    '🤽🏼‍♂' => 'monna o bapala polo ya ka meetseng: mmala wa letlalo wa go taga wa magareng',
    '🤽🏽‍♂' => 'monna o bapala polo ya ka meetseng: mmala wa letlalo wa magareng',
    '🤽🏾‍♂' => 'monna o bapala polo ya ka meetseng: mmala wa letlalo wo moswana wa magareng',
    '🤽🏿‍♂' => 'monna o bapala polo ya ka meetseng: mmala wa letlalo wo moswana',
    '🤽🏻‍♀' => 'mosadi o bapala polo ya ka meetseng: mmala wa letlalo wa go taga',
    '🤽🏼‍♀' => 'mosadi o bapala polo ya ka meetseng: mmala wa letlalo wa go taga wa magareng',
    '🤽🏽‍♀' => 'mosadi o bapala polo ya ka meetseng: mmala wa letlalo wa magareng',
    '🤽🏾‍♀' => 'mosadi o bapala polo ya ka meetseng: mmala wa letlalo wo moswana wa magareng',
    '🤽🏿‍♀' => 'mosadi o bapala polo ya ka meetseng: mmala wa letlalo wo moswana',
    '🤾🏻‍♂' => 'monna o bapa polo ya diatla: mmala wa letlalo wa go taga',
    '🤾🏼‍♂' => 'monna o bapa polo ya diatla: mmala wa letlalo wa go taga wa magareng',
    '🤾🏽‍♂' => 'monna o bapa polo ya diatla: mmala wa letlalo wa magareng',
    '🤾🏾‍♂' => 'monna o bapa polo ya diatla: mmala wa letlalo wo moswana wa magareng',
    '🤾🏿‍♂' => 'monna o bapa polo ya diatla: mmala wa letlalo wo moswana',
    '🤾🏻‍♀' => 'mosadi o bapala polo ya diatla: mmala wa letlalo wa go taga',
    '🤾🏼‍♀' => 'mosadi o bapala polo ya diatla: mmala wa letlalo wa go taga wa magareng',
    '🤾🏽‍♀' => 'mosadi o bapala polo ya diatla: mmala wa letlalo wa magareng',
    '🤾🏾‍♀' => 'mosadi o bapala polo ya diatla: mmala wa letlalo wo moswana wa magareng',
    '🤾🏿‍♀' => 'mosadi o bapala polo ya diatla: mmala wa letlalo wo moswana',
    '🤹🏻‍♂' => 'monna o dira mediro e mentši: mmala wa letlalo wa go taga',
    '🤹🏼‍♂' => 'monna o dira mediro e mentši: mmala wa letlalo wa go taga wa magareng',
    '🤹🏽‍♂' => 'monna o dira mediro e mentši: mmala wa letlalo wa magareng',
    '🤹🏾‍♂' => 'monna o dira mediro e mentši: mmala wa letlalo wo moswana wa magareng',
    '🤹🏿‍♂' => 'monna o dira mediro e mentši: mmala wa letlalo wo moswana',
    '🤹🏻‍♀' => 'mosadi o swara mo le mola: mmala wa letlalo wa go taga',
    '🤹🏼‍♀' => 'mosadi o swara mo le mola: mmala wa letlalo wa go taga wa magareng',
    '🤹🏽‍♀' => 'mosadi o swara mo le mola: mmala wa letlalo wa magareng',
    '🤹🏾‍♀' => 'mosadi o swara mo le mola: mmala wa letlalo wo moswana wa magareng',
    '🤹🏿‍♀' => 'mosadi o swara mo le mola: mmala wa letlalo wo moswana',
    '🧘🏻‍♂' => 'monna a phuthile maoto: mmala wa letlalo wa go taga',
    '🧘🏼‍♂' => 'monna a phuthile maoto: mmala wa letlalo wa go taga wa magareng',
    '🧘🏽‍♂' => 'monna a phuthile maoto: mmala wa letlalo wa magareng',
    '🧘🏾‍♂' => 'monna a phuthile maoto: mmala wa letlalo wo moswana wa magareng',
    '🧘🏿‍♂' => 'monna a phuthile maoto: mmala wa letlalo wo moswana',
    '🧘🏻‍♀' => 'mosadi a phuthile maoto: mmala wa letlalo wa go taga',
    '🧘🏼‍♀' => 'mosadi a phuthile maoto: mmala wa letlalo wa go taga wa magareng',
    '🧘🏽‍♀' => 'mosadi a phuthile maoto: mmala wa letlalo wa magareng',
    '🧘🏾‍♀' => 'mosadi a phuthile maoto: mmala wa letlalo wo moswana wa magareng',
    '🧘🏿‍♀' => 'mosadi a phuthile maoto: mmala wa letlalo wo moswana',
    '👨‍👦' => 'lapa: monna, mošemane',
    '👨‍👧' => 'lapa: monna, mosetsana',
    '👩‍👦' => 'lapa: mosadi, mošemane',
    '👩‍👧' => 'lapa: mosadi, mosetsana',
    '👁‍🗨' => 'leihlo ka gare ga pudulapolelo',
    '👱‍♂' => 'monna wa meriri ya mesehla',
    '👱‍♀' => 'mosadi wa meriri ye mesehla',
    '🙍‍♂' => 'monna yo a sa dumelego',
    '🙍‍♀' => 'mosadi yo a sa dumelego ka ditho',
    '🙎‍♂' => 'monna yo a ipopilego molomo',
    '🙎‍♀' => 'mosadi yo a ipopilego molomo',
    '🙅‍♂' => 'monna o re AOWA ka ditho',
    '🙅‍♀' => 'mosadi o re AOWA ka ditho',
    '🙆‍♂' => 'monna o re GO LOKILE',
    '🙆‍♀' => 'mosadi o re GO LOKILE',
    '💁‍♂' => 'monna yo a kgwathago seatla',
    '💁‍♀' => 'mosadi o kgwatha ka seatla',
    '🙋‍♂' => 'monna o emiša seatla',
    '🙋‍♀' => 'mosadi o emiša seatla',
    '🙇‍♂' => 'monna o a inama',
    '🙇‍♀' => 'mosadi o a inama',
    '🤦‍♂' => 'monna o beile seatla sefahlegong',
    '🤦‍♀' => 'mosadi a beile bokagare bja seatla',
    '🤷‍♂' => 'monna o emiša magetla',
    '🤷‍♀' => 'mosadi o emiša magetla',
    '👨‍⚕' => 'monna wa go šoma ka tša kalafo',
    '👩‍⚕' => 'mosadi wa go šoma ka tša kalafo',
    '👨‍🎓' => 'morutwana wa monna',
    '👩‍🎓' => 'morutwana wa mosadi',
    '👨‍🏫' => 'morutiši wa monna',
    '👩‍🏫' => 'morutišigadi',
    '👨‍⚖' => 'monna wa moahlodi',
    '👩‍⚖' => 'mosadi wa moahlodi',
    '👨‍🌾' => 'monna wa molemi',
    '👩‍🌾' => 'molemi wa mosadi',
    '👨‍🍳' => 'monna wa go apea',
    '👩‍🍳' => 'mosadi wa go apea',
    '👨‍🔧' => 'monna wa mekheniki',
    '👩‍🔧' => 'mosadi wa go šoma ka mohlagase',
    '👨‍🏭' => 'monna wa go šoma femeng',
    '👩‍🏭' => 'mosadi wa go šoma femeng',
    '👨‍💼' => 'monna wa go šoma ofising',
    '👩‍💼' => 'mosadi wa go šoma ofising',
    '👨‍🔬' => 'ramahlale',
    '👩‍🔬' => 'mosadi wa thutamahlale',
    '👨‍💻' => 'monna wa theknolotši',
    '👩‍💻' => 'mosadi wa theknolotši',
    '👨‍🎤' => 'monna wa seopedi',
    '👩‍🎤' => 'mosadi wa seopedi',
    '👨‍🎨' => 'monna wa mothadi',
    '👩‍🎨' => 'mosadi wa go thala',
    '👨‍✈' => 'monna wa mofofiši',
    '👩‍✈' => 'mosadi wa mofofiši',
    '👨‍🚀' => 'monna wa go ya lefaufaung',
    '👩‍🚀' => 'mosadi wa go ya lefaufaung',
    '👨‍🚒' => 'monna wa motimamollo',
    '👩‍🚒' => 'mosadi ditimamello',
    '👮‍♂' => 'monna wa mohlankedi wa lephodisa',
    '👮‍♀' => 'mosadi wa lephodisa',
    '🕵‍♂' => 'monna wa lephodisa',
    '🕵‍♀' => 'lephodisa la mosadi',
    '💂‍♂' => 'mohlokomedi wa monna',
    '💂‍♀' => 'mohlokomedi wa mosadi',
    '👷‍♂' => 'monna wa tša kago',
    '👷‍♀' => 'mosadi wa tša kago',
    '👳‍♂' => 'monna yo rwelego thepene',
    '👳‍♀' => 'mosadi yo rwelego thepene',
    '🧙‍♂' => 'monna wa maleatlana',
    '🧙‍♀' => 'mosadi wa maleatlana',
    '🧚‍♂' => 'monna wa boikgopolelo',
    '🧚‍♀' => 'mosadi wa boikgopolelo',
    '🧛‍♂' => 'monna wa bemphaya',
    '🧛‍♀' => 'mosadi wa bemphaya',
    '🧜‍♂' => 'monna wa ka meetseng',
    '🧜‍♀' => 'sephedi sa ka meetseng',
    '🧝‍♂' => 'monna wa matla a magolo',
    '🧝‍♀' => 'mosadi wa matla a magolo',
    '🧞‍♂' => 'monna wa genie',
    '🧞‍♀' => 'mosadi wa genie',
    '🧟‍♂' => 'monna wa setlotlwane',
    '🧟‍♀' => 'mosadi wa setlotlwane',
    '💆‍♂' => 'monna o a masatšwa',
    '💆‍♀' => 'mosadi o a masatšwa',
    '💇‍♂' => 'monna yo a kotwago moriri',
    '💇‍♀' => 'mosadi yo a kotwago moriri',
    '🚶‍♂' => 'monna o a sepela',
    '🚶‍♀' => 'mosadi o a sepela',
    '🏃‍♂' => 'monna o a kitima',
    '🏃‍♀' => 'mosadi o a kitima',
    '👯‍♂' => 'monna wa ditsebe tša mmutla o moletlong',
    '👯‍♀' => 'mosadi wa ditsebe tša mmutla o moletlong',
    '🧖‍♂' => 'monna ka phaphošing ya moya wa go fiša',
    '🧖‍♀' => 'mosadi ka phaphošing ya moya wa go fiša',
    '🧗‍♂' => 'monna o a namela',
    '🧗‍♀' => 'mosadi o a namela',
    '🏌‍♂' => 'monna o bapala kolofo',
    '🏌‍♀' => 'mosadi o bapala kolofo',
    '🏄‍♂' => 'monna o sesa lewatleng',
    '🏄‍♀' => 'mosadi o sesa lewatleng',
    '🚣‍♂' => 'monna o otlela seketswana',
    '🚣‍♀' => 'mosadi o otlela seketswana',
    '🏊‍♂' => 'monna o a rutha',
    '🏊‍♀' => 'mosadi o a rutha',
    '⛹‍♂' => 'monna o bethantšha polo',
    '⛹‍♀' => 'mosadi o bethantšha polo',
    '🏋‍♂' => 'monna o kuka boima',
    '🏋‍♀' => 'mosadi o kuka boima',
    '🚴‍♂' => 'monna o nametše paesekela',
    '🚴‍♀' => 'mosadi o nametše paesekela',
    '🚵‍♂' => 'monna ka paesekela thabeng',
    '🚵‍♀' => 'mosadi ka paesekela thabeng',
    '🤸‍♂' => 'monna o a khethawila',
    '🤸‍♀' => 'mosadi o a khethawila',
    '🤼‍♂' => 'banna ba a resela',
    '🤼‍♀' => 'mosadi o lwa reseling',
    '🤽‍♂' => 'monna o bapala polo ya ka meetseng',
    '🤽‍♀' => 'mosadi o bapala polo ya ka meetseng',
    '🤾‍♂' => 'monna o bapa polo ya diatla',
    '🤾‍♀' => 'mosadi o bapala polo ya diatla',
    '🤹‍♂' => 'monna o dira mediro e mentši',
    '🤹‍♀' => 'mosadi o swara mo le mola',
    '🧘‍♂' => 'monna a phuthile maoto',
    '🧘‍♀' => 'mosadi a phuthile maoto',
    '🏳‍🌈' => 'folaga ya molalatladi',
    '👋🏻' => 'letsogo le dumedišago: mmala wa letlalo wa go taga',
    '👋🏼' => 'letsogo le dumedišago: mmala wa letlalo wa go taga wa magareng',
    '👋🏽' => 'letsogo le dumedišago: mmala wa letlalo wa magareng',
    '👋🏾' => 'letsogo le dumedišago: mmala wa letlalo wo moswana wa magareng',
    '👋🏿' => 'letsogo le dumedišago: mmala wa letlalo wo moswana',
    '🤚🏻' => 'letsogo le emišeditšwego morago: mmala wa letlalo wa go taga',
    '🤚🏼' => 'letsogo le emišeditšwego morago: mmala wa letlalo wa go taga wa magareng',
    '🤚🏽' => 'letsogo le emišeditšwego morago: mmala wa letlalo wa magareng',
    '🤚🏾' => 'letsogo le emišeditšwego morago: mmala wa letlalo wo moswana wa magareng',
    '🤚🏿' => 'letsogo le emišeditšwego morago: mmala wa letlalo wo moswana',
    '🖐🏻' => 'go emiša letsogo o arogantše menwana: mmala wa letlalo wa go taga',
    '🖐🏼' => 'go emiša letsogo o arogantše menwana: mmala wa letlalo wa go taga wa magareng',
    '🖐🏽' => 'go emiša letsogo o arogantše menwana: mmala wa letlalo wa magareng',
    '🖐🏾' => 'go emiša letsogo o arogantše menwana: mmala wa letlalo wo moswana wa magareng',
    '🖐🏿' => 'go emiša letsogo o arogantše menwana: mmala wa letlalo wo moswana',
    '✋🏻' => 'letsogo le išitšwego godimo: mmala wa letlalo wa go taga',
    '✋🏼' => 'letsogo le išitšwego godimo: mmala wa letlalo wa go taga wa magareng',
    '✋🏽' => 'letsogo le išitšwego godimo: mmala wa letlalo wa magareng',
    '✋🏾' => 'letsogo le išitšwego godimo: mmala wa letlalo wo moswana wa magareng',
    '✋🏿' => 'letsogo le išitšwego godimo: mmala wa letlalo wo moswana',
    '🖖🏻' => 'go dumediša ga vulcan: mmala wa letlalo wa go taga',
    '🖖🏼' => 'go dumediša ga vulcan: mmala wa letlalo wa go taga wa magareng',
    '🖖🏽' => 'go dumediša ga vulcan: mmala wa letlalo wa magareng',
    '🖖🏾' => 'go dumediša ga vulcan: mmala wa letlalo wo moswana wa magareng',
    '🖖🏿' => 'go dumediša ga vulcan: mmala wa letlalo wo moswana',
    '👌🏻' => 'letsogo le le rego GO LOKILE: mmala wa letlalo wa go taga',
    '👌🏼' => 'letsogo le le rego GO LOKILE: mmala wa letlalo wa go taga wa magareng',
    '👌🏽' => 'letsogo le le rego GO LOKILE: mmala wa letlalo wa magareng',
    '👌🏾' => 'letsogo le le rego GO LOKILE: mmala wa letlalo wo moswana wa magareng',
    '👌🏿' => 'letsogo le le rego GO LOKILE: mmala wa letlalo wo moswana',
    '✌🏻' => 'seatla la go thopa: mmala wa letlalo wa go taga',
    '✌🏼' => 'seatla la go thopa: mmala wa letlalo wa go taga wa magareng',
    '✌🏽' => 'seatla la go thopa: mmala wa letlalo wa magareng',
    '✌🏾' => 'seatla la go thopa: mmala wa letlalo wo moswana wa magareng',
    '✌🏿' => 'seatla la go thopa: mmala wa letlalo wo moswana',
    '🤞🏻' => 'menwana e kopanego: mmala wa letlalo wa go taga',
    '🤞🏼' => 'menwana e kopanego: mmala wa letlalo wa go taga wa magareng',
    '🤞🏽' => 'menwana e kopanego: mmala wa letlalo wa magareng',
    '🤞🏾' => 'menwana e kopanego: mmala wa letlalo wo moswana wa magareng',
    '🤞🏿' => 'menwana e kopanego: mmala wa letlalo wo moswana',
    '🤟🏻' => 'leswao la lerato: mmala wa letlalo wa go taga',
    '🤟🏼' => 'leswao la lerato: mmala wa letlalo wa go taga wa magareng',
    '🤟🏽' => 'leswao la lerato: mmala wa letlalo wa magareng',
    '🤟🏾' => 'leswao la lerato: mmala wa letlalo wo moswana wa magareng',
    '🤟🏿' => 'leswao la lerato: mmala wa letlalo wo moswana',
    '🤘🏻' => 'leswao la manaka: mmala wa letlalo wa go taga',
    '🤘🏼' => 'leswao la manaka: mmala wa letlalo wa go taga wa magareng',
    '🤘🏽' => 'leswao la manaka: mmala wa letlalo wa magareng',
    '🤘🏾' => 'leswao la manaka: mmala wa letlalo wo moswana wa magareng',
    '🤘🏿' => 'leswao la manaka: mmala wa letlalo wo moswana',
    '🤙🏻' => 'seatla le bitšago: mmala wa letlalo wa go taga',
    '🤙🏼' => 'seatla le bitšago: mmala wa letlalo wa go taga wa magareng',
    '🤙🏽' => 'seatla le bitšago: mmala wa letlalo wa magareng',
    '🤙🏾' => 'seatla le bitšago: mmala wa letlalo wo moswana wa magareng',
    '🤙🏿' => 'seatla le bitšago: mmala wa letlalo wo moswana',
    '👈🏻' => 'letsogo la ka morago le šupile ka go le letshadi: mmala wa letlalo wa go taga',
    '👈🏼' => 'letsogo la ka morago le šupile ka go le letshadi: mmala wa letlalo wa go taga wa magareng',
    '👈🏽' => 'letsogo la ka morago le šupile ka go le letshadi: mmala wa letlalo wa magareng',
    '👈🏾' => 'letsogo la ka morago le šupile ka go le letshadi: mmala wa letlalo wo moswana wa magareng',
    '👈🏿' => 'letsogo la ka morago le šupile ka go le letshadi: mmala wa letlalo wo moswana',
    '👉🏻' => 'letsogo la ka morago le šupile ka go le letona: mmala wa letlalo wa go taga',
    '👉🏼' => 'letsogo la ka morago le šupile ka go le letona: mmala wa letlalo wa go taga wa magareng',
    '👉🏽' => 'letsogo la ka morago le šupile ka go le letona: mmala wa letlalo wa magareng',
    '👉🏾' => 'letsogo la ka morago le šupile ka go le letona: mmala wa letlalo wo moswana wa magareng',
    '👉🏿' => 'letsogo la ka morago le šupile ka go le letona: mmala wa letlalo wo moswana',
    '👆🏻' => 'letsogo la ka morago le šupile godimo: mmala wa letlalo wa go taga',
    '👆🏼' => 'letsogo la ka morago le šupile godimo: mmala wa letlalo wa go taga wa magareng',
    '👆🏽' => 'letsogo la ka morago le šupile godimo: mmala wa letlalo wa magareng',
    '👆🏾' => 'letsogo la ka morago le šupile godimo: mmala wa letlalo wo moswana wa magareng',
    '👆🏿' => 'letsogo la ka morago le šupile godimo: mmala wa letlalo wo moswana',
    '🖕🏻' => 'monwana wa gare: mmala wa letlalo wa go taga',
    '🖕🏼' => 'monwana wa gare: mmala wa letlalo wa go taga wa magareng',
    '🖕🏽' => 'monwana wa gare: mmala wa letlalo wa magareng',
    '🖕🏾' => 'monwana wa gare: mmala wa letlalo wo moswana wa magareng',
    '🖕🏿' => 'monwana wa gare: mmala wa letlalo wo moswana',
    '👇🏻' => 'letsogo la ka morago le šupile tlase: mmala wa letlalo wa go taga',
    '👇🏼' => 'letsogo la ka morago le šupile tlase: mmala wa letlalo wa go taga wa magareng',
    '👇🏽' => 'letsogo la ka morago le šupile tlase: mmala wa letlalo wa magareng',
    '👇🏾' => 'letsogo la ka morago le šupile tlase: mmala wa letlalo wo moswana wa magareng',
    '👇🏿' => 'letsogo la ka morago le šupile tlase: mmala wa letlalo wo moswana',
    '☝🏻' => 'monwana wa bone o šupile godimo: mmala wa letlalo wa go taga',
    '☝🏼' => 'monwana wa bone o šupile godimo: mmala wa letlalo wa go taga wa magareng',
    '☝🏽' => 'monwana wa bone o šupile godimo: mmala wa letlalo wa magareng',
    '☝🏾' => 'monwana wa bone o šupile godimo: mmala wa letlalo wo moswana wa magareng',
    '☝🏿' => 'monwana wa bone o šupile godimo: mmala wa letlalo wo moswana',
    '👍🏻' => 'monwana o mokoto godimo: mmala wa letlalo wa go taga',
    '👍🏼' => 'monwana o mokoto godimo: mmala wa letlalo wa go taga wa magareng',
    '👍🏽' => 'monwana o mokoto godimo: mmala wa letlalo wa magareng',
    '👍🏾' => 'monwana o mokoto godimo: mmala wa letlalo wo moswana wa magareng',
    '👍🏿' => 'monwana o mokoto godimo: mmala wa letlalo wo moswana',
    '👎🏻' => 'monwana o mogolo tlase: mmala wa letlalo wa go taga',
    '👎🏼' => 'monwana o mogolo tlase: mmala wa letlalo wa go taga wa magareng',
    '👎🏽' => 'monwana o mogolo tlase: mmala wa letlalo wa magareng',
    '👎🏾' => 'monwana o mogolo tlase: mmala wa letlalo wo moswana wa magareng',
    '👎🏿' => 'monwana o mogolo tlase: mmala wa letlalo wo moswana',
    '✊🏻' => 'feise e išitšwego godimo: mmala wa letlalo wa go taga',
    '✊🏼' => 'feise e išitšwego godimo: mmala wa letlalo wa go taga wa magareng',
    '✊🏽' => 'feise e išitšwego godimo: mmala wa letlalo wa magareng',
    '✊🏾' => 'feise e išitšwego godimo: mmala wa letlalo wo moswana wa magareng',
    '✊🏿' => 'feise e išitšwego godimo: mmala wa letlalo wo moswana',
    '👊🏻' => 'feise e sa tlago: mmala wa letlalo wa go taga',
    '👊🏼' => 'feise e sa tlago: mmala wa letlalo wa go taga wa magareng',
    '👊🏽' => 'feise e sa tlago: mmala wa letlalo wa magareng',
    '👊🏾' => 'feise e sa tlago: mmala wa letlalo wo moswana wa magareng',
    '👊🏿' => 'feise e sa tlago: mmala wa letlalo wo moswana',
    '🤛🏻' => 'letswele le lebilego ka le letshadi: mmala wa letlalo wa go taga',
    '🤛🏼' => 'letswele le lebilego ka le letshadi: mmala wa letlalo wa go taga wa magareng',
    '🤛🏽' => 'letswele le lebilego ka le letshadi: mmala wa letlalo wa magareng',
    '🤛🏾' => 'letswele le lebilego ka le letshadi: mmala wa letlalo wo moswana wa magareng',
    '🤛🏿' => 'letswele le lebilego ka le letshadi: mmala wa letlalo wo moswana',
    '🤜🏻' => 'letswele le lebilego ka go le letona: mmala wa letlalo wa go taga',
    '🤜🏼' => 'letswele le lebilego ka go le letona: mmala wa letlalo wa go taga wa magareng',
    '🤜🏽' => 'letswele le lebilego ka go le letona: mmala wa letlalo wa magareng',
    '🤜🏾' => 'letswele le lebilego ka go le letona: mmala wa letlalo wo moswana wa magareng',
    '🤜🏿' => 'letswele le lebilego ka go le letona: mmala wa letlalo wo moswana',
    '👏🏻' => 'go betha matsogo: mmala wa letlalo wa go taga',
    '👏🏼' => 'go betha matsogo: mmala wa letlalo wa go taga wa magareng',
    '👏🏽' => 'go betha matsogo: mmala wa letlalo wa magareng',
    '👏🏾' => 'go betha matsogo: mmala wa letlalo wo moswana wa magareng',
    '👏🏿' => 'go betha matsogo: mmala wa letlalo wo moswana',
    '🙌🏻' => 'go emiša matsogo: mmala wa letlalo wa go taga',
    '🙌🏼' => 'go emiša matsogo: mmala wa letlalo wa go taga wa magareng',
    '🙌🏽' => 'go emiša matsogo: mmala wa letlalo wa magareng',
    '🙌🏾' => 'go emiša matsogo: mmala wa letlalo wo moswana wa magareng',
    '🙌🏿' => 'go emiša matsogo: mmala wa letlalo wo moswana',
    '👐🏻' => 'matsogo a bulegilego: mmala wa letlalo wa go taga',
    '👐🏼' => 'matsogo a bulegilego: mmala wa letlalo wa go taga wa magareng',
    '👐🏽' => 'matsogo a bulegilego: mmala wa letlalo wa magareng',
    '👐🏾' => 'matsogo a bulegilego: mmala wa letlalo wo moswana wa magareng',
    '👐🏿' => 'matsogo a bulegilego: mmala wa letlalo wo moswana',
    '🤲🏻' => 'matsogo a ile godimo gotee: mmala wa letlalo wa go taga',
    '🤲🏼' => 'matsogo a ile godimo gotee: mmala wa letlalo wa go taga wa magareng',
    '🤲🏽' => 'matsogo a ile godimo gotee: mmala wa letlalo wa magareng',
    '🤲🏾' => 'matsogo a ile godimo gotee: mmala wa letlalo wo moswana wa magareng',
    '🤲🏿' => 'matsogo a ile godimo gotee: mmala wa letlalo wo moswana',
    '🤝🏻' => 'tumedišo ka letsogo: mmala wa letlalo wa go taga',
    '🤝🏼' => 'tumedišo ka letsogo: mmala wa letlalo wa go taga wa magareng',
    '🤝🏽' => 'tumedišo ka letsogo: mmala wa letlalo wa magareng',
    '🤝🏾' => 'tumedišo ka letsogo: mmala wa letlalo wo moswana wa magareng',
    '🤝🏿' => 'tumedišo ka letsogo: mmala wa letlalo wo moswana',
    '🙏🏻' => 'diatla tše phuthilwego: mmala wa letlalo wa go taga',
    '🙏🏼' => 'diatla tše phuthilwego: mmala wa letlalo wa go taga wa magareng',
    '🙏🏽' => 'diatla tše phuthilwego: mmala wa letlalo wa magareng',
    '🙏🏾' => 'diatla tše phuthilwego: mmala wa letlalo wo moswana wa magareng',
    '🙏🏿' => 'diatla tše phuthilwego: mmala wa letlalo wo moswana',
    '✍🏻' => 'seatla le ngwalago: mmala wa letlalo wa go taga',
    '✍🏼' => 'seatla le ngwalago: mmala wa letlalo wa go taga wa magareng',
    '✍🏽' => 'seatla le ngwalago: mmala wa letlalo wa magareng',
    '✍🏾' => 'seatla le ngwalago: mmala wa letlalo wo moswana wa magareng',
    '✍🏿' => 'seatla le ngwalago: mmala wa letlalo wo moswana',
    '💅🏻' => 'pholeše ya manala: mmala wa letlalo wa go taga',
    '💅🏼' => 'pholeše ya manala: mmala wa letlalo wa go taga wa magareng',
    '💅🏽' => 'pholeše ya manala: mmala wa letlalo wa magareng',
    '💅🏾' => 'pholeše ya manala: mmala wa letlalo wo moswana wa magareng',
    '💅🏿' => 'pholeše ya manala: mmala wa letlalo wo moswana',
    '🤳🏻' => 'go itšea senepe: mmala wa letlalo wa go taga',
    '🤳🏼' => 'go itšea senepe: mmala wa letlalo wa go taga wa magareng',
    '🤳🏽' => 'go itšea senepe: mmala wa letlalo wa magareng',
    '🤳🏾' => 'go itšea senepe: mmala wa letlalo wo moswana wa magareng',
    '🤳🏿' => 'go itšea senepe: mmala wa letlalo wo moswana',
    '💪🏻' => 'dimpana tša go itwaetša: mmala wa letlalo wa go taga',
    '💪🏼' => 'dimpana tša go itwaetša: mmala wa letlalo wa go taga wa magareng',
    '💪🏽' => 'dimpana tša go itwaetša: mmala wa letlalo wa magareng',
    '💪🏾' => 'dimpana tša go itwaetša: mmala wa letlalo wo moswana wa magareng',
    '💪🏿' => 'dimpana tša go itwaetša: mmala wa letlalo wo moswana',
    '👂🏻' => 'tsebe: mmala wa letlalo wa go taga',
    '👂🏼' => 'tsebe: mmala wa letlalo wa go taga wa magareng',
    '👂🏽' => 'tsebe: mmala wa letlalo wa magareng',
    '👂🏾' => 'tsebe: mmala wa letlalo wo moswana wa magareng',
    '👂🏿' => 'tsebe: mmala wa letlalo wo moswana',
    '👃🏻' => 'nko: mmala wa letlalo wa go taga',
    '👃🏼' => 'nko: mmala wa letlalo wa go taga wa magareng',
    '👃🏽' => 'nko: mmala wa letlalo wa magareng',
    '👃🏾' => 'nko: mmala wa letlalo wo moswana wa magareng',
    '👃🏿' => 'nko: mmala wa letlalo wo moswana',
    '👶🏻' => 'lesea: mmala wa letlalo wa go taga',
    '👶🏼' => 'lesea: mmala wa letlalo wa go taga wa magareng',
    '👶🏽' => 'lesea: mmala wa letlalo wa magareng',
    '👶🏾' => 'lesea: mmala wa letlalo wo moswana wa magareng',
    '👶🏿' => 'lesea: mmala wa letlalo wo moswana',
    '🧒🏻' => 'ngwana: mmala wa letlalo wa go taga',
    '🧒🏼' => 'ngwana: mmala wa letlalo wa go taga wa magareng',
    '🧒🏽' => 'ngwana: mmala wa letlalo wa magareng',
    '🧒🏾' => 'ngwana: mmala wa letlalo wo moswana wa magareng',
    '🧒🏿' => 'ngwana: mmala wa letlalo wo moswana',
    '👦🏻' => 'mošemane: mmala wa letlalo wa go taga',
    '👦🏼' => 'mošemane: mmala wa letlalo wa go taga wa magareng',
    '👦🏽' => 'mošemane: mmala wa letlalo wa magareng',
    '👦🏾' => 'mošemane: mmala wa letlalo wo moswana wa magareng',
    '👦🏿' => 'mošemane: mmala wa letlalo wo moswana',
    '👧🏻' => 'mosetsana: mmala wa letlalo wa go taga',
    '👧🏼' => 'mosetsana: mmala wa letlalo wa go taga wa magareng',
    '👧🏽' => 'mosetsana: mmala wa letlalo wa magareng',
    '👧🏾' => 'mosetsana: mmala wa letlalo wo moswana wa magareng',
    '👧🏿' => 'mosetsana: mmala wa letlalo wo moswana',
    '🧑🏻' => 'motho yo mogolo: mmala wa letlalo wa go taga',
    '🧑🏼' => 'motho yo mogolo: mmala wa letlalo wa go taga wa magareng',
    '🧑🏽' => 'motho yo mogolo: mmala wa letlalo wa magareng',
    '🧑🏾' => 'motho yo mogolo: mmala wa letlalo wo moswana wa magareng',
    '🧑🏿' => 'motho yo mogolo: mmala wa letlalo wo moswana',
    '👱🏻' => 'motho wa meriri ye mesehla: mmala wa letlalo wa go taga',
    '👱🏼' => 'motho wa meriri ye mesehla: mmala wa letlalo wa go taga wa magareng',
    '👱🏽' => 'motho wa meriri ye mesehla: mmala wa letlalo wa magareng',
    '👱🏾' => 'motho wa meriri ye mesehla: mmala wa letlalo wo moswana wa magareng',
    '👱🏿' => 'motho wa meriri ye mesehla: mmala wa letlalo wo moswana',
    '👨🏻' => 'monna: mmala wa letlalo wa go taga',
    '👨🏼' => 'monna: mmala wa letlalo wa go taga wa magareng',
    '👨🏽' => 'monna: mmala wa letlalo wa magareng',
    '👨🏾' => 'monna: mmala wa letlalo wo moswana wa magareng',
    '👨🏿' => 'monna: mmala wa letlalo wo moswana',
    '🧔🏻' => 'motho ka maledu: mmala wa letlalo wa go taga',
    '🧔🏼' => 'motho ka maledu: mmala wa letlalo wa go taga wa magareng',
    '🧔🏽' => 'motho ka maledu: mmala wa letlalo wa magareng',
    '🧔🏾' => 'motho ka maledu: mmala wa letlalo wo moswana wa magareng',
    '🧔🏿' => 'motho ka maledu: mmala wa letlalo wo moswana',
    '👩🏻' => 'mosadi: mmala wa letlalo wa go taga',
    '👩🏼' => 'mosadi: mmala wa letlalo wa go taga wa magareng',
    '👩🏽' => 'mosadi: mmala wa letlalo wa magareng',
    '👩🏾' => 'mosadi: mmala wa letlalo wo moswana wa magareng',
    '👩🏿' => 'mosadi: mmala wa letlalo wo moswana',
    '🧓🏻' => 'mokgalabje yo mogolo: mmala wa letlalo wa go taga',
    '🧓🏼' => 'mokgalabje yo mogolo: mmala wa letlalo wa go taga wa magareng',
    '🧓🏽' => 'mokgalabje yo mogolo: mmala wa letlalo wa magareng',
    '🧓🏾' => 'mokgalabje yo mogolo: mmala wa letlalo wo moswana wa magareng',
    '🧓🏿' => 'mokgalabje yo mogolo: mmala wa letlalo wo moswana',
    '👴🏻' => 'mokgalabje: mmala wa letlalo wa go taga',
    '👴🏼' => 'mokgalabje: mmala wa letlalo wa go taga wa magareng',
    '👴🏽' => 'mokgalabje: mmala wa letlalo wa magareng',
    '👴🏾' => 'mokgalabje: mmala wa letlalo wo moswana wa magareng',
    '👴🏿' => 'mokgalabje: mmala wa letlalo wo moswana',
    '👵🏻' => 'mokgekolo: mmala wa letlalo wa go taga',
    '👵🏼' => 'mokgekolo: mmala wa letlalo wa go taga wa magareng',
    '👵🏽' => 'mokgekolo: mmala wa letlalo wa magareng',
    '👵🏾' => 'mokgekolo: mmala wa letlalo wo moswana wa magareng',
    '👵🏿' => 'mokgekolo: mmala wa letlalo wo moswana',
    '🙍🏻' => 'motho yo a sa dumelego ka ditho: mmala wa letlalo wa go taga',
    '🙍🏼' => 'motho yo a sa dumelego ka ditho: mmala wa letlalo wa go taga wa magareng',
    '🙍🏽' => 'motho yo a sa dumelego ka ditho: mmala wa letlalo wa magareng',
    '🙍🏾' => 'motho yo a sa dumelego ka ditho: mmala wa letlalo wo moswana wa magareng',
    '🙍🏿' => 'motho yo a sa dumelego ka ditho: mmala wa letlalo wo moswana',
    '🙎🏻' => 'motho yo a ipopilego molomo: mmala wa letlalo wa go taga',
    '🙎🏼' => 'motho yo a ipopilego molomo: mmala wa letlalo wa go taga wa magareng',
    '🙎🏽' => 'motho yo a ipopilego molomo: mmala wa letlalo wa magareng',
    '🙎🏾' => 'motho yo a ipopilego molomo: mmala wa letlalo wo moswana wa magareng',
    '🙎🏿' => 'motho yo a ipopilego molomo: mmala wa letlalo wo moswana',
    '🙅🏻' => 'motho o re AOWA ka ditho: mmala wa letlalo wa go taga',
    '🙅🏼' => 'motho o re AOWA ka ditho: mmala wa letlalo wa go taga wa magareng',
    '🙅🏽' => 'motho o re AOWA ka ditho: mmala wa letlalo wa magareng',
    '🙅🏾' => 'motho o re AOWA ka ditho: mmala wa letlalo wo moswana wa magareng',
    '🙅🏿' => 'motho o re AOWA ka ditho: mmala wa letlalo wo moswana',
    '🙆🏻' => 'Motho o re go LOKILE: mmala wa letlalo wa go taga',
    '🙆🏼' => 'Motho o re go LOKILE: mmala wa letlalo wa go taga wa magareng',
    '🙆🏽' => 'Motho o re go LOKILE: mmala wa letlalo wa magareng',
    '🙆🏾' => 'Motho o re go LOKILE: mmala wa letlalo wo moswana wa magareng',
    '🙆🏿' => 'Motho o re go LOKILE: mmala wa letlalo wo moswana',
    '💁🏻' => 'motho yo a dumelago ka seatla: mmala wa letlalo wa go taga',
    '💁🏼' => 'motho yo a dumelago ka seatla: mmala wa letlalo wa go taga wa magareng',
    '💁🏽' => 'motho yo a dumelago ka seatla: mmala wa letlalo wa magareng',
    '💁🏾' => 'motho yo a dumelago ka seatla: mmala wa letlalo wo moswana wa magareng',
    '💁🏿' => 'motho yo a dumelago ka seatla: mmala wa letlalo wo moswana',
    '🙋🏻' => 'motho o emišitše seatla: mmala wa letlalo wa go taga',
    '🙋🏼' => 'motho o emišitše seatla: mmala wa letlalo wa go taga wa magareng',
    '🙋🏽' => 'motho o emišitše seatla: mmala wa letlalo wa magareng',
    '🙋🏾' => 'motho o emišitše seatla: mmala wa letlalo wo moswana wa magareng',
    '🙋🏿' => 'motho o emišitše seatla: mmala wa letlalo wo moswana',
    '🙇🏻' => 'motho yo a inamego: mmala wa letlalo wa go taga',
    '🙇🏼' => 'motho yo a inamego: mmala wa letlalo wa go taga wa magareng',
    '🙇🏽' => 'motho yo a inamego: mmala wa letlalo wa magareng',
    '🙇🏾' => 'motho yo a inamego: mmala wa letlalo wo moswana wa magareng',
    '🙇🏿' => 'motho yo a inamego: mmala wa letlalo wo moswana',
    '🤦🏻' => 'motho yo a emišago ka seatla: mmala wa letlalo wa go taga',
    '🤦🏼' => 'motho yo a emišago ka seatla: mmala wa letlalo wa go taga wa magareng',
    '🤦🏽' => 'motho yo a emišago ka seatla: mmala wa letlalo wa magareng',
    '🤦🏾' => 'motho yo a emišago ka seatla: mmala wa letlalo wo moswana wa magareng',
    '🤦🏿' => 'motho yo a emišago ka seatla: mmala wa letlalo wo moswana',
    '🤷🏻' => 'motho yo a emišitšego magetla: mmala wa letlalo wa go taga',
    '🤷🏼' => 'motho yo a emišitšego magetla: mmala wa letlalo wa go taga wa magareng',
    '🤷🏽' => 'motho yo a emišitšego magetla: mmala wa letlalo wa magareng',
    '🤷🏾' => 'motho yo a emišitšego magetla: mmala wa letlalo wo moswana wa magareng',
    '🤷🏿' => 'motho yo a emišitšego magetla: mmala wa letlalo wo moswana',
    '👮🏻' => 'mohlankedi wa maphodisa: mmala wa letlalo wa go taga',
    '👮🏼' => 'mohlankedi wa maphodisa: mmala wa letlalo wa go taga wa magareng',
    '👮🏽' => 'mohlankedi wa maphodisa: mmala wa letlalo wa magareng',
    '👮🏾' => 'mohlankedi wa maphodisa: mmala wa letlalo wo moswana wa magareng',
    '👮🏿' => 'mohlankedi wa maphodisa: mmala wa letlalo wo moswana',
    '🕵🏻' => 'lephodisa: mmala wa letlalo wa go taga',
    '🕵🏼' => 'lephodisa: mmala wa letlalo wa go taga wa magareng',
    '🕵🏽' => 'lephodisa: mmala wa letlalo wa magareng',
    '🕵🏾' => 'lephodisa: mmala wa letlalo wo moswana wa magareng',
    '🕵🏿' => 'lephodisa: mmala wa letlalo wo moswana',
    '💂🏻' => 'mohlokomedi: mmala wa letlalo wa go taga',
    '💂🏼' => 'mohlokomedi: mmala wa letlalo wa go taga wa magareng',
    '💂🏽' => 'mohlokomedi: mmala wa letlalo wa magareng',
    '💂🏾' => 'mohlokomedi: mmala wa letlalo wo moswana wa magareng',
    '💂🏿' => 'mohlokomedi: mmala wa letlalo wo moswana',
    '👷🏻' => 'mošomi wa go aga: mmala wa letlalo wa go taga',
    '👷🏼' => 'mošomi wa go aga: mmala wa letlalo wa go taga wa magareng',
    '👷🏽' => 'mošomi wa go aga: mmala wa letlalo wa magareng',
    '👷🏾' => 'mošomi wa go aga: mmala wa letlalo wo moswana wa magareng',
    '👷🏿' => 'mošomi wa go aga: mmala wa letlalo wo moswana',
    '🤴🏻' => 'morwakgoši: mmala wa letlalo wa go taga',
    '🤴🏼' => 'morwakgoši: mmala wa letlalo wa go taga wa magareng',
    '🤴🏽' => 'morwakgoši: mmala wa letlalo wa magareng',
    '🤴🏾' => 'morwakgoši: mmala wa letlalo wo moswana wa magareng',
    '🤴🏿' => 'morwakgoši: mmala wa letlalo wo moswana',
    '👸🏻' => 'kgošigadi: mmala wa letlalo wa go taga',
    '👸🏼' => 'kgošigadi: mmala wa letlalo wa go taga wa magareng',
    '👸🏽' => 'kgošigadi: mmala wa letlalo wa magareng',
    '👸🏾' => 'kgošigadi: mmala wa letlalo wo moswana wa magareng',
    '👸🏿' => 'kgošigadi: mmala wa letlalo wo moswana',
    '👳🏻' => 'motho yo rwelego thepene: mmala wa letlalo wa go taga',
    '👳🏼' => 'motho yo rwelego thepene: mmala wa letlalo wa go taga wa magareng',
    '👳🏽' => 'motho yo rwelego thepene: mmala wa letlalo wa magareng',
    '👳🏾' => 'motho yo rwelego thepene: mmala wa letlalo wo moswana wa magareng',
    '👳🏿' => 'motho yo rwelego thepene: mmala wa letlalo wo moswana',
    '👲🏻' => 'monna ka kefa ya Matšhaena: mmala wa letlalo wa go taga',
    '👲🏼' => 'monna ka kefa ya Matšhaena: mmala wa letlalo wa go taga wa magareng',
    '👲🏽' => 'monna ka kefa ya Matšhaena: mmala wa letlalo wa magareng',
    '👲🏾' => 'monna ka kefa ya Matšhaena: mmala wa letlalo wo moswana wa magareng',
    '👲🏿' => 'monna ka kefa ya Matšhaena: mmala wa letlalo wo moswana',
    '🧕🏻' => 'mosadi yo a rwelego hlogong: mmala wa letlalo wa go taga',
    '🧕🏼' => 'mosadi yo a rwelego hlogong: mmala wa letlalo wa go taga wa magareng',
    '🧕🏽' => 'mosadi yo a rwelego hlogong: mmala wa letlalo wa magareng',
    '🧕🏾' => 'mosadi yo a rwelego hlogong: mmala wa letlalo wo moswana wa magareng',
    '🧕🏿' => 'mosadi yo a rwelego hlogong: mmala wa letlalo wo moswana',
    '🤵🏻' => 'monna ka sutu: mmala wa letlalo wa go taga',
    '🤵🏼' => 'monna ka sutu: mmala wa letlalo wa go taga wa magareng',
    '🤵🏽' => 'monna ka sutu: mmala wa letlalo wa magareng',
    '🤵🏾' => 'monna ka sutu: mmala wa letlalo wo moswana wa magareng',
    '🤵🏿' => 'monna ka sutu: mmala wa letlalo wo moswana',
    '👰🏻' => 'ngwetši ka lešira: mmala wa letlalo wa go taga',
    '👰🏼' => 'ngwetši ka lešira: mmala wa letlalo wa go taga wa magareng',
    '👰🏽' => 'ngwetši ka lešira: mmala wa letlalo wa magareng',
    '👰🏾' => 'ngwetši ka lešira: mmala wa letlalo wo moswana wa magareng',
    '👰🏿' => 'ngwetši ka lešira: mmala wa letlalo wo moswana',
    '🤰🏻' => 'mosadi yo a imilego: mmala wa letlalo wa go taga',
    '🤰🏼' => 'mosadi yo a imilego: mmala wa letlalo wa go taga wa magareng',
    '🤰🏽' => 'mosadi yo a imilego: mmala wa letlalo wa magareng',
    '🤰🏾' => 'mosadi yo a imilego: mmala wa letlalo wo moswana wa magareng',
    '🤰🏿' => 'mosadi yo a imilego: mmala wa letlalo wo moswana',
    '🤱🏻' => 'go nyantšha: mmala wa letlalo wa go taga',
    '🤱🏼' => 'go nyantšha: mmala wa letlalo wa go taga wa magareng',
    '🤱🏽' => 'go nyantšha: mmala wa letlalo wa magareng',
    '🤱🏾' => 'go nyantšha: mmala wa letlalo wo moswana wa magareng',
    '🤱🏿' => 'go nyantšha: mmala wa letlalo wo moswana',
    '👼🏻' => 'lengoloi la lesea: mmala wa letlalo wa go taga',
    '👼🏼' => 'lengoloi la lesea: mmala wa letlalo wa go taga wa magareng',
    '👼🏽' => 'lengoloi la lesea: mmala wa letlalo wa magareng',
    '👼🏾' => 'lengoloi la lesea: mmala wa letlalo wo moswana wa magareng',
    '👼🏿' => 'lengoloi la lesea: mmala wa letlalo wo moswana',
    '🎅🏻' => 'Santa Claus: mmala wa letlalo wa go taga',
    '🎅🏼' => 'Santa Claus: mmala wa letlalo wa go taga wa magareng',
    '🎅🏽' => 'Santa Claus: mmala wa letlalo wa magareng',
    '🎅🏾' => 'Santa Claus: mmala wa letlalo wo moswana wa magareng',
    '🎅🏿' => 'Santa Claus: mmala wa letlalo wo moswana',
    '🤶🏻' => 'Mohumagadi Claus: mmala wa letlalo wa go taga',
    '🤶🏼' => 'Mohumagadi Claus: mmala wa letlalo wa go taga wa magareng',
    '🤶🏽' => 'Mohumagadi Claus: mmala wa letlalo wa magareng',
    '🤶🏾' => 'Mohumagadi Claus: mmala wa letlalo wo moswana wa magareng',
    '🤶🏿' => 'Mohumagadi Claus: mmala wa letlalo wo moswana',
    '🧙🏻' => 'maleatlana: mmala wa letlalo wa go taga',
    '🧙🏼' => 'maleatlana: mmala wa letlalo wa go taga wa magareng',
    '🧙🏽' => 'maleatlana: mmala wa letlalo wa magareng',
    '🧙🏾' => 'maleatlana: mmala wa letlalo wo moswana wa magareng',
    '🧙🏿' => 'maleatlana: mmala wa letlalo wo moswana',
    '🧚🏻' => 'boikgopolelo: mmala wa letlalo wa go taga',
    '🧚🏼' => 'boikgopolelo: mmala wa letlalo wa go taga wa magareng',
    '🧚🏽' => 'boikgopolelo: mmala wa letlalo wa magareng',
    '🧚🏾' => 'boikgopolelo: mmala wa letlalo wo moswana wa magareng',
    '🧚🏿' => 'boikgopolelo: mmala wa letlalo wo moswana',
    '🧛🏻' => 'bemphaya: mmala wa letlalo wa go taga',
    '🧛🏼' => 'bemphaya: mmala wa letlalo wa go taga wa magareng',
    '🧛🏽' => 'bemphaya: mmala wa letlalo wa magareng',
    '🧛🏾' => 'bemphaya: mmala wa letlalo wo moswana wa magareng',
    '🧛🏿' => 'bemphaya: mmala wa letlalo wo moswana',
    '🧜🏻' => 'motho wa ka meetseng: mmala wa letlalo wa go taga',
    '🧜🏼' => 'motho wa ka meetseng: mmala wa letlalo wa go taga wa magareng',
    '🧜🏽' => 'motho wa ka meetseng: mmala wa letlalo wa magareng',
    '🧜🏾' => 'motho wa ka meetseng: mmala wa letlalo wo moswana wa magareng',
    '🧜🏿' => 'motho wa ka meetseng: mmala wa letlalo wo moswana',
    '🧝🏻' => 'sephidi se matla: mmala wa letlalo wa go taga',
    '🧝🏼' => 'sephidi se matla: mmala wa letlalo wa go taga wa magareng',
    '🧝🏽' => 'sephidi se matla: mmala wa letlalo wa magareng',
    '🧝🏾' => 'sephidi se matla: mmala wa letlalo wo moswana wa magareng',
    '🧝🏿' => 'sephidi se matla: mmala wa letlalo wo moswana',
    '💆🏻' => 'motho yo a masatšwago: mmala wa letlalo wa go taga',
    '💆🏼' => 'motho yo a masatšwago: mmala wa letlalo wa go taga wa magareng',
    '💆🏽' => 'motho yo a masatšwago: mmala wa letlalo wa magareng',
    '💆🏾' => 'motho yo a masatšwago: mmala wa letlalo wo moswana wa magareng',
    '💆🏿' => 'motho yo a masatšwago: mmala wa letlalo wo moswana',
    '💇🏻' => 'motho yo a kotwago moriri: mmala wa letlalo wa go taga',
    '💇🏼' => 'motho yo a kotwago moriri: mmala wa letlalo wa go taga wa magareng',
    '💇🏽' => 'motho yo a kotwago moriri: mmala wa letlalo wa magareng',
    '💇🏾' => 'motho yo a kotwago moriri: mmala wa letlalo wo moswana wa magareng',
    '💇🏿' => 'motho yo a kotwago moriri: mmala wa letlalo wo moswana',
    '🚶🏻' => 'motho yo a sepelago: mmala wa letlalo wa go taga',
    '🚶🏼' => 'motho yo a sepelago: mmala wa letlalo wa go taga wa magareng',
    '🚶🏽' => 'motho yo a sepelago: mmala wa letlalo wa magareng',
    '🚶🏾' => 'motho yo a sepelago: mmala wa letlalo wo moswana wa magareng',
    '🚶🏿' => 'motho yo a sepelago: mmala wa letlalo wo moswana',
    '🏃🏻' => 'motho yo a kitimago: mmala wa letlalo wa go taga',
    '🏃🏼' => 'motho yo a kitimago: mmala wa letlalo wa go taga wa magareng',
    '🏃🏽' => 'motho yo a kitimago: mmala wa letlalo wa magareng',
    '🏃🏾' => 'motho yo a kitimago: mmala wa letlalo wo moswana wa magareng',
    '🏃🏿' => 'motho yo a kitimago: mmala wa letlalo wo moswana',
    '💃🏻' => 'mosadi yo a binago: mmala wa letlalo wa go taga',
    '💃🏼' => 'mosadi yo a binago: mmala wa letlalo wa go taga wa magareng',
    '💃🏽' => 'mosadi yo a binago: mmala wa letlalo wa magareng',
    '💃🏾' => 'mosadi yo a binago: mmala wa letlalo wo moswana wa magareng',
    '💃🏿' => 'mosadi yo a binago: mmala wa letlalo wo moswana',
    '🕺🏻' => 'monna yo a binago: mmala wa letlalo wa go taga',
    '🕺🏼' => 'monna yo a binago: mmala wa letlalo wa go taga wa magareng',
    '🕺🏽' => 'monna yo a binago: mmala wa letlalo wa magareng',
    '🕺🏾' => 'monna yo a binago: mmala wa letlalo wo moswana wa magareng',
    '🕺🏿' => 'monna yo a binago: mmala wa letlalo wo moswana',
    '🕴🏻' => 'monna o apere sutu ya mošomo wa ema: mmala wa letlalo wa go taga',
    '🕴🏼' => 'monna o apere sutu ya mošomo wa ema: mmala wa letlalo wa go taga wa magareng',
    '🕴🏽' => 'monna o apere sutu ya mošomo wa ema: mmala wa letlalo wa magareng',
    '🕴🏾' => 'monna o apere sutu ya mošomo wa ema: mmala wa letlalo wo moswana wa magareng',
    '🕴🏿' => 'monna o apere sutu ya mošomo wa ema: mmala wa letlalo wo moswana',
    '👯🏻' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wa go taga',
    '👯🏼' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wa go taga wa magareng',
    '👯🏽' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wa magareng',
    '👯🏾' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wo moswana wa magareng',
    '👯🏿' => 'batho ba ditsebe tša mmutla ba a bina: mmala wa letlalo wo moswana',
    '🧖🏻' => 'motho ka phaphošing ya moya wa go fiša: mmala wa letlalo wa go taga',
    '🧖🏼' => 'motho ka phaphošing ya moya wa go fiša: mmala wa letlalo wa go taga wa magareng',
    '🧖🏽' => 'motho ka phaphošing ya moya wa go fiša: mmala wa letlalo wa magareng',
    '🧖🏾' => 'motho ka phaphošing ya moya wa go fiša: mmala wa letlalo wo moswana wa magareng',
    '🧖🏿' => 'motho ka phaphošing ya moya wa go fiša: mmala wa letlalo wo moswana',
    '🧗🏻' => 'motho o a namela: mmala wa letlalo wa go taga',
    '🧗🏼' => 'motho o a namela: mmala wa letlalo wa go taga wa magareng',
    '🧗🏽' => 'motho o a namela: mmala wa letlalo wa magareng',
    '🧗🏾' => 'motho o a namela: mmala wa letlalo wo moswana wa magareng',
    '🧗🏿' => 'motho o a namela: mmala wa letlalo wo moswana',
    '🏇🏻' => 'go kitima ga dipere: mmala wa letlalo wa go taga',
    '🏇🏼' => 'go kitima ga dipere: mmala wa letlalo wa go taga wa magareng',
    '🏇🏽' => 'go kitima ga dipere: mmala wa letlalo wa magareng',
    '🏇🏾' => 'go kitima ga dipere: mmala wa letlalo wo moswana wa magareng',
    '🏇🏿' => 'go kitima ga dipere: mmala wa letlalo wo moswana',
    '🏂🏻' => 'go sesa lehlweng: mmala wa letlalo wa go taga',
    '🏂🏼' => 'go sesa lehlweng: mmala wa letlalo wa go taga wa magareng',
    '🏂🏽' => 'go sesa lehlweng: mmala wa letlalo wa magareng',
    '🏂🏾' => 'go sesa lehlweng: mmala wa letlalo wo moswana wa magareng',
    '🏂🏿' => 'go sesa lehlweng: mmala wa letlalo wo moswana',
    '🏌🏻' => 'motho o bapala kolofo: mmala wa letlalo wa go taga',
    '🏌🏼' => 'motho o bapala kolofo: mmala wa letlalo wa go taga wa magareng',
    '🏌🏽' => 'motho o bapala kolofo: mmala wa letlalo wa magareng',
    '🏌🏾' => 'motho o bapala kolofo: mmala wa letlalo wo moswana wa magareng',
    '🏌🏿' => 'motho o bapala kolofo: mmala wa letlalo wo moswana',
    '🏄🏻' => 'motho a sesa lewatleng: mmala wa letlalo wa go taga',
    '🏄🏼' => 'motho a sesa lewatleng: mmala wa letlalo wa go taga wa magareng',
    '🏄🏽' => 'motho a sesa lewatleng: mmala wa letlalo wa magareng',
    '🏄🏾' => 'motho a sesa lewatleng: mmala wa letlalo wo moswana wa magareng',
    '🏄🏿' => 'motho a sesa lewatleng: mmala wa letlalo wo moswana',
    '🚣🏻' => 'motho ka seketswana: mmala wa letlalo wa go taga',
    '🚣🏼' => 'motho ka seketswana: mmala wa letlalo wa go taga wa magareng',
    '🚣🏽' => 'motho ka seketswana: mmala wa letlalo wa magareng',
    '🚣🏾' => 'motho ka seketswana: mmala wa letlalo wo moswana wa magareng',
    '🚣🏿' => 'motho ka seketswana: mmala wa letlalo wo moswana',
    '🏊🏻' => 'motho o a rutha: mmala wa letlalo wa go taga',
    '🏊🏼' => 'motho o a rutha: mmala wa letlalo wa go taga wa magareng',
    '🏊🏽' => 'motho o a rutha: mmala wa letlalo wa magareng',
    '🏊🏾' => 'motho o a rutha: mmala wa letlalo wo moswana wa magareng',
    '🏊🏿' => 'motho o a rutha: mmala wa letlalo wo moswana',
    '⛹🏻' => 'motho o bethantšha polo: mmala wa letlalo wa go taga',
    '⛹🏼' => 'motho o bethantšha polo: mmala wa letlalo wa go taga wa magareng',
    '⛹🏽' => 'motho o bethantšha polo: mmala wa letlalo wa magareng',
    '⛹🏾' => 'motho o bethantšha polo: mmala wa letlalo wo moswana wa magareng',
    '⛹🏿' => 'motho o bethantšha polo: mmala wa letlalo wo moswana',
    '🏋🏻' => 'motho o kuka boima: mmala wa letlalo wa go taga',
    '🏋🏼' => 'motho o kuka boima: mmala wa letlalo wa go taga wa magareng',
    '🏋🏽' => 'motho o kuka boima: mmala wa letlalo wa magareng',
    '🏋🏾' => 'motho o kuka boima: mmala wa letlalo wo moswana wa magareng',
    '🏋🏿' => 'motho o kuka boima: mmala wa letlalo wo moswana',
    '🚴🏻' => 'motho ka paesekela: mmala wa letlalo wa go taga',
    '🚴🏼' => 'motho ka paesekela: mmala wa letlalo wa go taga wa magareng',
    '🚴🏽' => 'motho ka paesekela: mmala wa letlalo wa magareng',
    '🚴🏾' => 'motho ka paesekela: mmala wa letlalo wo moswana wa magareng',
    '🚴🏿' => 'motho ka paesekela: mmala wa letlalo wo moswana',
    '🚵🏻' => 'motho ka paesekela thabeng: mmala wa letlalo wa go taga',
    '🚵🏼' => 'motho ka paesekela thabeng: mmala wa letlalo wa go taga wa magareng',
    '🚵🏽' => 'motho ka paesekela thabeng: mmala wa letlalo wa magareng',
    '🚵🏾' => 'motho ka paesekela thabeng: mmala wa letlalo wo moswana wa magareng',
    '🚵🏿' => 'motho ka paesekela thabeng: mmala wa letlalo wo moswana',
    '🤸🏻' => 'motho a dikologa ka mmele: mmala wa letlalo wa go taga',
    '🤸🏼' => 'motho a dikologa ka mmele: mmala wa letlalo wa go taga wa magareng',
    '🤸🏽' => 'motho a dikologa ka mmele: mmala wa letlalo wa magareng',
    '🤸🏾' => 'motho a dikologa ka mmele: mmala wa letlalo wo moswana wa magareng',
    '🤸🏿' => 'motho a dikologa ka mmele: mmala wa letlalo wo moswana',
    '🤼🏻' => 'motho o lwa reseling: mmala wa letlalo wa go taga',
    '🤼🏼' => 'motho o lwa reseling: mmala wa letlalo wa go taga wa magareng',
    '🤼🏽' => 'motho o lwa reseling: mmala wa letlalo wa magareng',
    '🤼🏾' => 'motho o lwa reseling: mmala wa letlalo wo moswana wa magareng',
    '🤼🏿' => 'motho o lwa reseling: mmala wa letlalo wo moswana',
    '🤽🏻' => 'motho o bapala polo ya ka meetseng: mmala wa letlalo wa go taga',
    '🤽🏼' => 'motho o bapala polo ya ka meetseng: mmala wa letlalo wa go taga wa magareng',
    '🤽🏽' => 'motho o bapala polo ya ka meetseng: mmala wa letlalo wa magareng',
    '🤽🏾' => 'motho o bapala polo ya ka meetseng: mmala wa letlalo wo moswana wa magareng',
    '🤽🏿' => 'motho o bapala polo ya ka meetseng: mmala wa letlalo wo moswana',
    '🤾🏻' => 'motho a bapala polo ya diatla: mmala wa letlalo wa go taga',
    '🤾🏼' => 'motho a bapala polo ya diatla: mmala wa letlalo wa go taga wa magareng',
    '🤾🏽' => 'motho a bapala polo ya diatla: mmala wa letlalo wa magareng',
    '🤾🏾' => 'motho a bapala polo ya diatla: mmala wa letlalo wo moswana wa magareng',
    '🤾🏿' => 'motho a bapala polo ya diatla: mmala wa letlalo wo moswana',
    '🤹🏻' => 'motho o swara mo le mola: mmala wa letlalo wa go taga',
    '🤹🏼' => 'motho o swara mo le mola: mmala wa letlalo wa go taga wa magareng',
    '🤹🏽' => 'motho o swara mo le mola: mmala wa letlalo wa magareng',
    '🤹🏾' => 'motho o swara mo le mola: mmala wa letlalo wo moswana wa magareng',
    '🤹🏿' => 'motho o swara mo le mola: mmala wa letlalo wo moswana',
    '🧘🏻' => 'motho a phuthile maoto: mmala wa letlalo wa go taga',
    '🧘🏼' => 'motho a phuthile maoto: mmala wa letlalo wa go taga wa magareng',
    '🧘🏽' => 'motho a phuthile maoto: mmala wa letlalo wa magareng',
    '🧘🏾' => 'motho a phuthile maoto: mmala wa letlalo wo moswana wa magareng',
    '🧘🏿' => 'motho a phuthile maoto: mmala wa letlalo wo moswana',
    '🛀🏻' => 'motho o a hlapa: mmala wa letlalo wa go taga',
    '🛀🏼' => 'motho o a hlapa: mmala wa letlalo wa go taga wa magareng',
    '🛀🏽' => 'motho o a hlapa: mmala wa letlalo wa magareng',
    '🛀🏾' => 'motho o a hlapa: mmala wa letlalo wo moswana wa magareng',
    '🛀🏿' => 'motho o a hlapa: mmala wa letlalo wo moswana',
    '🛌🏻' => 'motho mpeteng: mmala wa letlalo wa go taga',
    '🛌🏼' => 'motho mpeteng: mmala wa letlalo wa go taga wa magareng',
    '🛌🏽' => 'motho mpeteng: mmala wa letlalo wa magareng',
    '🛌🏾' => 'motho mpeteng: mmala wa letlalo wo moswana wa magareng',
    '🛌🏿' => 'motho mpeteng: mmala wa letlalo wo moswana',
    '👭🏻' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wa go taga',
    '👭🏼' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wa go taga wa magareng',
    '👭🏽' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wa magareng',
    '👭🏾' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wo moswana wa magareng',
    '👭🏿' => 'basadi ba babedi ba swarane ka matsogo: mmala wa letlalo wo moswana',
    '👫🏻' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wa go taga',
    '👫🏼' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wa go taga wa magareng',
    '👫🏽' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wa magareng',
    '👫🏾' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wo moswana wa magareng',
    '👫🏿' => 'monna le mosadi ba swarane ka matsogo: mmala wa letlalo wo moswana',
    '👬🏻' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wa go taga',
    '👬🏼' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wa go taga wa magareng',
    '👬🏽' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wa magareng',
    '👬🏾' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wo moswana wa magareng',
    '👬🏿' => 'banna ba babedi ba swarane ka matsogo: mmala wa letlalo wo moswana',
    '💏🏻' => 'atlana: mmala wa letlalo wa go taga',
    '💏🏼' => 'atlana: mmala wa letlalo wa go taga wa magareng',
    '💏🏽' => 'atlana: mmala wa letlalo wa magareng',
    '💏🏾' => 'atlana: mmala wa letlalo wo moswana wa magareng',
    '💏🏿' => 'atlana: mmala wa letlalo wo moswana',
    '💑🏻' => 'balekane ka pelwana: mmala wa letlalo wa go taga',
    '💑🏼' => 'balekane ka pelwana: mmala wa letlalo wa go taga wa magareng',
    '💑🏽' => 'balekane ka pelwana: mmala wa letlalo wa magareng',
    '💑🏾' => 'balekane ka pelwana: mmala wa letlalo wo moswana wa magareng',
    '💑🏿' => 'balekane ka pelwana: mmala wa letlalo wo moswana',
    '🏻' => 'mmala wa letlalo wa go taga',
    '🏼' => 'mmala wa letlalo wa go taga wa magareng',
    '🏽' => 'mmala wa letlalo wa magareng',
    '🏾' => 'mmala wa letlalo wo moswana wa magareng',
    '🏿' => 'mmala wa letlalo wo moswana',
    '😀' => 'sefahlego se myemyelago kudu',
    '😃' => 'sefahlego se myemyelago le molomo o bulegilego',
    '😄' => 'sefahlego seo se myemyelago seo se butšego molomo le sefahlego se myemyelago',
    '😁' => 'sefahlego se šinyalalago le sefahlego se myemyelago',
    '😆' => 'sefahlego seo se myemyelago sa molomo wa go bulega le mahlo a tswaletšwego',
    '😅' => 'sefahlego seo se myemyelago se butše molomo le kudumela e tonyago',
    '🤣' => 'go sega o rapaletše fase',
    '😂' => 'sefahlego sa megokgo ya lethabo',
    '🙂' => 'sefahlego se myemyelago ganyenyane',
    '🙃' => 'sefahlego se lebeletšego fase',
    '😉' => 'sefahlego se ponyago letee',
    '😊' => 'sefahlego le mahlo a myemyelago',
    '😇' => 'sefahlego se myemyelago le halo',
    '😍' => 'sefahlego se myemyelago le mahlwana a pellwana',
    '🤩' => 'go wa ga naledi',
    '😘' => 'katlo ye butšwetšago moya',
    '😗' => 'sefahlego sa go atlana',
    '☺' => 'sefahlego se myemyelago',
    '😚' => 'sefahlego sa go atlana le go tswalela mahlo',
    '😙' => 'sefahlego sa go atlana le go myemyela',
    '😋' => 'sefahlego se fanago ka dijo tše rothišago mare',
    '😛' => 'sefahlego sa lelengwana',
    '😜' => 'sefahlego seo se ntšhitšego leleme le go ponya leihlo',
    '🤪' => 'sefahlego sa bogaswi',
    '😝' => 'sefahlego sa go ntšha leleme le mahlo a tswalegilego',
    '🤑' => 'sefahlego sa tšhelete molomong',
    '🤗' => 'sefahlego se gokarelanago',
    '🤭' => 'sefahlego se nago le seatla molomong',
    '🤫' => 'sefahlego sa gore homola',
    '🤔' => 'sefahlego se naganago',
    '🤐' => 'sefahlego sa molomo o tswalegilego',
    '🤨' => 'sefahlego se emišitšego dintši',
    '😐' => 'sefahlego sa magareng',
    '😑' => 'sefahlego sa go hloka maikwelo',
    '😶' => 'sefahlego sa go hloka molomo',
    '😏' => 'go myemyela mo go sa kgahlišego',
    '😒' => 'sefahlego sa go se kgotsofale',
    '🙄' => 'sefahlego sa mahlo a go dikologa',
    '😬' => 'sefahlego se tšintšego',
    '🤥' => 'sefahlego se bolelago maaka',
    '😌' => 'sefahlego se imologilego',
    '😔' => 'sefahlego se lapišitšwego ke bophelo',
    '😪' => 'sefahlego sa boroko',
    '🤤' => 'sefahlego sa ditete',
    '😴' => 'sefahlego se robetšego',
    '😷' => 'sefahlego se aperego tša bongaka',
    '🤒' => 'Sefahlego se nago le themometara',
    '🤕' => 'sefahlego sa pantetšhe ya hlogong',
    '🤢' => 'sefahlego se belekegago',
    '🤮' => 'sefahlego se hlatšago',
    '🤧' => 'sefahlego se ithimolago',
    '😵' => 'sefahlego se dikologago',
    '🤯' => 'hlogo e thunyago',
    '🤠' => 'sefahlego sa kefa ya lekhaopoye',
    '😎' => 'sefahlego se myemyelago ka digalasetšatši',
    '🤓' => 'sefahlego sa dipaketsane',
    '🧐' => 'sefahlego sa metlae',
    '😕' => 'sefahlego se gakanegilego',
    '😟' => 'sefahlego se tshwenyegilego',
    '🙁' => 'sefahlego sa go se dumele go se nene',
    '☹' => 'sefahlego se se šošobanego',
    '😮' => 'sefahlego sa molomo o bulegilego',
    '😯' => 'sefahlego se homotšego',
    '😲' => 'sefahlego se maketšego',
    '😳' => 'sefahlego se thabilego kudu',
    '😦' => 'sefahlego sa go se dumele le molomo o bulegilego',
    '😧' => 'sefahlego se kwago bohloko',
    '😨' => 'sefahlego se boifago',
    '😰' => 'sefahlego sa molomo o bulegilego le kudumela e tonyago',
    '😥' => 'sefahlego se nyamilego sa go imologa',
    '😢' => 'sefahlego se llago',
    '😭' => 'sefahlego se llelago godimo',
    '😱' => 'sefahlego se goeletšago ka poifo',
    '😖' => 'sefahlego se tenegilego',
    '😣' => 'sefahlego sa go kgotlelela',
    '😞' => 'sefahlego se se nyamilego',
    '😓' => 'sefahlego sa kudumela e tonyago',
    '😩' => 'sefahlego se imelwago',
    '😫' => 'sefahlego se lapilego',
    '😤' => 'sefahlego sa go tupa muši nkong',
    '😡' => 'sefahlego se ipopilego molomo',
    '😠' => 'sefahlego se galefilego',
    '🤬' => 'sefahlego se nago le maswao kgauswi le molomo',
    '😈' => 'sefahlego sa manaka se myemyelago',
    '👿' => 'sefahlego sa manaka se galefilego',
    '💀' => 'marapo a hlogo',
    '☠' => 'marapo a hlogo le marapo a putlaganego',
    '💩' => 'mokgobo wa makaka',
    '🤡' => 'sefahlego sa rametlae',
    '👹' => 'okere',
    '👺' => 'kobline',
    '👻' => 'sepoko',
    '👽' => 'motšwantle',
    '👾' => 'sephedi sa motšwantle',
    '🤖' => 'sefahlego sa roboto',
    '😺' => 'sefahlego se myemyelago sa katse se butšego molomo',
    '😸' => 'sefahlego sa katse se myemyelago kudu le mahlong',
    '😹' => 'sefahlego sa katse sa mekgokgo ya lethabo',
    '😻' => 'sefahlego sa katse se myemyelago le mahlo a lerato',
    '😼' => 'sefahlego sa katse se tenegilego',
    '😽' => 'sefahlego sa katse sa go atlana se tswaletše mahlo',
    '🙀' => 'sefahlego se imetšwego sa katse',
    '😿' => 'sefahlego sa katse se se llago',
    '😾' => 'katse e ipopilego molomo',
    '🙈' => 'kgabo ya go se bone bobe',
    '🙉' => 'kgabo ya go se kwe bobe',
    '🙊' => 'kgabo ya go se bolele bobe',
    '💌' => 'lengwalo la lerato',
    '💘' => 'pelo le lerungwana',
    '💝' => 'pelo ya ribone',
    '💖' => 'pelo e benyabenyago',
    '💗' => 'pelo e golago',
    '💓' => 'pelo e bethago',
    '💞' => 'dipelo tše dikologago',
    '💕' => 'dipelo tše pedi',
    '💟' => 'pelo e kgabišitšwego',
    '❣' => 'go makala ga pelo e kgolo',
    '💔' => 'pelo e robegilego',
    '❤' => 'pelo e khubedu',
    '🧡' => 'pelo ya mmala wa namune',
    '💛' => 'pelo e serolwana',
    '💚' => 'pelo e talamorogo',
    '💙' => 'pelo e talalegodimo',
    '💜' => 'pelo e phepolo',
    '🖤' => 'pelo e ntsho',
    '💋' => 'leswao la tladimolongwana',
    '💯' => 'dintlha tše lekgolo',
    '💢' => 'leswao la kgalefo',
    '💥' => 'go thulana',
    '💫' => 'Go dikologa',
    '💦' => 'marothi a kudumela',
    '💨' => 'go sepela',
    '🕳' => 'molete',
    '💬' => 'polelo ya ka paloneng',
    '🗨' => 'podula ya polelo ka go le letshadi',
    '🗯' => 'podula ya polelo ka go le letona',
    '💭' => 'paloni ya go nagana',
    '💤' => 'zzz',
    '👋' => 'letsogo le dumedišago',
    '🤚' => 'letsogo le emišeditšwego morago',
    '🖐' => 'go emiša letsogo o arogantše menwana',
    '✋' => 'letsogo le išitšwego godimo',
    '🖖' => 'go dumediša ga vulcan',
    '👌' => 'letsogo le le rego GO LOKILE',
    '✌' => 'seatla la go thopa',
    '🤞' => 'menwana e kopanego',
    '🤟' => 'leswao la lerato',
    '🤘' => 'leswao la manaka',
    '🤙' => 'seatla le bitšago',
    '👈' => 'letsogo la ka morago le šupile ka go le letshadi',
    '👉' => 'letsogo la ka morago le šupile ka go le letona',
    '👆' => 'letsogo la ka morago le šupile godimo',
    '🖕' => 'monwana wa gare',
    '👇' => 'letsogo la ka morago le šupile tlase',
    '☝' => 'monwana wa bone o šupile godimo',
    '👍' => 'monwana o mokoto godimo',
    '👎' => 'monwana o mogolo tlase',
    '✊' => 'feise e išitšwego godimo',
    '👊' => 'feise e sa tlago',
    '🤛' => 'letswele le lebilego ka le letshadi',
    '🤜' => 'letswele le lebilego ka go le letona',
    '👏' => 'go betha matsogo',
    '🙌' => 'go emiša matsogo',
    '👐' => 'matsogo a bulegilego',
    '🤲' => 'matsogo a ile godimo gotee',
    '🤝' => 'tumedišo ka letsogo',
    '🙏' => 'diatla tše phuthilwego',
    '✍' => 'seatla le ngwalago',
    '💅' => 'pholeše ya manala',
    '🤳' => 'go itšea senepe',
    '💪' => 'dimpana tša go itwaetša',
    '👂' => 'tsebe',
    '👃' => 'nko',
    '🧠' => 'monagano',
    '👀' => 'mahlo',
    '👁' => 'leihlo',
    '👅' => 'leleme',
    '👄' => 'molomo',
    '👶' => 'lesea',
    '🧒' => 'ngwana',
    '👦' => 'mošemane',
    '👧' => 'mosetsana',
    '🧑' => 'motho yo mogolo',
    '👱' => 'motho wa meriri ye mesehla',
    '👨' => 'monna',
    '🧔' => 'motho ka maledu',
    '👩' => 'mosadi',
    '🧓' => 'mokgalabje yo mogolo',
    '👴' => 'mokgalabje',
    '👵' => 'mokgekolo',
    '🙍' => 'motho yo a sa dumelego ka ditho',
    '🙎' => 'motho yo a ipopilego molomo',
    '🙅' => 'motho o re AOWA ka ditho',
    '🙆' => 'Motho o re go LOKILE',
    '💁' => 'motho yo a dumelago ka seatla',
    '🙋' => 'motho o emišitše seatla',
    '🙇' => 'motho yo a inamego',
    '🤦' => 'motho yo a emišago ka seatla',
    '🤷' => 'motho yo a emišitšego magetla',
    '👮' => 'mohlankedi wa maphodisa',
    '🕵' => 'lephodisa',
    '💂' => 'mohlokomedi',
    '👷' => 'mošomi wa go aga',
    '🤴' => 'morwakgoši',
    '👸' => 'kgošigadi',
    '👳' => 'motho yo rwelego thepene',
    '👲' => 'monna ka kefa ya Matšhaena',
    '🧕' => 'mosadi yo a rwelego hlogong',
    '🤵' => 'monna ka sutu',
    '👰' => 'ngwetši ka lešira',
    '🤰' => 'mosadi yo a imilego',
    '🤱' => 'go nyantšha',
    '👼' => 'lengoloi la lesea',
    '🎅' => 'Santa Claus',
    '🤶' => 'Mohumagadi Claus',
    '🧙' => 'maleatlana',
    '🧚' => 'boikgopolelo',
    '🧛' => 'bemphaya',
    '🧜' => 'motho wa ka meetseng',
    '🧝' => 'sephidi se matla',
    '🧞' => 'genie',
    '🧟' => 'setlotlwane',
    '💆' => 'motho yo a masatšwago',
    '💇' => 'motho yo a kotwago moriri',
    '🚶' => 'motho yo a sepelago',
    '🏃' => 'motho yo a kitimago',
    '💃' => 'mosadi yo a binago',
    '🕺' => 'monna yo a binago',
    '🕴' => 'monna o apere sutu ya mošomo wa ema',
    '👯' => 'batho ba ditsebe tša mmutla ba a bina',
    '🧖' => 'motho ka phaphošing ya moya wa go fiša',
    '🧗' => 'motho o a namela',
    '🤺' => 'motho o lwa ka marumo',
    '🏇' => 'go kitima ga dipere',
    '⛷' => 'sekhaya',
    '🏂' => 'go sesa lehlweng',
    '🏌' => 'motho o bapala kolofo',
    '🏄' => 'motho a sesa lewatleng',
    '🚣' => 'motho ka seketswana',
    '🏊' => 'motho o a rutha',
    '⛹' => 'motho o bethantšha polo',
    '🏋' => 'motho o kuka boima',
    '🚴' => 'motho ka paesekela',
    '🚵' => 'motho ka paesekela thabeng',
    '🤸' => 'motho a dikologa ka mmele',
    '🤼' => 'motho o lwa reseling',
    '🤽' => 'motho o bapala polo ya ka meetseng',
    '🤾' => 'motho a bapala polo ya diatla',
    '🤹' => 'motho o swara mo le mola',
    '🧘' => 'motho a phuthile maoto',
    '🛀' => 'motho o a hlapa',
    '🛌' => 'motho mpeteng',
    '👭' => 'basadi ba babedi ba swarane ka matsogo',
    '👫' => 'monna le mosadi ba swarane ka matsogo',
    '👬' => 'banna ba babedi ba swarane ka matsogo',
    '💏' => 'atlana',
    '💑' => 'balekane ka pelwana',
    '🗣' => 'hlogo e bolelago',
    '👤' => 'ka gare ga silhouete',
    '👥' => 'bogareng bja silhouete',
    '👪' => 'lapa',
    '👣' => 'mehlala ya dikgato',
    '🐵' => 'sefahlego sa kgabo',
    '🐒' => 'kgabo',
    '🦍' => 'korela',
    '🐶' => 'sefahlego sa mpša',
    '🐕' => 'mpša',
    '🐩' => 'mpšha e nyenyane',
    '🐺' => 'sefahlego sa phiri',
    '🦊' => 'sefahlego sa phukubje',
    '🐱' => 'sefahlego sa katse',
    '🐈' => 'katse',
    '🦁' => 'sefahlego sa tau',
    '🐯' => 'sefahlego sa lepogo',
    '🐅' => 'lepogo',
    '🐆' => 'nkwe',
    '🐴' => 'sefahlego sa pere',
    '🐎' => 'pere',
    '🦄' => 'seswantšhwana sa phoofolo',
    '🦓' => 'pitsi',
    '🦌' => 'kgama',
    '🐮' => 'sefahlego sa kgomo',
    '🐂' => 'pholo',
    '🐃' => 'nare ya ka meetseng',
    '🐄' => 'kgomo ya tshadi',
    '🐷' => 'sefahlego sa kolobe',
    '🐖' => 'kolobe',
    '🐗' => 'kolobe ya naga',
    '🐽' => 'nko ya kolobe',
    '🐏' => 'kgapa',
    '🐑' => 'nku ya tshadi',
    '🐐' => 'pudi',
    '🐪' => 'kamela',
    '🐫' => 'kamela ya mathota a mabedi',
    '🦒' => 'thutlwa',
    '🐘' => 'tlou',
    '🦏' => 'tšhukudu',
    '🐭' => 'sefahlego sa legotlo',
    '🐁' => 'maose',
    '🐀' => 'legotlo',
    '🐹' => 'sefahlego sa ntswete',
    '🐰' => 'sefahlego sa mmutla',
    '🐇' => 'mmutla',
    '🐿' => 'legotlonyana',
    '🦔' => 'noko',
    '🦇' => 'mankgagane',
    '🐻' => 'sefahlego se bere',
    '🐨' => 'koala',
    '🐼' => 'sefahlego sa phanta',
    '🐾' => 'mohlala wa borofa',
    '🦃' => 'turkey',
    '🐔' => 'kgogo',
    '🐓' => 'mokoko',
    '🐣' => 'letswiana le a thwathwaša',
    '🐤' => 'letswiana',
    '🐥' => 'letswiana le le galefilego',
    '🐦' => 'nonyana',
    '🐧' => 'phenkhwini',
    '🕊' => 'leeba',
    '🦅' => 'ntšhu',
    '🦆' => 'lepidibidi',
    '🦉' => 'leribiši',
    '🐸' => 'sefahlego sa segwagwa',
    '🐊' => 'kwena',
    '🐢' => 'khudu ya ka meetseng',
    '🦎' => 'mokgaditswane',
    '🐍' => 'noga',
    '🐲' => 'sefahlego sa kgolomodumo',
    '🐉' => 'kgolomodumo',
    '🦕' => 'sauropod',
    '🦖' => 'T-Rex',
    '🐳' => 'leruarua le le tshwelago',
    '🐋' => 'leruarua',
    '🐬' => 'tolefini',
    '🐟' => 'hlapi',
    '🐠' => 'hlapi ya mebala',
    '🐡' => 'hlapi ya go kokomoga',
    '🦈' => 'šaka',
    '🐙' => 'okthopase',
    '🐚' => 'shele',
    '🦀' => 'letlapakgerere',
    '🦐' => 'šerimpo',
    '🦑' => 'sekhwiti',
    '🐌' => 'kgopa',
    '🦋' => 'serurubele',
    '🐛' => 'selomanyane',
    '🐜' => 'tšhošane',
    '🐝' => 'nosi',
    '🐞' => 'khunkwanyane ya tshadi',
    '🦗' => 'khrikete',
    '🕷' => 'segoko',
    '🕸' => 'bolepu bja segoko',
    '🦂' => 'kgome',
    '💐' => 'ngatana ya matšoba',
    '🌸' => 'matšoba a cherry',
    '💮' => 'letšoba le letšhweu',
    '🏵' => 'rosete',
    '🌹' => 'letšobana',
    '🥀' => 'letšoba le ponnego',
    '🌺' => 'letšoba le bulegilego',
    '🌻' => 'sonopolomo',
    '🌼' => 'khukhuša',
    '🌷' => 'lekhukhuša',
    '🌱' => 'peu',
    '🌲' => 'mohlare wa go dula o le o motala',
    '🌳' => 'mohlare wa go hlohlorega',
    '🌴' => 'mohlare wa mopalema',
    '🌵' => 'khakthase',
    '🌾' => 'mohlare wa reise',
    '🌿' => 'segwere',
    '☘' => 'šemoroko',
    '🍀' => 'letlakala la mahlare a mane',
    '🍁' => 'letlakala la mohlare',
    '🍂' => 'letlakala le le welego',
    '🍃' => 'letlakala leo le tšwego ke moya',
    '🍄' => 'mašerumu',
    '🍇' => 'diterebe',
    '🍈' => 'melone',
    '🍉' => 'legapu',
    '🍊' => 'nariki',
    '🍋' => 'swiri',
    '🍌' => 'panana',
    '🍍' => 'phaeneapole',
    '🍎' => 'apola e hubedu',
    '🍏' => 'apola e tala',
    '🍐' => 'piere',
    '🍑' => 'perekisi',
    '🍒' => 'cheri',
    '🍓' => 'strawberry',
    '🥝' => 'seenywa sa kiwi',
    '🍅' => 'tamati',
    '🥥' => 'khokhonate',
    '🥑' => 'abokhate',
    '🍆' => 'mothobe',
    '🥔' => 'letapola',
    '🥕' => 'kherotse',
    '🌽' => 'letlakala la lehea',
    '🌶' => 'perepere ya go baba',
    '🥒' => 'khukhampa',
    '🥦' => 'brokholi',
    '🥜' => 'ditokomane',
    '🌰' => 'dikoko',
    '🍞' => 'borotho',
    '🥐' => 'khroisante',
    '🥖' => 'borotho bja baguette',
    '🥨' => 'simba',
    '🥞' => 'dipanse',
    '🧀' => 'selai sa tšhese',
    '🍖' => 'nama lerapong',
    '🍗' => 'monatlana',
    '🥩' => 'nama',
    '🥓' => 'nama ya kolobe',
    '🍔' => 'hampeka',
    '🍟' => 'ditšhipisi',
    '🍕' => 'phitsa',
    '🌭' => 'hot dog',
    '🥪' => 'sangwetši',
    '🌮' => 'thakho',
    '🌯' => 'burrito',
    '🥙' => 'borotho bja phaphathi bjo tladitšwego',
    '🥚' => 'lee',
    '🍳' => 'apea',
    '🥘' => 'pane ya go iša ya borotho',
    '🍲' => 'poto ya dijo',
    '🥣' => 'sekotlelo le lelepola',
    '🥗' => 'salate e tala',
    '🍿' => 'phopokhone',
    '🥫' => 'sejo ka kheneng',
    '🍱' => 'lepokisana la bento',
    '🍘' => 'pisikiti',
    '🍙' => 'polo ya reise',
    '🍚' => 'reise e apeilwego',
    '🍛' => 'reise ya go baba',
    '🍜' => 'sekotlelo sa go fiša',
    '🍝' => 'makaroni',
    '🍠' => 'matapola a forailwego',
    '🍢' => 'metswako ya dijo',
    '🍣' => 'suši',
    '🍤' => 'hlapiana e forailwego',
    '🍥' => 'kheke e thadilwego ya hlapi',
    '🍡' => 'dango',
    '🥟' => 'letompolo',
    '🥠' => 'kuku ya mahlatse',
    '🥡' => 'lepokisi la dijo',
    '🍦' => 'ice cream e boleta',
    '🍧' => 'aese ye bopilwego',
    '🍨' => 'ice cream',
    '🍩' => 'tonate',
    '🍪' => 'kuku',
    '🎂' => 'khekhe ya matswalo',
    '🍰' => 'khekhe e kopana',
    '🥧' => 'phae',
    '🍫' => 'para ya tšhokolete',
    '🍬' => 'lelekere',
    '🍭' => 'pongpong',
    '🍮' => 'khasetete',
    '🍯' => 'pitša ya todi',
    '🍼' => 'tami',
    '🥛' => 'galase ya maswi',
    '☕' => 'seno se fišago',
    '🍵' => 'kopi ya go hloka mokgok',
    '🍶' => 'seike',
    '🍾' => 'lepotlelo la go tswalela ka lepolankana',
    '🍷' => 'galase ya beine',
    '🍸' => 'galase ya cocktail',
    '🍹' => 'seno se kgabišitšwego',
    '🍺' => 'kopi ya piri',
    '🍻' => 'dikopi tša piri di a bethanago',
    '🥂' => 'digalase tše di bethanago',
    '🥃' => 'galase ya go hloka mokgoko',
    '🥤' => 'komiki le lethontswana',
    '🥢' => 'diphatana',
    '🍽' => 'thipa le foroko ka poleiteng',
    '🍴' => 'foroko le thipa',
    '🥄' => 'lelepola',
    '🔪' => 'thipa ya go apea',
    '🏺' => 'moeta',
    '🌍' => 'mmapa o bontšhago Yuropa le Afrika',
    '🌎' => 'mmapa o bontšhago Amerika',
    '🌏' => 'mmapa o bontšhago Asia le Australia',
    '🌐' => 'diswantšho tša lefase',
    '🗺' => 'mmepe wa lefase',
    '🗾' => 'mmapa wa Japane',
    '🏔' => 'thaba e apereditšwego ke lehlwa',
    '⛰' => 'thaba',
    '🌋' => 'thabamollo',
    '🗻' => 'mothuthupo wa thaba',
    '🏕' => 'go kampa',
    '🏖' => 'lebopo le samporene',
    '🏜' => 'leganata',
    '🏝' => 'sehlakahlakaganata',
    '🏞' => 'serapa sa bosetšhaba',
    '🏟' => 'lepatlelo',
    '🏛' => 'moago wa kgale',
    '🏗' => 'go aga moago',
    '🏘' => 'dintlo',
    '🏚' => 'ntlo e hlokomologilwego',
    '🏠' => 'ntlo',
    '🏡' => 'ntlo le serapa',
    '🏢' => 'moago wa diofisi',
    '🏣' => 'ofisi ya poso ya japane',
    '🏤' => 'ofisi ya poso',
    '🏥' => 'sepetlele',
    '🏦' => 'panka',
    '🏨' => 'hotele',
    '🏩' => 'hotele ya lerato',
    '🏪' => 'lebenkele la kholofelo',
    '🏫' => 'sekolo',
    '🏬' => 'lefapha la lebenkele',
    '🏭' => 'feme',
    '🏯' => 'ntlo ya bogoši ya Japane',
    '🏰' => 'ntlo ya bogoši',
    '💒' => 'lenyalo',
    '🗼' => 'tora ya Tokyo',
    '🗽' => 'Sehlwa se eme sa Liberty',
    '⛪' => 'kereke',
    '🕌' => 'mosque',
    '🕍' => 'sinagogo',
    '⛩' => 'aletare ya shinto',
    '🕋' => 'kaaba',
    '⛲' => 'petse',
    '⛺' => 'tente',
    '🌁' => 'go kgodi',
    '🌃' => 'bošego bja dinaledi',
    '🏙' => 'ponagalo ya toropo',
    '🌄' => 'letšatši le hlaba thabeng',
    '🌅' => 'go hlaba ga letšatši',
    '🌆' => 'kgoro e bonalago lewatleng',
    '🌇' => 'go dikela ga letšatši',
    '🌉' => 'leporogo bošego',
    '♨' => 'lehlabula la go fiša',
    '🎠' => 'pere ya kharaosele',
    '🎡' => 'leotwana la teku',
    '🎢' => 'papadi ya dinamelwa tša moyeng',
    '💈' => 'pala ya lebenkele la go kota meriri',
    '🎪' => 'tente ya metlae',
    '🚂' => 'terene',
    '🚃' => 'terene ya koloi',
    '🚄' => 'terene ya lebelo',
    '🚅' => 'lebelo la terene ya nko ya kolo',
    '🚆' => 'setimela',
    '🚇' => 'toropokgolo',
    '🚈' => 'seporo sa lebone',
    '🚉' => 'seteše',
    '🚊' => 'terene ya mohlagase',
    '🚝' => 'terene ya go sepela godimo',
    '🚞' => 'seporo sa thabeng',
    '🚋' => 'koloi ya go bulega',
    '🚌' => 'pese',
    '🚍' => 'pese e tlago',
    '🚎' => 'pese ya terole',
    '🚐' => 'pese e nyenyane',
    '🚑' => 'ampulense',
    '🚒' => 'koloi ya ditimamollo',
    '🚓' => 'koloi ya maphodisa',
    '🚔' => 'koloi ya maphodisa e tlago',
    '🚕' => 'thekisi',
    '🚖' => 'thekisi e tlago',
    '🚗' => 'mmotoro',
    '🚘' => 'mmotoro o tlago',
    '🚙' => 'koloi ya dipapadi',
    '🚚' => 'lori ya dithoto',
    '🚛' => 'lori ya merwalo',
    '🚜' => 'terekere',
    '🏎' => 'koloi ya mabelo',
    '🏍' => 'sekuta',
    '🛵' => 'sekuta sa mmoto',
    '🚲' => 'paesekele',
    '🛴' => 'paesekela e nyenyane',
    '🚏' => 'boemapese',
    '🛣' => 'mmila',
    '🛤' => 'terene tseleng ye terene',
    '🛢' => 'moropa wa oli',
    '⛽' => 'pompo ya peterole',
    '🚨' => 'lebone la koloi ya maphodisa',
    '🚥' => 'roboto ya go rapama',
    '🚦' => 'roboto ya go tsepama',
    '🛑' => 'leswao la ema',
    '🚧' => 'go aga',
    '⚓' => 'ankere',
    '⛵' => 'seketswana sa go sesa',
    '🛶' => 'seketswana',
    '🚤' => 'sekepe sa lebelo',
    '🛳' => 'monamedi wa sekepe',
    '⛴' => 'sekepe se segolo',
    '🛥' => 'thuthuthu',
    '🚢' => 'sekepe',
    '✈' => 'sefofane',
    '🛩' => 'sefofane se senyenyane',
    '🛫' => 'moo difofane di tlogago gona',
    '🛬' => 'go goroga ga sefofane',
    '💺' => 'setulo',
    '🚁' => 'helikhoptara',
    '🚟' => 'seporo se fegilwego',
    '🚠' => 'thapo ya thaba',
    '🚡' => 'koloyana ya dithapo',
    '🛰' => 'sathalaete',
    '🚀' => 'rokhete',
    '🛸' => 'piring ya go fofa',
    '🛎' => 'pele ya lebati',
    '⌛' => 'galasana ya nako',
    '⏳' => 'galase ya nako e nago le santa',
    '⌚' => 'sešupanako',
    '⏰' => 'sešupanako sa alamo',
    '⏱' => 'nako ya go ema',
    '⏲' => 'go lekanyetša nako',
    '🕰' => 'nako e botse',
    '🕛' => 'iri ya lesomepedi godimo ga hlogo',
    '🕧' => 'seripa ka morago ga iri ya lesomepedi',
    '🕐' => 'iri ya pele godimo ga hlogo',
    '🕜' => 'seripa ka morago ga iri ya pele',
    '🕑' => 'iri ya bobedi godimo ga hlogo',
    '🕝' => 'seripa ka morago ga iri ya bobedi',
    '🕒' => 'iri ya boraro godimo ga hlogo',
    '🕞' => 'seripagare go tšwa go iri ya boraro',
    '🕓' => 'iri ya bone godimo ga hlogo',
    '🕟' => 'seripagare go tšwa go iri ya bone',
    '🕔' => 'iri ya bohlano godimo ga hlogo',
    '🕠' => 'seripagare go tšwa go iri ya bohlano',
    '🕕' => 'iri ya boselela godimo ga hlogo',
    '🕡' => 'seripagare go tšwa go botshelela',
    '🕖' => 'iri ya bošupa godimo ga hlogo',
    '🕢' => 'seripagare go tšwa go iri ya bošupa',
    '🕗' => 'iri ya seswai godimo ga hlogo',
    '🕣' => 'seripagare go tšwa go iri ya seswai',
    '🕘' => 'iri ya senyane godimo ga hlogo',
    '🕤' => 'seripagare go tšwa go iri ya senyane',
    '🕙' => 'iri ya lesome godimo ga hlogo',
    '🕥' => 'seripagare go tšwa go iri ya lesome',
    '🕚' => 'iri ya lesometee godimo ga hlogo',
    '🕦' => 'seripa ka morago ga iri ya lesometee',
    '🌑' => 'ngwedi o mofsa',
    '🌒' => 'ngwedi wa seripa wo o kgopamego',
    '🌓' => 'ngwedi wa kotara ya mathomo',
    '🌔' => 'ngwedi wo o fifetšego',
    '🌕' => 'ngwedi o tletšego',
    '🌖' => 'ngwedi o sa felelago',
    '🌗' => 'kotara ya mafelelo ya ngwedi',
    '🌘' => 'ngwedi o hwelelago wa go kgopama',
    '🌙' => 'ngwedi o balamego',
    '🌚' => 'sefahlego sa ngwedi o mofsa',
    '🌛' => 'kotara ya mathomo ya ngwedi le sefahlego',
    '🌜' => 'kotara ya mafelelo ya ngwedi le sefahlego',
    '🌡' => 'themomethara',
    '☀' => 'letšatši',
    '🌝' => 'ngwedi o feletšego le sefahlego',
    '🌞' => 'letšatši le nago le ngwedi',
    '⭐' => 'naledi ya bogare ye tšhweu',
    '🌟' => 'naledi e phadimago',
    '🌠' => 'naledi e fofago',
    '🌌' => 'dithutlwanaledi',
    '☁' => 'maru',
    '⛅' => 'letšatši ka morago ga ngwedi',
    '⛈' => 'maru a magadima le pula',
    '🌤' => 'letšatši ka morago ga leru le lenyenyane',
    '🌥' => 'letšatši ka morago ga leru le legolo',
    '🌦' => 'letšatši ka morago ga leru la pula',
    '🌧' => 'maru a nago le pula',
    '🌨' => 'maru a nago le lehlwa',
    '🌩' => 'maru a nago le magadima',
    '🌪' => 'thonato',
    '🌫' => 'kgodi',
    '🌬' => 'bokapele bja moya',
    '🌀' => 'modikologo',
    '🌈' => 'molalatladi',
    '🌂' => 'samporene se se tswaletšwego',
    '☂' => 'samporene',
    '☔' => 'samporene se nago le marothodi a pula',
    '⛱' => 'samporene mo fase',
    '⚡' => 'voltage ya godimo',
    '❄' => 'lehlwa le legolo',
    '☃' => 'monna wa lehlwa',
    '⛄' => 'monna wa lehlwa ntle le lehlwa',
    '☄' => 'khomete',
    '🔥' => 'mollo',
    '💧' => 'lerotholodi',
    '🌊' => 'lephoto la meetse',
    '🎃' => 'seswantšhwana sa moletlo',
    '🎄' => 'mohlare wa Keresemose',
    '🎆' => 'dikherikhete',
    '🎇' => 'sephadimi',
    '✨' => 'ya phadima',
    '🎈' => 'palone',
    '🎉' => 'sesenyamodiro',
    '🎊' => 'polo ya moletlo',
    '🎋' => 'mohlare wa tanabata',
    '🎍' => 'mokgabišo wa pine',
    '🎎' => 'dipopi tša Japane',
    '🎏' => 'popi ya hlapi',
    '🎐' => 'mokgabišo',
    '🎑' => 'moletlo wa go bona ngwedi',
    '🎀' => 'ripone',
    '🎁' => 'mpho e kgabišitšwego',
    '🎗' => 'ribone ya kgopotšo',
    '🎟' => 'dithekete tša go tsena',
    '🎫' => 'thekete',
    '🎖' => 'metale wa mašole',
    '🏆' => 'sefoka',
    '🏅' => 'metale ya dipapadi',
    '🥇' => 'metale wa maemo a pele',
    '🥈' => 'metale wa maemo a bobedi',
    '🥉' => 'metale wa maemo a boraro',
    '⚽' => 'kgwele ya maoto',
    '⚾' => 'peisepolo',
    '🏀' => 'kgwele ya diatla',
    '🏐' => 'bolipolo',
    '🏈' => 'polo ya amerika',
    '🏉' => 'polo ya rakbi',
    '🎾' => 'thenese',
    '🎳' => 'go paola',
    '🏏' => 'papadi ya krikete',
    '🏑' => 'papadi ya hockey',
    '🏒' => 'hoki ya lehlweng',
    '🏓' => 'polo ya ping',
    '🏸' => 'petemintone',
    '🥊' => 'ditlelafo tša papadi ya matswele',
    '🥋' => 'yunifomo ya bokgabo bja sekarate',
    '🥅' => 'nete ya dino',
    '⛳' => 'folaga ka lešobeng',
    '⛸' => 'go bapala go sesa aeseng',
    '🎣' => 'pale ya go rea dihlapi',
    '🎽' => 'hempe ya go kitima',
    '🎿' => 'sekhaese',
    '🛷' => 'tafolana',
    '🥌' => 'leswika le kgopamego',
    '🎯' => 'go betha ka go lebanya',
    '🔫' => 'sethunya se sennyane',
    '🎱' => 'polo ya bo 8',
    '🔮' => 'polo ya go phadima',
    '🎮' => 'papadi ya bidio',
    '🕹' => 'selo sa go bapadiša',
    '🎰' => 'motšhene wa tšhelete',
    '🎲' => 'papadi ya letaese',
    '♠' => 'sutu ya sepeiti',
    '♥' => 'pelo ya suit',
    '♦' => 'taemane ya suti',
    '♣' => 'sutu ya sehlopha',
    '🃏' => 'joker',
    '🀄' => 'kgolomodumo e hubedu ya mahjong',
    '🎴' => 'dikarata tša papadi tša matšoba',
    '🎭' => 'go dira tša bokgabo',
    '🖼' => 'senepe se se foreimetšwego',
    '🎨' => 'palete ya bokgabo',
    '👓' => 'digalase',
    '🕶' => 'digalase tša letšatši',
    '👔' => 'thai',
    '👕' => 'sekhipha',
    '👖' => 'dipokathe',
    '🧣' => 'sekhafo',
    '🧤' => 'ditlelafo',
    '🧥' => 'baiki',
    '🧦' => 'masokisi',
    '👗' => 'roko',
    '👘' => 'kimono',
    '👙' => 'pikini',
    '👚' => 'diaparo tša basadi',
    '👛' => 'sekhwama',
    '👜' => 'peke ya go athwa',
    '👝' => 'peke ya basadi',
    '🛍' => 'mokotla wa reka',
    '🎒' => 'peke ya sekolo',
    '👞' => 'seeta sa monna',
    '👟' => 'dieta tša go kitima',
    '👠' => 'dihili tše ditelele tša basadi',
    '👡' => 'ramphašane ya basadi',
    '👢' => 'diputsu tša basadi',
    '👑' => 'korone',
    '👒' => 'kefa ya basadi',
    '🎩' => 'kefa ya godimo',
    '🎓' => 'kefa ya go aloga',
    '🧢' => 'kefa ya thekišo',
    '⛑' => 'helmete ya bašomi ba thušo',
    '📿' => 'dipheta tša thapelo',
    '💄' => 'setlolamelomo',
    '💍' => 'palamonwana',
    '💎' => 'leswika le bohlokwa',
    '🔇' => 'dipikara tše di timilwego',
    '🔈' => 'sepikara sa bolumo ya tlase',
    '🔉' => 'sepikara sa bolumo ya magareng',
    '🔊' => 'sepikara sa bolumo ya godimo',
    '📢' => 'sepikara sa go rasa',
    '📣' => 'mekafoune',
    '📯' => 'lenaka la poso',
    '🔔' => 'pele',
    '🔕' => 'pele e khansetšwego',
    '🎼' => 'dintlha tša mmino',
    '🎵' => 'noto ya mmino',
    '🎶' => 'dinnoto tša mmino',
    '🎙' => 'maekrofouno wa ka setutiong',
    '🎚' => 'konope ya selaeta',
    '🎛' => 'dikonope tša go laola',
    '🎤' => 'maekherofoune',
    '🎧' => 'ditsebjana',
    '📻' => 'seyalemoya',
    '🎷' => 'seksofoune',
    '🎺' => 'porompeta',
    '🎸' => 'katara',
    '🎹' => 'khiipoto ya mmino',
    '🎻' => 'bayolini',
    '🥁' => 'moropa',
    '📱' => 'selefouno',
    '📲' => 'founo ya go ba le lerungwana',
    '☎' => 'founo',
    '📞' => 'seamogedi sa founo',
    '📟' => 'pheitšara',
    '📠' => 'motšhene wa fekese',
    '🔋' => 'peteri',
    '🔌' => 'pholaka ya mohlagase',
    '💻' => 'khomphutha ya lepthopo',
    '🖥' => 'khomphutha ya teskthopo',
    '🖨' => 'phrinthara',
    '⌨' => 'khiipoto',
    '🖱' => 'maose wa khomphutha',
    '🖲' => 'polwana ya maose',
    '💽' => 'tiske ya khomphutha',
    '💾' => 'flopitiske',
    '💿' => 'tiske ya kgetho',
    '📀' => 'dvd',
    '🎥' => 'khamera ya mmobi',
    '🎞' => 'diforeime tša filimi',
    '📽' => 'protšekta ya filimi',
    '🎬' => 'poto ya mmobi',
    '📺' => 'thelebišene',
    '📷' => 'khamera',
    '📸' => 'khamera ya foleše',
    '📹' => 'khamera ya bidio',
    '📼' => 'khasete ya bidio',
    '🔍' => 'galase ya go bona ya go leba ka go le letshadi',
    '🔎' => 'galase ya go bona ya go leba ka go le letona',
    '🕯' => 'kerese',
    '💡' => 'tlelupu',
    '🔦' => 'lebone',
    '🏮' => 'lantere ya letlakakala le lehubedu',
    '📔' => 'notepuku ya khabara e kgabišitšwego',
    '📕' => 'puku e tswaletšwego',
    '📖' => 'puku e bulegilego',
    '📗' => 'puku e talamorogo',
    '📘' => 'puku e talalegodimo',
    '📙' => 'puku ya mmala wa namune',
    '📚' => 'dipuku',
    '📓' => 'notepuku',
    '📒' => 'leja',
    '📃' => 'letlakala le kobegilego',
    '📜' => 'sekorola',
    '📄' => 'letlakala le lebeletšego godimo',
    '📰' => 'kuranta',
    '🗞' => 'kuranta e phuthilwego',
    '📑' => 'dithepo tša go swaya puku',
    '🔖' => 'pukumaraka',
    '🏷' => 'leipole',
    '💰' => 'mokotla wa tšhelete',
    '💴' => 'tšheletepampiri ya yen',
    '💵' => 'tšhelete ya pampiri ya tolara',
    '💶' => 'tšhelete ya pampiri ya yuro',
    '💷' => 'tšhelete ya pampiri ya ponto',
    '💸' => 'tšhelete ya go utswiwa',
    '💳' => 'karata ya mokitlana',
    '💹' => 'tšhate e oketšagago ka yen',
    '✉' => 'omfolopo',
    '📧' => 'emaile',
    '📨' => 'onfolopo e tsenago',
    '📩' => 'onfolopo ya lerungwana',
    '📤' => 'therei ya melaetša ye tšwago',
    '📥' => 'therei ya melaetšatsena',
    '📦' => 'sephuthelwana',
    '📫' => 'lepokisi la melaetša le tswaletšwego le nago le folaga e emeletšego',
    '📪' => 'lepokisi la melaetša le tswaletšwego le nago le folaga e robetšego',
    '📬' => 'lepokisi la melaetša le bulegilego le nago le folaga e emeletšego',
    '📭' => 'lepokisi la melaetša le bulegilego le nago le folaga e robetšego',
    '📮' => 'lepokisi la poso',
    '🗳' => 'lepokisi la palote le nago le palote',
    '✏' => 'phensele',
    '✒' => 'nib e ntsho',
    '🖋' => 'pene e telele',
    '🖊' => 'pene',
    '🖌' => 'poratšhe ya go penta',
    '🖍' => 'kherayone',
    '📝' => 'memorantamo',
    '💼' => 'porifikheisi',
    '📁' => 'faele ya foltara',
    '📂' => 'faele ya foltara e bulegilego',
    '🗂' => 'dikarata tša go aroganya lemetletšo',
    '📅' => 'khalentara',
    '📆' => 'tlerola khalentara',
    '🗒' => 'noutephete e lomagantšwego',
    '🗓' => 'khalentara e lomagatšwego',
    '📇' => 'karata ya tšhupaboteng',
    '📈' => 'go oketšwa ga tšhate',
    '📉' => 'tšhate e fokotšegago',
    '📊' => 'tšhate ya dipara',
    '📋' => 'klipbote',
    '📌' => 'phini ya go kgarametša',
    '📍' => 'phini ya go kgarametša ya nkgokolo',
    '📎' => 'seswarišamatlakala',
    '🖇' => 'seswarišamatlakala sa dilinki',
    '📏' => 'thaladi e emego thwii',
    '📐' => 'thaladi ya khutlotharo',
    '✂' => 'sekero',
    '🗃' => 'lepokisi la go faela dikarata',
    '🗄' => 'kabinete ya difaele',
    '🗑' => 'motomo wa ditlakala',
    '🔒' => 'notletšwe',
    '🔓' => 'e notlolotšwe',
    '🔏' => 'e notletšwe ka pene',
    '🔐' => 'e notletšwe ka khii',
    '🔑' => 'khii',
    '🗝' => 'sekhii sa kgale',
    '🔨' => 'hamole',
    '⛏' => 'peke',
    '⚒' => 'hamola le peke',
    '🛠' => 'hamola le sepanere',
    '🗡' => 'goga',
    '⚔' => 'ditšhoša tše di dirilego sefapano',
    '💣' => 'pomo',
    '🏹' => 'bora le mosebe',
    '🛡' => 'sešireletši',
    '🔧' => 'sepanere',
    '🔩' => 'pauto le nate',
    '⚙' => 'kere',
    '🗜' => 'tlelempo',
    '⚖' => 'go lekanya boleng',
    '🔗' => 'linki',
    '⛓' => 'ditšhaene',
    '⚗' => 'tshwarišano',
    '🔬' => 'maekherosekoupu',
    '🔭' => 'thelesekoupu',
    '📡' => 'sathalaete ya manakana',
    '💉' => 'saerintše',
    '💊' => 'philisi',
    '🚪' => 'lebati',
    '🛏' => 'mpete',
    '🛋' => 'sofa le lebone',
    '🚽' => 'ntlwana ya boithomelo',
    '🚿' => 'šawara',
    '🛁' => 'thepo ya pafo',
    '🛒' => 'mokotla wa go reka',
    '🚬' => 'kwae',
    '⚰' => 'lepokisi',
    '⚱' => 'moeta wa lehu',
    '🗿' => 'sehlwaseeme',
    '🏧' => 'leswao la ATM',
    '🚮' => 'leswao la motomo wa ditlakala',
    '🚰' => 'meetse a swaregago',
    '♿' => 'leswao la wilitšhere',
    '🚹' => 'ntlwanaboithomelo ya banna',
    '🚺' => 'ntlwana ya basadi',
    '🚻' => 'ntlwanaboithušo',
    '🚼' => 'leswao la lesea',
    '🚾' => 'thoilete ya meetse',
    '🛂' => 'taolo ya phasepote',
    '🛃' => 'metlwae',
    '🛄' => 'kleime ya merwalo',
    '🛅' => 'morwalo o tlogetšwego',
    '⚠' => 'temošo',
    '🚸' => 'bana ba a tshela',
    '⛔' => 'ga go tsenwe',
    '🚫' => 'go thibetšwe',
    '🚳' => 'dipaesekela ga di dumelelwe',
    '🚭' => 'ga go kgogwe',
    '🚯' => 'ga go tlatšwe ditlakala',
    '🚱' => 'meetse a sa rwalegego',
    '🚷' => 'batho ga ba dumelelwe',
    '📵' => 'difouno ga di dumelelwe',
    '🔞' => 'e sego ba ka tlase ga lesomeseswai',
    '☢' => 'radioekthibi',
    '☣' => 'kotsitlhagong',
    '⬆' => 'lerungwana la godimo',
    '↗' => 'lerungwana la godimo ka gojeng',
    '➡' => 'lerungwana la gojeng',
    '↘' => 'lerungwana la tlase ka gojeng',
    '⬇' => 'lerungwana la tlase',
    '↙' => 'lerungwana la tlase ka go le letshadi',
    '⬅' => 'lerungwana la ka go le letshadi',
    '↖' => 'lerungwana la godimo ka go le letshadi',
    '↕' => 'lerungwana la godimo le tlase',
    '↔' => 'lerungwana la ka go le letshadi go ya go le letona',
    '↩' => 'lerungwana la godimo le eya ka go le letshadi',
    '↪' => 'lerungwana la ka go le letshadi le eya ka go le letona',
    '⤴' => 'lerungwana la ka go le letona le eya godimo',
    '⤵' => 'lerungwana la ka go le letona lekgopamela tlase',
    '🔃' => 'marungwana a dikologelago ka go le letona',
    '🔄' => 'konope ya marungwana a dikologelago ka go le letshadi',
    '🔙' => 'lerungwana la MORAGO',
    '🔚' => 'lerungwana la go BOFELO',
    '🔛' => 'leswao la go GOTEDITŠE',
    '🔜' => 'leswao la E SE KGALE',
    '🔝' => 'leswao la GODIMO',
    '🛐' => 'lefelo la borapedi',
    '⚛' => 'leswao la athomo',
    '🕉' => 'om',
    '✡' => 'naledi ya Tafita',
    '☸' => 'leotwana la dharma',
    '☯' => 'yin yang',
    '✝' => 'sefapano sa latin',
    '☦' => 'sefapano sa othotokse',
    '☪' => 'naledi e khutlohlano',
    '☮' => 'leswao la khutšo',
    '🕎' => 'sehlomapone',
    '🔯' => 'naletšana ya dikhutlwana e thadilego tshelela',
    '♈' => 'Aries',
    '♉' => 'Taurus',
    '♊' => 'Gemini',
    '♋' => 'Cancer',
    '♌' => 'Leo',
    '♍' => 'Virgo',
    '♎' => 'Libra',
    '♏' => 'Scorpius',
    '♐' => 'Sagittarius',
    '♑' => 'Capricorn',
    '♒' => 'Aquarius',
    '♓' => 'Pisces',
    '⛎' => 'Ophiuchus',
    '🔀' => 'konope ya go beakanya dikoša',
    '🔁' => 'konope ya go bušeletša',
    '🔂' => 'konope e tee ya go bušeletša',
    '▶' => 'konope ya go bapala',
    '⏩' => 'konope ya go bapala ka lebelo',
    '⏭' => 'koša e latelago',
    '⏯' => 'konope ya go emiša goba go bapal',
    '◀' => 'konope ya go boetša morago',
    '⏪' => 'konope ya go boela morago ka lebelo',
    '⏮' => 'konope ya koša ya go feta',
    '🔼' => 'konope ya godimo',
    '⏫' => 'konope ya go ya godimo ka kebelo',
    '🔽' => 'konope ya tlase',
    '⏬' => 'konope ya tlase ka lebelo',
    '⏸' => 'konope ya go emišanyana',
    '⏹' => 'konope ya go emiša',
    '⏺' => 'konope ya go rekhotha',
    '⏏' => 'konope ya go ntšha',
    '🎦' => 'bobogelo bja dimobi',
    '🔅' => 'konope ya go tima',
    '🔆' => 'konope ya go phadima',
    '📶' => 'dipara tša manakana',
    '📳' => 'mokgwa wa go šikinyega',
    '📴' => 'founo e timilwe',
    '♀' => 'leswao la mosadi',
    '♂' => 'leswao la monna',
    '✖' => 'leswao e legolo la go atiša x',
    '➕' => 'leswao le legolo la hlakanya',
    '➖' => 'leswao le legolo la go ntšha',
    '➗' => 'leswao le legolo la aroganya',
    '‼' => 'maswao a mabedi a makalo',
    '⁉' => 'leswao la makalo le potšišo',
    '❓' => 'leswao la potšišo',
    '❔' => 'leswao le letšhweu la hlakanya',
    '❕' => 'leswao le legolo la makalo le letšhweu',
    '❗' => 'leswao la go makala',
    '〰' => 'mothalo wa go dikologa',
    '💱' => 'go fetola tšhelete',
    '💲' => 'leswao le legolo la tolara',
    '⚕' => 'leswao la kalafo',
    '♻' => 'leswao la go hwetša gape',
    '⚜' => 'fluer-de-lis',
    '🔱' => 'leswao sabola',
    '📛' => 'leina la petše',
    '🔰' => 'leswao la Japane la mathomong',
    '⭕' => 'leswao le legolo la nkgokolo',
    '✅' => 'leswao le legolo la go hlola le letšhweu',
    '☑' => 'lepokisi la palote le kgethilwego',
    '✔' => 'leswao le legolo la go kgetha',
    '❌' => 'sefapano',
    '❎' => 'konope ya leswao',
    '➰' => 'meriri e tatanego',
    '➿' => 'meriri e tatanego gabedi',
    '〽' => 'leswao la karolo la go fetola',
    '✳' => 'naletšana ya marungwana a seswai',
    '✴' => 'naledi ya khutloseswai',
    '❇' => 'benya',
    '™' => 'leswao la kgwebo',
    '🔠' => 'go tsenya leswao le legolo la selatine',
    '🔡' => 'go tsenya leswao le lenyenyane la selatine',
    '🔢' => 'go tsenya dinomoro',
    '🔣' => 'go tsenya maswao',
    '🔤' => 'go tsenya ditlhaka tša selatine',
    '🅰' => 'konope ya A (mohuta wa madi)',
    '🆎' => 'konope ya AB (mohuta wa madi)',
    '🅱' => 'konope ya B (mohuta wa madi)',
    '🆑' => 'konope ya CL',
    '🆒' => 'konope ya COOL',
    '🆓' => 'konope ya MAHALA',
    'ℹ' => 'tshedimošo',
    '🆔' => 'konope ya ID',
    'Ⓜ' => 'nkgokolo ya M',
    '🆕' => 'konope ya MPSHA',
    '🆖' => 'konope ya NG',
    '🅾' => 'konope ya O (mohuta wa madi)',
    '🆗' => 'konope ya OK',
    '🅿' => 'konope ya P',
    '🆘' => 'konope ya SOS',
    '🆚' => 'konope ya VS',
    '🈁' => 'konope ya Sejapane ya "mo"',
    '🈂' => 'konope ya Sejapane ya "tefišo ya tirelo"',
    '🈷' => 'konope ya Sejapane ya "tefišo ya kgwedi ka kgwedi"',
    '🈶' => 'konope ya Sejapane ya "ga se mahala"',
    '🈯' => 'konope ya Sejapane ye "beetšwego"',
    '🉐' => 'konope ya Sejapane ya "mpho"',
    '🈹' => 'konope ya Sejapane ya "phokoletšo"',
    '🈚' => 'konope ya Sejapane ya "mahala"',
    '🈲' => 'konope ya Sejapane ya "ileditšwe"',
    '🉑' => 'konope ya Sejapane ya "e amogelegile"',
    '🈸' => 'konope ya Sejapane ya "tirišo"',
    '🈴' => 'konope ya Sejapane ya "go phasa mphato"',
    '🈳' => 'konope ya Sejapane ya "mošomo"',
    '㊗' => 'konope ya Sejapane ya "tebogišo"',
    '㊙' => 'konope ya Sejapane ya "sephiri"',
    '🈺' => 'konope ya Sejapane ya "buletšwe kgwebo"',
    '🈵' => 'konope ya Sejapane ya "ga go sekgoba"',
    '🔴' => 'nkgokolo ye khubedu',
    '🔵' => 'nkgokolo ye talalegodimo',
    '⚫' => 'nkgokolo ye ntsho',
    '⚪' => 'nkgokolo e tšhweu',
    '⬛' => 'khutlonne e ntsho e kgolo',
    '⬜' => 'khutlonne e kgolo tšhweu',
    '◼' => 'bogare bja ngwedi o moso',
    '◻' => 'bogare bja ngwedi o motšhweu',
    '◾' => 'khutlonne e ntsho ya bogareng',
    '◽' => 'khutlonee e tšhweu ya bogareng',
    '▪' => 'khutlonne e nyenyane e ntsho',
    '▫' => 'khutlonne e nyenyane e tšhweu',
    '🔶' => 'taemane e kgolo ya mmala wa namune',
    '🔷' => 'taemane e kgolo e talalegodimo',
    '🔸' => 'taemane e nyenyane ya mmala wa namune',
    '🔹' => 'taemane e nyenyane e talamorogo',
    '🔺' => 'khutlonne e hubedu e šupilego godimo',
    '🔻' => 'khutlonne e hubedu e šupilego fase',
    '💠' => 'taemane e nago le khutlo',
    '🔘' => 'konope ya seyalemoya',
    '🔳' => 'taemane e tšhweu ya khutlonee',
    '🔲' => 'taemane e ntsho ya khutlonee',
    '🏁' => 'folaga e kgethilwego',
    '🚩' => 'fologa ya khutlonne',
    '🎌' => 'difolaga tše di thadilwego ka bogare',
    '🏴' => 'folaga e ntsho',
    '🏳' => 'fologa e tšhweu',
];
